@@ -15,8 +15,6 @@
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <ctime>
-
 #include "SDL_lib.hxx"
 #include "bspf.hxx"
 
@@ -28,15 +26,18 @@
 #include "FBSurfaceSDL2.hxx"
 #include "FrameBufferSDL2.hxx"
 
+#include "ThreadDebugging.hxx"
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FrameBufferSDL2::FrameBufferSDL2(OSystem& osystem)
   : FrameBuffer(osystem),
     myWindow(nullptr),
-    myRenderer(nullptr),
-    myDirtyFlag(true)
+    myRenderer(nullptr)
 {
+  ASSERT_MAIN_THREAD;
+
   // Initialize SDL2 context
-  if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_JOYSTICK) < 0)
+  if(SDL_InitSubSystem(SDL_INIT_VIDEO | SDL_INIT_TIMER) < 0)
   {
     ostringstream buf;
     buf << "ERROR: Couldn't initialize SDL: " << SDL_GetError() << endl;
@@ -55,6 +56,8 @@ FrameBufferSDL2::FrameBufferSDL2(OSystem& osystem)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FrameBufferSDL2::~FrameBufferSDL2()
 {
+  ASSERT_MAIN_THREAD;
+
   SDL_FreeFormat(myPixelFormat);
 
   if(myRenderer)
@@ -75,20 +78,33 @@ FrameBufferSDL2::~FrameBufferSDL2()
     SDL_DestroyWindow(myWindow);
     myWindow = nullptr;
   }
+  SDL_QuitSubSystem(SDL_INIT_VIDEO | SDL_INIT_TIMER);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::queryHardware(vector<GUI::Size>& displays,
                                     VariantList& renderers)
 {
+  ASSERT_MAIN_THREAD;
+
   // First get the maximum windowed desktop resolution
-  SDL_DisplayMode display;
   int maxDisplays = SDL_GetNumVideoDisplays();
+#if SDL_VERSION_ATLEAST(2,0,5)
+  SDL_Rect r;
+  for(int i = 0; i < maxDisplays; ++i)
+  {
+    // Display bounds minus dock
+    SDL_GetDisplayUsableBounds(i, &r);  // Requires SDL-2.0.5 or higher
+    displays.emplace_back(r.w, r.h);
+  }
+#else
+  SDL_DisplayMode display;
   for(int i = 0; i < maxDisplays; ++i)
   {
     SDL_GetDesktopDisplayMode(i, &display);
     displays.emplace_back(display.w, display.h);
   }
+#endif
 
   struct RenderName
   {
@@ -131,12 +147,16 @@ void FrameBufferSDL2::queryHardware(vector<GUI::Size>& displays,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Int32 FrameBufferSDL2::getCurrentDisplayIndex()
 {
+  ASSERT_MAIN_THREAD;
+
   return SDL_GetWindowDisplayIndex(myWindow);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
 {
+  ASSERT_MAIN_THREAD;
+
   // If not initialized by this point, then immediately fail
   if(SDL_WasInit(SDL_INIT_VIDEO) == 0)
     return false;
@@ -144,10 +164,6 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
   // Always recreate renderer (some systems need this)
   if(myRenderer)
   {
-    // Always clear the (double-buffered) renderer surface
-    SDL_RenderClear(myRenderer);
-    SDL_RenderPresent(myRenderer);
-    SDL_RenderClear(myRenderer);
     SDL_DestroyRenderer(myRenderer);
     myRenderer = nullptr;
   }
@@ -173,12 +189,12 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
                  : SDL_WINDOWPOS_UNDEFINED_DISPLAY(displayIndex);
   uInt32 flags = mode.fsIndex != -1 ? SDL_WINDOW_FULLSCREEN_DESKTOP : 0;
 
-  // OSX seems to have issues with destroying the window, and wants to keep
-  // the same handle
+  // macOS seems to have issues with destroying the window, and wants to
+  // keep the same handle
   // Problem is, doing so on other platforms results in flickering when
   // toggling fullscreen windowed mode
-  // So we have a special case for OSX
-#ifndef BSPF_MAC_OSX
+  // So we have a special case for macOS
+#ifndef BSPF_MACOS
   // Don't re-create the window if its size hasn't changed, as it's not
   // necessary, and causes flashing in fullscreen mode
   if(myWindow)
@@ -197,7 +213,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
     SDL_SetWindowTitle(myWindow, title.c_str());
   }
 #else
-  // OSX wants to *never* re-create the window
+  // macOS wants to *never* re-create the window
   // This sometimes results in the window being resized *after* it's displayed,
   // but at least the code works and doesn't crash
   if(myWindow)
@@ -234,6 +250,12 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
     myOSystem.logMessage(msg, 0);
     return false;
   }
+
+  // Always clear the (double-buffered) renderer surface
+  SDL_RenderClear(myRenderer);
+  SDL_RenderPresent(myRenderer);
+  SDL_RenderClear(myRenderer);
+
   SDL_RendererInfo renderinfo;
   if(SDL_GetRendererInfo(myRenderer, &renderinfo) >= 0)
     myOSystem.settings().setValue("video", renderinfo.name);
@@ -241,8 +263,11 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
   return true;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::setTitle(const string& title)
 {
+  ASSERT_MAIN_THREAD;
+
   myScreenTitle = title;
 
   if(myWindow)
@@ -252,6 +277,8 @@ void FrameBufferSDL2::setTitle(const string& title)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string FrameBufferSDL2::about() const
 {
+  ASSERT_MAIN_THREAD;
+
   ostringstream out;
   out << "Video system: " << SDL_GetCurrentVideoDriver() << endl;
   SDL_RendererInfo info;
@@ -272,25 +299,32 @@ string FrameBufferSDL2::about() const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::invalidate()
 {
-  myDirtyFlag = true;
+  ASSERT_MAIN_THREAD;
+
   SDL_RenderClear(myRenderer);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::showCursor(bool show)
 {
+  ASSERT_MAIN_THREAD;
+
   SDL_ShowCursor(show ? SDL_ENABLE : SDL_DISABLE);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::grabMouse(bool grab)
 {
+  ASSERT_MAIN_THREAD;
+
   SDL_SetRelativeMouseMode(grab ? SDL_TRUE : SDL_FALSE);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool FrameBufferSDL2::fullScreen() const
 {
+  ASSERT_MAIN_THREAD;
+
 #ifdef WINDOWED_SUPPORT
   return SDL_GetWindowFlags(myWindow) & SDL_WINDOW_FULLSCREEN_DESKTOP;
 #else
@@ -299,20 +333,20 @@ bool FrameBufferSDL2::fullScreen() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBufferSDL2::postFrameUpdate()
+void FrameBufferSDL2::renderToScreen()
 {
-  if(myDirtyFlag)
-  {
-    // Now show all changes made to the renderer
-    SDL_RenderPresent(myRenderer);
-    myDirtyFlag = false;
-  }
+  ASSERT_MAIN_THREAD;
+
+  // Show all changes made to the renderer
+  SDL_RenderPresent(myRenderer);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::setWindowIcon()
 {
-#ifndef BSPF_MAC_OSX        // Currently not needed for OSX
+  ASSERT_MAIN_THREAD;
+
+#ifndef BSPF_MACOS          // Currently not needed for macOS
 #include "stella_icon.hxx"  // The Stella icon
 
   SDL_Surface* surface = SDL_CreateRGBSurfaceFrom(stella_icon, 32, 32, 32,
@@ -333,6 +367,8 @@ unique_ptr<FBSurface>
 void FrameBufferSDL2::readPixels(uInt8* pixels, uInt32 pitch,
                                  const GUI::Rect& rect) const
 {
+  ASSERT_MAIN_THREAD;
+
   SDL_Rect r;
   r.x = rect.x();  r.y = rect.y();
   r.w = rect.width();  r.h = rect.height();
@@ -344,5 +380,5 @@ void FrameBufferSDL2::readPixels(uInt8* pixels, uInt32 pitch,
 void FrameBufferSDL2::clear()
 {
   invalidate();
-  postFrameUpdate();
+  renderToScreen();
 }
