@@ -15,8 +15,6 @@
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <ctime>
-
 #include "bspf.hxx"
 #include "System.hxx"
 #include "M6502.hxx"
@@ -34,6 +32,8 @@
 #include "CartRamWidget.hxx"
 #include "RomWidget.hxx"
 #include "Base.hxx"
+#include "exception/EmulationWarning.hxx"
+
 using Common::Base;
 using std::hex;
 using std::dec;
@@ -48,7 +48,6 @@ CartDebug::CartDebug(Debugger& dbg, Console& console, const OSystem& osystem)
     myOSystem(osystem),
     myDebugWidget(nullptr),
     myAddrToLineIsROM(true),
-    myRWPortAddress(0),
     myLabelLength(8)   // longest pre-defined label
 {
   // Add case sensitive compare for user labels
@@ -160,30 +159,6 @@ void CartDebug::saveOldState()
   }
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CartDebug::triggerReadFromWritePort(uInt16 addr)
-{
-  myRWPortAddress = addr;
-  mySystem.setDirtyPage(addr);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int CartDebug::readFromWritePort()
-{
-  uInt16 addr = myRWPortAddress;
-  myRWPortAddress = 0;
-
-  // A read from the write port occurs when the read is actually in the write
-  // port address space AND the last access was actually a read (the latter
-  // differentiates between reads that are normally part of a write cycle vs.
-  // ones that are illegal)
-  if(mySystem.m6502().lastReadAddress() &&
-      (mySystem.getPageAccessType(addr) & System::PA_WRITE) == System::PA_WRITE)
-    return addr;
-  else
-    return 0;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int CartDebug::lastReadBaseAddress()
 {
@@ -462,7 +437,7 @@ bool CartDebug::addDirective(CartDebug::DisasmType type,
       i->end = tag.start - 1;
 
       // Insert new endpoint
-      i++;
+      ++i;
       list.insert(i, tag2);
       break;  // no need to go further; this is the insertion point
     }
@@ -735,7 +710,7 @@ string CartDebug::loadListFile()
 
     getline(in, line);
 
-    if(line.length() == 0 || line[0] == '-')
+    if(!in.good() || line == "" || line[0] == '-')
       continue;
     else  // Search for constants
     {
@@ -798,6 +773,7 @@ string CartDebug::loadSymbolFile()
     int value = -1;
 
     getline(in, label);
+    if(!in.good())  continue;
     stringstream buf(label);
     buf >> label >> hex >> value;
 
@@ -1100,10 +1076,9 @@ string CartDebug::saveDisassembly()
   }
 
   // Some boilerplate, similar to what DiStella adds
-  time_t currtime;
-  time(&currtime);
+  auto timeinfo = BSPF::localTime();
   out << "; Disassembly of " << myOSystem.romFile().getShortPath() << "\n"
-      << "; Disassembled " << ctime(&currtime)
+      << "; Disassembled " << std::put_time(&timeinfo, "%c\n")
       << "; Using Stella " << STELLA_VERSION << "\n;\n"
       << "; ROM properties name : " << myConsole.properties().get(Cartridge_Name) << "\n"
       << "; ROM properties MD5  : " << myConsole.properties().get(Cartridge_MD5) << "\n"
@@ -1181,10 +1156,10 @@ string CartDebug::saveDisassembly()
           out << "\n";
         out << ALIGN(16) << ourZPMnemonic[addr - 0x80] << "= $"
           << Base::HEX2 << right << (addr)
-          << (stackUsed|codeUsed ? "; (" : "")
+          << ((stackUsed|codeUsed) ? "; (" : "")
           << (codeUsed ? "c" : "")
           << (stackUsed ? "s" : "")
-          << (stackUsed | codeUsed ? ")" : "")
+          << ((stackUsed | codeUsed) ? ")" : "")
           << "\n";
         addLine = false;
       } else if (ramUsed|codeUsed|stackUsed) {
@@ -1291,7 +1266,7 @@ string CartDebug::clearConfig(int bank)
     endbank = startbank + 1;
   }
 
-  uInt32 count = 0;
+  size_t count = 0;
   for(uInt32 b = startbank; b < endbank; ++b)
   {
     count += myBankInfo[b].directiveList.size();
