@@ -54,6 +54,7 @@
 
 #include "TIA.hxx"
 #include "Debugger.hxx"
+#include "DispatchResult.hxx"
 
 Debugger* Debugger::myStaticDebugger = nullptr;
 
@@ -155,7 +156,10 @@ void Debugger::quit(bool exitrom)
   if(exitrom)
     myOSystem.eventHandler().handleEvent(Event::LauncherMode, 1);
   else
+  {
     myOSystem.eventHandler().leaveDebugMode();
+    myOSystem.console().tia().clearPendingFrame();
+  }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -511,9 +515,12 @@ void Debugger::nextFrame(int frames)
   saveOldState();
 
   unlockSystem();
+  DispatchResult dispatchResult;
   while(frames)
   {
-    myOSystem.console().tia().update();
+    do
+      myOSystem.console().tia().update(dispatchResult, myOSystem.console().emulationTiming().maxCyclesPerTimeslice());
+    while (dispatchResult.getStatus() == DispatchResult::Status::debugger);
     --frames;
   }
   lockSystem();
@@ -711,14 +718,14 @@ const FunctionDefMap Debugger::getFunctionDefMap() const
 string Debugger::builtinHelp() const
 {
   ostringstream buf;
-  uInt16 len, c_maxlen = 0, i_maxlen = 0;
+  uInt32 len, c_maxlen = 0, i_maxlen = 0;
 
   // Get column widths for aligned output (functions)
   for(uInt32 i = 0; i < NUM_BUILTIN_FUNCS; ++i)
   {
-    len = ourBuiltinFunctions[i].name.size();
+    len = uInt32(ourBuiltinFunctions[i].name.size());
     if(len > c_maxlen)  c_maxlen = len;
-    len = ourBuiltinFunctions[i].defn.size();
+    len = uInt32(ourBuiltinFunctions[i].defn.size());
     if(len > i_maxlen)  i_maxlen = len;
   }
 
@@ -737,7 +744,7 @@ string Debugger::builtinHelp() const
   c_maxlen = 0;
   for(uInt32 i = 0; i < NUM_PSEUDO_REGS; ++i)
   {
-    len = ourPseudoRegisters[i].name.size();
+    len = uInt32(ourPseudoRegisters[i].name.size());
     if(len > c_maxlen)  c_maxlen = len;
   }
 
@@ -786,6 +793,12 @@ void Debugger::unlockSystem()
   myConsole.cartridge().unlockBank();
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool Debugger::canExit() const
+{
+  return !myDialogStack.empty() && myDialogStack.top() == baseDialog();
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Debugger::BuiltinFunction Debugger::ourBuiltinFunctions[NUM_BUILTIN_FUNCS] = {
   // left joystick:
@@ -823,7 +836,6 @@ Debugger::PseudoRegister Debugger::ourPseudoRegisters[NUM_PSEUDO_REGS] = {
   { "_fcount",    "Number of frames since emulation started" },
   { "_fcycles",   "Number of cycles since frame started" },
   { "_icycles",    "Number of cycles of last instruction" },
-  { "_rwport",    "Address at which a read from a write port occurred" },
   { "_scan",      "Current scanline count" },
   { "_scycles",   "Number of cycles in current scanline" },
   { "_vblank",    "Whether vertical blank is enabled (1 or 0)" },
