@@ -66,6 +66,7 @@ const DebuggerState& RiotDebug::getState()
   myState.TIMINT    = timint();
   myState.TIMCLKS   = timClocks();
   myState.INTIMCLKS = intimClocks();
+  myState.TIMDIV    = timDivider();
 
   return myState;
 }
@@ -107,6 +108,7 @@ void RiotDebug::saveOldState()
   myOldState.TIMINT    = timint();
   myOldState.TIMCLKS   = timClocks();
   myOldState.INTIMCLKS = intimClocks();
+  myOldState.TIMDIV    = timDivider();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -223,6 +225,12 @@ Int32 RiotDebug::intimClocks() const
   return mySystem.m6532().intimClocks();
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+Int32 RiotDebug::timDivider() const
+{
+  return mySystem.m6532().myDivider;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Controller& RiotDebug::controller(Controller::Jack jack) const
 {
@@ -285,10 +293,10 @@ string RiotDebug::dirP0String()
 {
   uInt8 reg = swcha();
   ostringstream buf;
-  buf << (reg & 0x80 ? "" : "right ")
-      << (reg & 0x40 ? "" : "left ")
-      << (reg & 0x20 ? "" : "left ")
-      << (reg & 0x10 ? "" : "left ")
+  buf << ((reg & 0x80) ? "" : "right ")
+      << ((reg & 0x40) ? "" : "left ")
+      << ((reg & 0x20) ? "" : "left ")
+      << ((reg & 0x10) ? "" : "left ")
       << ((reg & 0xf0) == 0xf0 ? "(no directions) " : "");
   return buf.str();
 }
@@ -298,10 +306,10 @@ string RiotDebug::dirP1String()
 {
   uInt8 reg = swcha();
   ostringstream buf;
-  buf << (reg & 0x08 ? "" : "right ")
-      << (reg & 0x04 ? "" : "left ")
-      << (reg & 0x02 ? "" : "left ")
-      << (reg & 0x01 ? "" : "left ")
+  buf << ((reg & 0x08) ? "" : "right ")
+      << ((reg & 0x04) ? "" : "left ")
+      << ((reg & 0x02) ? "" : "left ")
+      << ((reg & 0x01) ? "" : "left ")
       << ((reg & 0x0f) == 0x0f ? "(no directions) " : "");
   return buf.str();
 }
@@ -328,8 +336,8 @@ string RiotDebug::tvTypeString()
 string RiotDebug::switchesString()
 {
   ostringstream buf;
-  buf << (swchb() & 0x2 ? "-" : "+") << "select "
-      << (swchb() & 0x1 ? "-" : "+") << "reset";
+  buf << ((swchb() & 0x2) ? "-" : "+") << "select "
+      << ((swchb() & 0x1) ? "-" : "+") << "reset";
   return buf.str();
 }
 
@@ -362,6 +370,7 @@ string RiotDebug::toString()
       << " 285/TIMINT=" << myDebugger.invIfChanged(state.TIMINT, oldstate.TIMINT)
       << " Timer_Clocks=" << myDebugger.invIfChanged(state.TIMCLKS, oldstate.TIMCLKS)
       << " INTIM_Clocks=" << myDebugger.invIfChanged(state.INTIMCLKS, oldstate.INTIMCLKS)
+      << " Divider=" << myDebugger.invIfChanged(state.TIMDIV, oldstate.TIMDIV)
       << endl
 
       << "Left/P0diff: " << diffP0String() << "   Right/P1diff: " << diffP0String()
