@@ -35,7 +35,7 @@ CartridgeCVPlusWidget::CartridgeCVPlusWidget(
        << "1024 bytes RAM @ $F000 - $F7FF\n"
        << "  $F000 - $F3FF (R), $F400 - $F7FF (W)\n"
        << "2048 bytes ROM @ $F800 - $FFFF, by writing to $3D\n"
-       << "Startup bank = " << cart.myStartBank << "\n";
+       << "Startup bank = " << cart.startBank() << "\n";
 
   int xpos = 10,
       ypos = addBaseInformation(size, "LS_Dracon / Stephen Anthony",
@@ -90,7 +90,8 @@ string CartridgeCVPlusWidget::bankState()
 void CartridgeCVPlusWidget::saveOldState()
 {
   myOldState.internalram.clear();
-  for(uInt32 i = 0; i < this->internalRamSize();i++)
+
+  for(uInt32 i = 0; i < internalRamSize(); ++i)
     myOldState.internalram.push_back(myCart.myRAM[i]);
 
   myOldState.bank = myCart.getBank();
