@@ -46,7 +46,8 @@ CartridgeCVWidget::CartridgeCVWidget(
 void CartridgeCVWidget::saveOldState()
 {
   myOldState.internalram.clear();
-  for(uInt32 i = 0; i < this->internalRamSize();i++)
+
+  for(uInt32 i = 0; i < internalRamSize(); ++i)
     myOldState.internalram.push_back(myCart.myRAM[i]);
 }
 
