@@ -45,6 +45,7 @@
 #include "ConsoleMediumBFont.hxx"
 #include "StellaMediumFont.hxx"
 #include "OptionsDialog.hxx"
+#include "StateManager.hxx"
 #include "DebuggerDialog.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -117,6 +118,64 @@ void DebuggerDialog::handleKeyDown(StellaKey key, StellaMod mod)
       case KBDK_UP:  // Alt-up rewinds to end of list
         doUnwindAll();
         return;
+
+      case KBDK_Z:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleP0Collision();
+        else
+          instance().console().toggleP0Bit();
+        return;
+
+      case KBDK_X:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleP1Collision();
+        else
+          instance().console().toggleP1Bit();
+        return;
+
+      case KBDK_C:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleM0Collision();
+        else
+          instance().console().toggleM0Bit();
+        return;
+
+      case KBDK_V:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleM1Collision();
+        else
+          instance().console().toggleM1Bit();
+        return;
+
+      case KBDK_B:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleBLCollision();
+        else
+          instance().console().toggleBLBit();
+        return;
+
+      case KBDK_N:
+        if(StellaModTest::isShift(mod))
+          instance().console().togglePFCollision();
+        else
+          instance().console().togglePFBit();
+        return;
+
+      case KBDK_COMMA:
+        instance().console().toggleFixedColors();
+        return;
+
+      case KBDK_PERIOD:
+        if(StellaModTest::isShift(mod))
+          instance().console().toggleCollisions();
+        else
+          instance().console().toggleBits();
+        return;
+
+      case KBDK_T:  // Alt-t toggles Time Machine
+        instance().state().toggleTimeMachine();
+        break;
+
       default:
         break;
     }
@@ -221,72 +280,84 @@ void DebuggerDialog::handleCommand(CommandSender* sender, int cmd,
 void DebuggerDialog::doStep()
 {
   instance().debugger().parser().run("step");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doTrace()
 {
   instance().debugger().parser().run("trace");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doAdvance()
 {
   instance().debugger().parser().run("frame #1");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doScanlineAdvance()
 {
   instance().debugger().parser().run("scanline #1");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doRewind()
 {
   instance().debugger().parser().run("rewind");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doUnwind()
 {
   instance().debugger().parser().run("unwind");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doRewind10()
 {
   instance().debugger().parser().run("rewind #10");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doUnwind10()
 {
   instance().debugger().parser().run("unwind #10");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doRewindAll()
 {
   instance().debugger().parser().run("rewind #1000");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doUnwindAll()
 {
   instance().debugger().parser().run("unwind #1000");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doExitDebugger()
 {
   instance().debugger().parser().run("run");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::doExitRom()
 {
   instance().debugger().parser().run("exitrom");
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -351,7 +422,7 @@ void DebuggerDialog::createFont()
 void DebuggerDialog::showFatalMessage(const string& msg)
 {
   myFatalError = make_unique<GUI::MessageBox>(this, *myLFont, msg, _w/2, _h/2,
-                          kDDExitFatalCmd, "Exit ROM", "Continue");
+                          kDDExitFatalCmd, "Exit ROM", "Continue", "Fatal error");
   myFatalError->show();
 }
 
@@ -382,15 +453,9 @@ void DebuggerDialog::addTabArea()
   int tabID;
 
   // The Prompt/console tab
-#ifndef FLAT_UI
-  tabID = myTab->addTab(" Prompt ");
-  myPrompt = new PromptWidget(myTab, *myNFont,
-                              2, 2, widWidth, widHeight);
-#else
   tabID = myTab->addTab("Prompt");
   myPrompt = new PromptWidget(myTab, *myNFont,
                               2, 2, widWidth - 4, widHeight);
-#endif
   myTab->setParentWidget(tabID, myPrompt);
   addToFocusList(myPrompt->getFocusList(), myTab, tabID);
 
@@ -476,25 +541,32 @@ void DebuggerDialog::addRomArea()
 
   const GUI::Rect& r = getRomBounds();
   const int VBORDER = 4;
-  const string ELLIPSIS = "\x1d";
+  WidgetArray wid1, wid2;
+  ButtonWidget* b;
 
   int bwidth  = myLFont->getStringWidth("Frame +1 "),
       bheight = myLFont->getLineHeight() + 2;
   int buttonX = r.right - bwidth - 5, buttonY = r.top + 5;
-  new ButtonWidget(this, *myLFont, buttonX, buttonY,
-                   bwidth, bheight, "Step", kDDStepCmd);
+
+  b = new ButtonWidget(this, *myLFont, buttonX, buttonY,
+                       bwidth, bheight, "Step", kDDStepCmd);
+  wid2.push_back(b);
   buttonY += bheight + 4;
-  new ButtonWidget(this, *myLFont, buttonX, buttonY,
-                   bwidth, bheight, "Trace", kDDTraceCmd);
+  b = new ButtonWidget(this, *myLFont, buttonX, buttonY,
+                       bwidth, bheight, "Trace", kDDTraceCmd);
+  wid2.push_back(b);
   buttonY += bheight + 4;
-  new ButtonWidget(this, *myLFont, buttonX, buttonY,
-                   bwidth, bheight, "Scan +1", kDDSAdvCmd);
+  b = new ButtonWidget(this, *myLFont, buttonX, buttonY,
+                       bwidth, bheight, "Scan +1", kDDSAdvCmd);
+  wid2.push_back(b);
   buttonY += bheight + 4;
-  new ButtonWidget(this, *myLFont, buttonX, buttonY,
-                   bwidth, bheight, "Frame +1", kDDAdvCmd);
+  b = new ButtonWidget(this, *myLFont, buttonX, buttonY,
+                       bwidth, bheight, "Frame +1", kDDAdvCmd);
+  wid2.push_back(b);
   buttonY += bheight + 4;
-  new ButtonWidget(this, *myLFont, buttonX, buttonY,
-                   bwidth, bheight, "Exit", kDDExitCmd);
+  b = new ButtonWidget(this, *myLFont, buttonX, buttonY,
+                       bwidth, bheight, "Exit", kDDExitCmd);
+  wid2.push_back(b);
 
   bwidth = bheight; // 7 + 12;
   bheight = bheight * 3 + 4 * 2;
@@ -504,7 +576,6 @@ void DebuggerDialog::addRomArea()
   myRewindButton =
     new ButtonWidget(this, *myLFont, buttonX, buttonY,
                      bwidth, bheight, LEFT_ARROW, 7, 11, kDDRewindCmd);
-
   myRewindButton->clearFlags(WIDGET_ENABLED);
 
   buttonY += bheight + 4;
@@ -520,7 +591,11 @@ void DebuggerDialog::addRomArea()
   bwidth = myLFont->getStringWidth("Options " + ELLIPSIS);
   bheight = myLFont->getLineHeight() + 2;
 
-  new ButtonWidget(this, *myLFont, xpos, r.top + 5, bwidth, bheight, "Options" + ELLIPSIS, kDDOptionsCmd);
+  b = new ButtonWidget(this, *myLFont, xpos, r.top + 5, bwidth, bheight,
+                       "Options" + ELLIPSIS, kDDOptionsCmd);
+  wid1.push_back(b);
+  wid1.push_back(myRewindButton);
+  wid1.push_back(myUnwindButton);
 
   DataGridOpsWidget* ops = new DataGridOpsWidget(this, *myLFont, xpos, ypos);
 
@@ -529,6 +604,9 @@ void DebuggerDialog::addRomArea()
   myCpu = new CpuWidget(this, *myLFont, *myNFont, xpos, ypos, max_w);
   addToFocusList(myCpu->getFocusList());
 
+  addToFocusList(wid1);
+  addToFocusList(wid2);
+
   xpos = r.left + 10;  ypos += myCpu->getHeight() + 10;
   myRam = new RiotRamWidget(this, *myLFont, *myNFont, xpos, ypos, r.width() - 10);
   addToFocusList(myRam->getFocusList());
