@@ -90,25 +90,26 @@ void DelayQueueWidget::loadConfig() {
 void DelayQueueWidget::drawWidget(bool hilite)
 {
   FBSurface& surface = _boss->dialog().surface();
+  bool onTop = _boss->dialog().isOnTop();
 
   int y = _y,
       x = _x,
       w = _w,
       lineHeight = _font.getLineHeight();
 
-  surface.frameRect(x, y, w, _h, kShadowColor);
+  surface.frameRect(x, y, w, _h, kColor);
 
   y += 1;
   x += 1;
   w -= 1;
-  surface.fillRect(x, y, w - 1, _h - 2, kBGColorHi);
+  surface.fillRect(x, y, w - 1, _h - 2, onTop ? kDlgColor : _bgcolorlo);
 
   y += 2;
   x += 2;
   w -= 3;
 
   for (const auto& line : myLines) {
-    surface.drawString(_font, line, x, y, w, _textcolor);
+    surface.drawString(_font, line, x, y, w, onTop ? _textcolor : kColor);
     y += lineHeight;
   }
 }
