@@ -22,8 +22,10 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FlashWidget::FlashWidget(GuiObject* boss, const GUI::Font& font,
                          int x, int y, Controller& controller)
-  : ControllerWidget(boss, font, x, y, controller)
+  : ControllerWidget(boss, font, x, y, controller),
+    myEEPROMEraseCurrent(nullptr)
 {
+  std::fill(myPage, myPage + MAX_PAGES, nullptr);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -34,7 +36,7 @@ void FlashWidget::init(GuiObject* boss, const GUI::Font& font, int x, int y)
   int xpos = x, ypos = y;
 
   new StaticTextWidget(boss, font, xpos, ypos + 2, getHeader());
-  
+
   ypos += lineHeight + 6;
 
   new StaticTextWidget(boss, ifont, xpos, ypos, "Pages/Ranges used:");
