@@ -56,7 +56,7 @@ void RiotRamWidget::fillList(uInt32 start, uInt32 size, IntArray& alist,
   const CartState& state    = static_cast<const CartState&>(myDbg.getState());
   const CartState& oldstate = static_cast<const CartState&>(myDbg.getOldState());
 
-  for(uInt32 i = 0; i < size; i++)
+  for(uInt32 i = 0; i < size; ++i)
   {
     alist.push_back(i+start);
     vlist.push_back(state.ram[i]);
