@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -16,8 +16,8 @@
 //============================================================================
 
 #include "Base.hxx"
+#include "Font.hxx"
 #include "OSystem.hxx"
-#include "FrameBuffer.hxx"
 #include "Debugger.hxx"
 #include "TIADebug.hxx"
 #include "Widget.hxx"
@@ -44,7 +44,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
   // Add frame info
   new StaticTextWidget(boss, lfont, xpos, ypos, lwidth, lineHeight,
                        longstr ? "Frame Count " : "Frame ",
-                       kTextAlignLeft);
+                       TextAlign::Left);
   xpos += lwidth;
   myFrameCount = new EditTextWidget(boss, nfont, xpos, ypos-1, fwidth, lineHeight, "");
   myFrameCount->setEditable(false, true);
@@ -52,7 +52,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
   xpos = x;  ypos += lineHeight + 5;
   new StaticTextWidget(boss, lfont, xpos, ypos, lwidth, lineHeight,
                        longstr ? "Frame Cycle " : "F. Cycle ",
-                       kTextAlignLeft);
+                       TextAlign::Left);
   xpos += lwidth;
   myFrameCycles = new EditTextWidget(boss, nfont, xpos, ypos-1, fwidth, lineHeight, "");
   myFrameCycles->setEditable(false, true);
@@ -71,7 +71,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
 
   new StaticTextWidget(boss, lfont, xpos, ypos,
     lfont.getStringWidth(longstr ? "Scanline" : "Scn Ln"), lineHeight,
-    longstr ? "Scanline" : "Scn Ln", kTextAlignLeft);
+    longstr ? "Scanline" : "Scn Ln", TextAlign::Left);
 
   myScanlineCountLast = new EditTextWidget(boss, nfont, xpos+lwidth, ypos-1, fwidth,
                                        lineHeight, "");
@@ -84,7 +84,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
 
   ypos += lineHeight + 5;
   new StaticTextWidget(boss, lfont, xpos, ypos, lwidth, lineHeight,
-                       longstr ? "Scan Cycle " : "Scn Cycle", kTextAlignLeft);
+                       longstr ? "Scan Cycle " : "Scn Cycle", TextAlign::Left);
 
   myScanlineCycles = new EditTextWidget(boss, nfont, xpos+lwidth, ypos-1, fwidth,
                                         lineHeight, "");
@@ -92,7 +92,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
 
   ypos += lineHeight + 5;
   new StaticTextWidget(boss, lfont, xpos, ypos, lwidth, lineHeight,
-                       "Pixel Pos ", kTextAlignLeft);
+                       "Pixel Pos ", TextAlign::Left);
 
   myPixelPosition = new EditTextWidget(boss, nfont, xpos+lwidth, ypos-1, fwidth,
                                        lineHeight, "");
@@ -100,7 +100,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
 
   ypos += lineHeight + 5;
   new StaticTextWidget(boss, lfont, xpos, ypos, lwidth, lineHeight,
-                       longstr ? "Color Clock " : "Color Clk ", kTextAlignLeft);
+                       longstr ? "Color Clock " : "Color Clk ", TextAlign::Left);
 
   myColorClocks = new EditTextWidget(boss, nfont, xpos+lwidth, ypos-1, fwidth,
                                      lineHeight, "");
@@ -112,7 +112,7 @@ TiaInfoWidget::TiaInfoWidget(GuiObject* boss, const GUI::Font& lfont,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TiaInfoWidget::handleMouseDown(int x, int y, int button, int clickCount)
+void TiaInfoWidget::handleMouseDown(int x, int y, MouseButton b, int clickCount)
 {
 //cerr << "TiaInfoWidget button press: x = " << x << ", y = " << y << endl;
 }
@@ -127,19 +127,26 @@ void TiaInfoWidget::loadConfig()
 {
   Debugger& dbg = instance().debugger();
   TIADebug& tia = dbg.tiaDebug();
+  const TiaState& oldTia = static_cast<const TiaState&>(tia.getOldState());
 
-  myFrameCount->setText(Common::Base::toString(tia.frameCount(), Common::Base::F_10));
-  myFrameCycles->setText(Common::Base::toString(dbg.cycles(), Common::Base::F_10));
+  myFrameCount->setText("  " + Common::Base::toString(tia.frameCount(), Common::Base::F_10),
+                        tia.frameCount() != oldTia.info[0]);
+  myFrameCycles->setText("  " + Common::Base::toString(tia.frameCycles(), Common::Base::F_10),
+                         tia.frameCycles() != oldTia.info[1]);
 
-  myVSync->setState(tia.vsync());
-  myVBlank->setState(tia.vblank());
+  myVSync->setState(tia.vsync(), tia.vsyncAsInt() != oldTia.info[2]);
+  myVBlank->setState(tia.vblank(), tia.vblankAsInt() != oldTia.info[3]);
 
   int clk = tia.clocksThisLine();
-  myScanlineCount->setText(
-      Common::Base::toString(tia.scanlines(), Common::Base::F_10));
+  myScanlineCount->setText(Common::Base::toString(tia.scanlines(), Common::Base::F_10),
+                           tia.scanlines() != oldTia.info[4]);
   myScanlineCountLast->setText(
-      Common::Base::toString(tia.scanlinesLastFrame(), Common::Base::F_10));
-  myScanlineCycles->setText(Common::Base::toString(clk/3, Common::Base::F_10));
-  myPixelPosition->setText(Common::Base::toString(clk-68, Common::Base::F_10));
-  myColorClocks->setText(Common::Base::toString(clk, Common::Base::F_10));
+    Common::Base::toString(tia.scanlinesLastFrame(), Common::Base::F_10),
+    tia.scanlinesLastFrame() != oldTia.info[5]);
+  myScanlineCycles->setText(Common::Base::toString(clk/3, Common::Base::F_10),
+                            clk != oldTia.info[6]);
+  myPixelPosition->setText(Common::Base::toString(clk-68, Common::Base::F_10),
+                           clk != oldTia.info[6]);
+  myColorClocks->setText(Common::Base::toString(clk, Common::Base::F_10),
+                         clk != oldTia.info[6]);
 }
