@@ -119,9 +119,10 @@ void TiaOutputWidget::handleCommand(CommandSender* sender, int cmd, int data, in
       if(rmb == "scanline")
       {
         ostringstream command;
-        int lines = myClickY + ystart;
-        if(instance().console().tia().isRendering())
-          lines -= instance().console().tia().scanlines();
+        int lines = myClickY + ystart - instance().console().tia().scanlines();
+
+        if(lines < 0)
+          lines += instance().console().tia().scanlinesLastFrame();
         if(lines > 0)
         {
           command << "scanline #" << lines;
@@ -168,6 +169,8 @@ void TiaOutputWidget::drawWidget(bool hilite)
   uInt32 scanx, scany, scanoffset;
   bool visible = instance().console().tia().electronBeamPos(scanx, scany);
   scanoffset = width * scany + scanx;
+  uInt8* tiaOutputBuffer = instance().console().tia().outputBuffer();
+  TIASurface& tiaSurface(instance().frameBuffer().tiaSurface());
 
   for(uInt32 y = 0, i = 0; y < height; ++y)
   {
@@ -175,7 +178,7 @@ void TiaOutputWidget::drawWidget(bool hilite)
     for(uInt32 x = 0; x < width; ++x, ++i)
     {
       uInt8 shift = i >= scanoffset ? 1 : 0;
-      uInt32 pixel = instance().frameBuffer().tiaSurface().pixel(i, shift);
+      uInt32 pixel = tiaSurface.mapIndexedPixel(tiaOutputBuffer[i], shift);
       *line_ptr++ = pixel;
       *line_ptr++ = pixel;
     }
