@@ -30,6 +30,7 @@ ToggleBitWidget::ToggleBitWidget(GuiObject* boss, const GUI::Font& font,
 {
   _rowHeight = font.getLineHeight();
   _colWidth  = colchars * font.getMaxCharWidth() + 8;
+  _bgcolorlo = kDlgColor;
 
   // Make sure all lists contain some default values
   int size = _rows * _cols;
@@ -73,33 +74,27 @@ void ToggleBitWidget::drawWidget(bool hilite)
 {
 //cerr << "ToggleBitWidget::drawWidget\n";
   FBSurface& s = dialog().surface();
+  bool onTop = _boss->dialog().isOnTop();
   int row, col;
   string buffer;
 
+  s.frameRect(_x, _y, _w, _h, hilite && isEnabled() && isEditable() ? kWidColorHi : kColor);
+
   // Draw the internal grid and labels
   int linewidth = _cols * _colWidth;
-#ifndef FLAT_UI
-  for (row = 0; row <= _rows; row++)
-    s.hLine(_x, _y + (row * _rowHeight), _x + linewidth, kColor);
-  int lineheight = _rows * _rowHeight;
-  for (col = 0; col <= _cols; col++)
-    s.vLine(_x + (col * _colWidth), _y, _y + lineheight, kColor);
-#else
-  s.frameRect(_x, _y, _w, _h, kColor);
   for(row = 1; row <= _rows - 1; row++)
     s.hLine(_x + 1, _y + (row * _rowHeight), _x + linewidth - 1, kBGColorLo);
 
   int lineheight = _rows * _rowHeight;
   for(col = 1; col <= _cols - 1; col++)
     s.vLine(_x + (col * _colWidth), _y + 1, _y + lineheight - 1, kBGColorLo);
-#endif
 
   // Draw the list items
   for (row = 0; row < _rows; row++)
   {
     for (col = 0; col < _cols; col++)
     {
-      uInt32 textColor = kTextColor;
+      ColorId textColor = kTextColor;
       int x = _x + 4 + (col * _colWidth);
       int y = _y + 2 + (row * _rowHeight);
       int pos = row*_cols + col;
@@ -121,16 +116,18 @@ void ToggleBitWidget::drawWidget(bool hilite)
         // Highlight changes
         if(_changedList[pos])
         {
-          s.fillRect(x - 3, y - 1, _colWidth-1, _rowHeight-1, kDbgChangedColor);
-          s.drawString(_font, buffer, x, y, _colWidth, kDbgChangedTextColor);
+          s.fillRect(x - 3, y - 1, _colWidth-1, _rowHeight-1,
+                     onTop ? kDbgChangedColor : _bgcolorlo);
+          s.drawString(_font, buffer, x, y, _colWidth, onTop ? kDbgChangedTextColor : kColor);
         }
         else
-          s.drawString(_font, buffer, x, y, _colWidth, textColor);
+          s.drawString(_font, buffer, x, y, _colWidth,
+                       onTop ? textColor : kColor);
       }
       else
       {
-        s.fillRect(x - 3, y - 1, _colWidth-1, _rowHeight-1, kBGColorHi);
-        s.drawString(_font, buffer, x, y, _colWidth, kTextColor);
+        s.fillRect(x - 3, y - 1, _colWidth-1, _rowHeight-1, onTop ? kBGColorHi : kDlgColor);
+        s.drawString(_font, buffer, x, y, _colWidth, onTop ? kTextColor : kColor);
       }
     }
   }
