@@ -26,7 +26,7 @@
 TogglePixelWidget::TogglePixelWidget(GuiObject* boss, const GUI::Font& font,
                                      int x, int y, int cols, int rows)
   : ToggleWidget(boss, font, x, y, cols, rows, 1),
-    _pixelColor(0),
+    _pixelColor(kNone),
     _backgroundColor(kDlgColor),
     _swapBits(false),
     _crossBits(false)
@@ -121,14 +121,17 @@ void TogglePixelWidget::drawWidget(bool hilite)
 {
 //cerr << "TogglePixelWidget::drawWidget\n";
   FBSurface& s = dialog().surface();
+  bool onTop = _boss->dialog().isOnTop();
   int row, col;
 
+  s.frameRect(_x, _y, _w, _h, hilite && isEnabled() && isEditable() ? kWidColorHi : kColor);
+
   // Draw the internal grid and labels
   int linewidth = _cols * _colWidth;
-  for (row = 0; row <= _rows; row++)
+  for (row = 1; row <= _rows - 1; row++)
     s.hLine(_x, _y + (row * _rowHeight), _x + linewidth, kColor);
   int lineheight = _rows * _rowHeight;
-  for (col = 0; col <= _cols; col++)
+  for (col = 1; col <= _cols - 1; col++)
     s.vLine(_x + (col * _colWidth), _y, _y + lineheight, kColor);
 
   // Draw the pixels
@@ -146,7 +149,7 @@ void TogglePixelWidget::drawWidget(bool hilite)
 
       // Either draw the pixel in given color, or erase (show background)
       s.fillRect(x - 3, y - 1, _colWidth-1, _rowHeight-1,
-                 _stateList[pos] ? _pixelColor : _backgroundColor);
+                 _stateList[pos] ? onTop ? _pixelColor : kColor : onTop ? _backgroundColor : kBGColorLo);
       if (_changedList[pos])
         s.frameRect(x - 3, y - 1, _colWidth - 1, _rowHeight - 1, kDbgChangedColor);
     }
@@ -155,10 +158,6 @@ void TogglePixelWidget::drawWidget(bool hilite)
   // Cross out the bits?
   if(_crossBits)
   {
-#ifndef FLAT_UI
-    for(row = 1; row < 4; ++row)
-      s.hLine(_x, _y + (row * lineheight / 4), _x + linewidth, kColor);
-#else
     for(col = 0; col < _cols; ++col)
     {
       int x = _x + col * _colWidth;
@@ -166,6 +165,5 @@ void TogglePixelWidget::drawWidget(bool hilite)
       s.line(x + 1, _y + 1, x + _colWidth - 1, _y + lineheight - 1, kColor);
       s.line(x + _colWidth - 1, _y + 1, x + 1, _y + lineheight - 1, kColor);
     }
-#endif
   }
 }
