@@ -21,8 +21,8 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Cartridge3E::Cartridge3E(const BytePtr& image, uInt32 size,
-                         const Settings& settings)
-  : Cartridge(settings),
+                         const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
     mySize(size),
     myCurrentBank(0)
 {
@@ -32,18 +32,16 @@ Cartridge3E::Cartridge3E(const BytePtr& image, uInt32 size,
   // Copy the ROM image into my buffer
   memcpy(myImage.get(), image.get(), mySize);
   createCodeAccessBase(mySize + 32768);
-
-  // Remember startup bank
-  myStartBank = 0;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Cartridge3E::reset()
 {
   initializeRAM(myRAM, 32768);
+  initializeStartBank(0);
 
   // We'll map the startup bank into the first segment upon reset
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -67,7 +65,7 @@ void Cartridge3E::install(System& system)
   }
 
   // Install pages for the startup bank into the first segment
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -87,15 +85,7 @@ uInt8 Cartridge3E::peek(uInt16 address)
       else
       {
         // Reading from the write port triggers an unwanted write
-        uInt8 value = mySystem->getDataBusState(0xFF);
-
-        if(bankLocked())
-          return value;
-        else
-        {
-          triggerReadFromWritePort(peekAddress);
-          return myRAM[(address & 0x03FF) + ((myCurrentBank - 256) << 10)] = value;
-        }
+        return peekRAM(myRAM[(address & 0x03FF) + ((myCurrentBank - 256) << 10)], peekAddress);
       }
     }
   }
@@ -108,23 +98,24 @@ uInt8 Cartridge3E::peek(uInt16 address)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Cartridge3E::poke(uInt16 address, uInt8 value)
 {
+  uInt16 pokeAddress = address;
   address &= 0x0FFF;
 
   // Switch banks if necessary. Armin (Kroko) says there are no mirrored
   // hotspots.
-  if(address == 0x003F)
+  if(address < 0x0040)
   {
-    bank(value);
-  }
-  else if(address == 0x003E)
-  {
-    bank(value + 256);
-  }
+    if(address == 0x003F)
+      bank(value);
+    else if(address == 0x003E)
+      bank(value + 256);
 
-  // Handle TIA space that we claimed above
-  mySystem->tia().poke(address, value);
+    return mySystem->tia().poke(address, value);
+  }
+  else
+    pokeRAM(myRAM[(address & 0x03FF) + ((myCurrentBank - 256) << 10)], pokeAddress, value);
 
-  return false;
+  return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -182,9 +173,10 @@ bool Cartridge3E::bank(uInt16 bank)
     access.type = System::PA_WRITE;
 
     // Map write-port RAM image into the system
+    // Map access to this class, since we need to inspect all accesses to
+    // check if RWP happens
     for(uInt16 addr = 0x1400; addr < 0x1800; addr += System::PAGE_SIZE)
     {
-      access.directPokeBase = &myRAM[offset + (addr & 0x03FF)];
       access.codeAccessBase = &myCodeAccessBase[mySize + offset + (addr & 0x03FF)];
       mySystem->setPageAccess(addr, access);
     }
@@ -239,7 +231,6 @@ bool Cartridge3E::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
     out.putShort(myCurrentBank);
     out.putByteArray(myRAM, 32768);
   }
@@ -257,9 +248,6 @@ bool Cartridge3E::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     myCurrentBank = in.getShort();
     in.getByteArray(myRAM, 32768);
   }
