@@ -22,8 +22,8 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Cartridge4A50::Cartridge4A50(const BytePtr& image, uInt32 size,
-                             const Settings& settings)
-  : Cartridge(settings),
+                             const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
     mySize(size),
     mySliceLow(0),
     mySliceMiddle(0),
@@ -367,8 +367,6 @@ bool Cartridge4A50::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
     // The 32K bytes of RAM
     out.putByteArray(myRAM, 32768);
 
@@ -400,9 +398,6 @@ bool Cartridge4A50::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     in.getByteArray(myRAM, 32768);
 
     // Index pointers
