@@ -25,6 +25,7 @@
 #include "TIA.hxx"
 #include "Thumbulator.hxx"
 #include "CartBUS.hxx"
+#include "exception/FatalEmulationError.hxx"
 
 // Location of data within the RAM copy of the BUS Driver.
 #define DSxPTR        0x06D8
@@ -41,8 +42,8 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeBUS::CartridgeBUS(const BytePtr& image, uInt32 size,
-                           const Settings& settings)
-  : Cartridge(settings),
+                           const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
     myAudioCycles(0),
     myARMCycles(0),
     myFractionalClocks(0.0)
@@ -64,9 +65,10 @@ CartridgeBUS::CartridgeBUS(const BytePtr& image, uInt32 size,
   myDisplayImage = myBUSRAM + DSRAM;
 
   // Create Thumbulator ARM emulator
+  const string& prefix = settings.getBool("dev.settings") ? "dev." : "plr.";
   myThumbEmulator = make_unique<Thumbulator>(
     reinterpret_cast<uInt16*>(myImage), reinterpret_cast<uInt16*>(myBUSRAM),
-    settings.getBool("thumb.trapfatal"), Thumbulator::ConfigureFor::BUS, this
+    settings.getBool(prefix + "thumb.trapfatal"), Thumbulator::ConfigureFor::BUS, this
   );
 
   setInitialState();
@@ -77,6 +79,9 @@ void CartridgeBUS::reset()
 {
   initializeRAM(myBUSRAM+2048, 8192-2048);
 
+  // BUS always starts in bank 6
+  initializeStartBank(6);
+
   // Update cycles to the current system cycles
   myAudioCycles = myARMCycles = 0;
   myFractionalClocks = 0.0;
@@ -84,7 +89,7 @@ void CartridgeBUS::reset()
   setInitialState();
 
   // Upon reset we switch to the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -96,12 +101,14 @@ void CartridgeBUS::setInitialState()
   for (int i=0; i < 3; ++i)
     myMusicWaveformSize[i] = 27;
 
-  // BUS always starts in bank 6
-  myStartBank = 6;
-
   // Assuming mode starts out with Fast Fetch off and 3-Voice music,
   // need to confirm with Chris
   myMode = 0xFF;
+
+  myBankOffset = myBusOverdriveAddress =
+    mySTYZeroPageAddress = myJMPoperandAddress = 0;
+
+  myFastJumpActive = 0;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -126,7 +133,7 @@ void CartridgeBUS::install(System& system)
   mySystem->m6532().installDelegate(system, *this);
 
   // Install pages for the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -165,11 +172,7 @@ inline void CartridgeBUS::callFunction(uInt8 value)
       catch(const runtime_error& e) {
         if(!mySystem->autodetectMode())
         {
-      #ifdef DEBUGGER_SUPPORT
-          Debugger::debugger().startWithFatalError(e.what());
-      #else
-          cout << e.what() << endl;
-      #endif
+          FatalEmulationError::raise(e.what());
         }
       }
       break;
@@ -206,8 +209,8 @@ uInt8 CartridgeBUS::peek(uInt16 address)
       uInt32 pointer;
       uInt8 value;
 
-      myFastJumpActive--;
-      myJMPoperandAddress++;
+      --myFastJumpActive;
+      ++myJMPoperandAddress;
 
       pointer = getDatastreamPointer(JUMPSTREAM);
       value = myDisplayImage[ pointer >> 20 ];
@@ -540,8 +543,6 @@ bool CartridgeBUS::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
     // Indicates which bank is currently active
     out.putShort(myBankOffset);
 
@@ -583,9 +584,6 @@ bool CartridgeBUS::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     // Indicates which bank is currently active
     myBankOffset = in.getShort();
 
