@@ -25,6 +25,7 @@
 #include "Thumbulator.hxx"
 #include "CartCDF.hxx"
 #include "TIA.hxx"
+#include "exception/FatalEmulationError.hxx"
 
 // Location of data within the RAM copy of the CDF Driver.
 //  Version                   0       1
@@ -42,8 +43,8 @@ const uInt16 WAVEFORM[] = {0x07F0, 0x01B0};
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeCDF::CartridgeCDF(const BytePtr& image, uInt32 size,
-                           const Settings& settings)
-  : Cartridge(settings),
+                           const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
     myAudioCycles(0),
     myARMCycles(0),
     myFractionalClocks(0.0)
@@ -67,9 +68,10 @@ CartridgeCDF::CartridgeCDF(const BytePtr& image, uInt32 size,
   setVersion();
 
   // Create Thumbulator ARM emulator
+  const string& prefix = settings.getBool("dev.settings") ? "dev." : "plr.";
   myThumbEmulator = make_unique<Thumbulator>(
     reinterpret_cast<uInt16*>(myImage), reinterpret_cast<uInt16*>(myCDFRAM),
-    settings.getBool("thumb.trapfatal"), myVersion ?
+    settings.getBool(prefix + "thumb.trapfatal"), myVersion ?
     Thumbulator::ConfigureFor::CDF1 : Thumbulator::ConfigureFor::CDF, this);
 
   setInitialState();
@@ -80,13 +82,16 @@ void CartridgeCDF::reset()
 {
   initializeRAM(myCDFRAM+2048, 8192-2048);
 
+  // CDF always starts in bank 6
+  initializeStartBank(6);
+
   myAudioCycles = myARMCycles = 0;
   myFractionalClocks = 0.0;
 
   setInitialState();
 
   // Upon reset we switch to the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -98,13 +103,11 @@ void CartridgeCDF::setInitialState()
   for (int i=0; i < 3; ++i)
     myMusicWaveformSize[i] = 27;
 
-  // CDF always starts in bank 6
-  myStartBank = 6;
-
   // Assuming mode starts out with Fast Fetch off and 3-Voice music,
   // need to confirm with Chris
   myMode = 0xFF;
 
+  myBankOffset = myLDAimmediateOperandAddress = myJMPoperandAddress = 0;
   myFastJumpActive = 0;
 }
 
@@ -125,7 +128,7 @@ void CartridgeCDF::install(System& system)
     mySystem->setPageAccess(addr, access);
 
   // Install pages for the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -164,11 +167,7 @@ inline void CartridgeCDF::callFunction(uInt8 value)
       catch(const runtime_error& e) {
         if(!mySystem->autodetectMode())
         {
-#ifdef DEBUGGER_SUPPORT
-          Debugger::debugger().startWithFatalError(e.what());
-#else
-          cout << e.what() << endl;
-#endif
+          FatalEmulationError::raise(e.what());
         }
       }
       break;
@@ -194,8 +193,8 @@ uInt8 CartridgeCDF::peek(uInt16 address)
     uInt32 pointer;
     uInt8 value;
 
-    myFastJumpActive--;
-    myJMPoperandAddress++;
+    --myFastJumpActive;
+    ++myJMPoperandAddress;
 
     pointer = getDatastreamPointer(JUMPSTREAM);
     value = myDisplayImage[ pointer >> 20 ];
@@ -476,8 +475,6 @@ bool CartridgeCDF::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
     // Indicates which bank is currently active
     out.putShort(myBankOffset);
 
@@ -518,9 +515,6 @@ bool CartridgeCDF::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     // Indicates which bank is currently active
     myBankOffset = in.getShort();
 
