@@ -22,11 +22,13 @@
 #include "Thumbulator.hxx"
 #include "CartDPCPlus.hxx"
 #include "TIA.hxx"
+#include "exception/FatalEmulationError.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeDPCPlus::CartridgeDPCPlus(const BytePtr& image, uInt32 size,
-                                   const Settings& settings)
-  : Cartridge(settings),
+                                   const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
+    mySize(std::min(size, 32768u)),
     myFastFetch(false),
     myLDAimmediate(false),
     myParameterPointer(0),
@@ -37,7 +39,6 @@ CartridgeDPCPlus::CartridgeDPCPlus(const BytePtr& image, uInt32 size,
 {
   // Image is always 32K, but in the case of ROM > 29K, the image is
   // copied to the end of the buffer
-  mySize = std::min(size, 32768u);
   if(mySize < 32768u)
     memset(myImage, 0, 32768);
   memcpy(myImage + (32768u - mySize), image.get(), size);
@@ -53,17 +54,15 @@ CartridgeDPCPlus::CartridgeDPCPlus(const BytePtr& image, uInt32 size,
   myFrequencyImage = myDisplayImage + 0x1000;
 
   // Create Thumbulator ARM emulator
+  const string& prefix = settings.getBool("dev.settings") ? "dev." : "plr.";
   myThumbEmulator = make_unique<Thumbulator>
       (reinterpret_cast<uInt16*>(myImage),
        reinterpret_cast<uInt16*>(myDPCRAM),
-       settings.getBool("thumb.trapfatal"),
+       settings.getBool(prefix + "thumb.trapfatal"),
        Thumbulator::ConfigureFor::DPCplus,
        this);
 
   setInitialState();
-
-  // DPC+ always starts in bank 5
-  myStartBank = 5;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -74,8 +73,11 @@ void CartridgeDPCPlus::reset()
 
   setInitialState();
 
+  // DPC+ always starts in bank 5
+  initializeStartBank(5);
+
   // Upon reset we switch to the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -89,8 +91,11 @@ void CartridgeDPCPlus::setInitialState()
 
   // Initialize the DPC data fetcher registers
   for(int i = 0; i < 8; ++i)
-    myTops[i] = myBottoms[i] = myCounters[i] = myFractionalIncrements[i] =
+  {
+    myTops[i] = myBottoms[i] = myFractionalIncrements[i] = 0;
     myFractionalCounters[i] = 0;
+    myCounters[i] = 0;
+  }
 
   // Set waveforms to first waveform entry
   myMusicWaveforms[0] = myMusicWaveforms[1] = myMusicWaveforms[2] = 0;
@@ -116,7 +121,7 @@ void CartridgeDPCPlus::install(System& system)
     mySystem->setPageAccess(addr, access);
 
   // Install pages for the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -187,11 +192,7 @@ inline void CartridgeDPCPlus::callFunction(uInt8 value)
       catch(const runtime_error& e) {
         if(!mySystem->autodetectMode())
         {
-      #ifdef DEBUGGER_SUPPORT
-          Debugger::debugger().startWithFatalError(e.what());
-      #else
-          cout << e.what() << endl;
-      #endif
+          FatalEmulationError::raise(e.what());
         }
       }
       break;
@@ -629,8 +630,6 @@ bool CartridgeDPCPlus::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
     // Indicates which bank is currently active
     out.putShort(myBankOffset);
 
@@ -692,9 +691,6 @@ bool CartridgeDPCPlus::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     // Indicates which bank is currently active
     myBankOffset = in.getShort();
 
