@@ -26,6 +26,8 @@
 #include "Cart4K.hxx"
 #include "Cart4KSC.hxx"
 #include "CartAR.hxx"
+#include "CartBF.hxx"
+#include "CartBFSC.hxx"
 #include "CartBUS.hxx"
 #include "CartCDF.hxx"
 #include "CartCM.hxx"
@@ -33,6 +35,8 @@
 #include "CartCV.hxx"
 #include "CartCVPlus.hxx"
 #include "CartDASH.hxx"
+#include "CartDF.hxx"
+#include "CartDFSC.hxx"
 #include "CartDPC.hxx"
 #include "CartDPCPlus.hxx"
 #include "CartE0.hxx"
@@ -40,10 +44,6 @@
 #include "CartE78K.hxx"
 #include "CartEF.hxx"
 #include "CartEFSC.hxx"
-#include "CartBF.hxx"
-#include "CartBFSC.hxx"
-#include "CartDF.hxx"
-#include "CartDFSC.hxx"
 #include "CartF0.hxx"
 #include "CartF4.hxx"
 #include "CartF4SC.hxx"
@@ -66,23 +66,30 @@
 #include "CartDetector.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
-    string& md5, const string& propertiesType, const OSystem& osystem)
+unique_ptr<Cartridge> CartDetector::create(const FilesystemNode& file,
+    const BytePtr& image, uInt32 size, string& md5,
+    const string& propertiesType, const OSystem& osystem)
 {
   unique_ptr<Cartridge> cartridge;
-  BSType type = Bankswitch::nameToType(propertiesType),
+  Bankswitch::Type type = Bankswitch::nameToType(propertiesType),
          detectedType = type;
   string id;
 
   // Collect some info about the ROM
   ostringstream buf;
 
+  // First inspect the file extension itself
+  // If a valid type is found, it will override the one passed into this method
+  Bankswitch::Type typeByName = Bankswitch::typeFromExtension(file);
+  if(typeByName != Bankswitch::Type::_AUTO)
+    type = detectedType = typeByName;
+
   // See if we should try to auto-detect the cartridge type
   // If we ask for extended info, always do an autodetect
-  if(type == BSType::_AUTO || osystem.settings().getBool("rominfo"))
+  if(type == Bankswitch::Type::_AUTO || osystem.settings().getBool("rominfo"))
   {
     detectedType = autodetectType(image, size);
-    if(type != BSType::_AUTO && type != detectedType)
+    if(type != Bankswitch::Type::_AUTO && type != detectedType)
       cerr << "Auto-detection not consistent: "
            << Bankswitch::typeToName(type) << ", "
            << Bankswitch::typeToName(detectedType) << endl;
@@ -96,7 +103,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
   // Check for multicart first; if found, get the correct part of the image
   switch(type)
   {
-    case BSType::_2IN1:
+    case Bankswitch::Type::_2IN1:
       // Make sure we have a valid sized image
       if(size == 2*2048 || size == 2*4096 || size == 2*8192 || size == 2*16384)
       {
@@ -109,7 +116,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_4IN1:
+    case Bankswitch::Type::_4IN1:
       // Make sure we have a valid sized image
       if(size == 4*2048 || size == 4*4096 || size == 4*8192)
       {
@@ -122,7 +129,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_8IN1:
+    case Bankswitch::Type::_8IN1:
       // Make sure we have a valid sized image
       if(size == 8*2048 || size == 8*4096 || size == 8*8192)
       {
@@ -135,7 +142,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_16IN1:
+    case Bankswitch::Type::_16IN1:
       // Make sure we have a valid sized image
       if(size == 16*2048 || size == 16*4096 || size == 16*8192)
       {
@@ -148,7 +155,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_32IN1:
+    case Bankswitch::Type::_32IN1:
       // Make sure we have a valid sized image
       if(size == 32*2048 || size == 32*4096)
       {
@@ -161,7 +168,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_64IN1:
+    case Bankswitch::Type::_64IN1:
       // Make sure we have a valid sized image
       if(size == 64*2048 || size == 64*4096)
       {
@@ -174,7 +181,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
                             Bankswitch::typeToName(type) + "'");
       break;
 
-    case BSType::_128IN1:
+    case Bankswitch::Type::_128IN1:
       // Make sure we have a valid sized image
       if(size == 128*2048 || size == 128*4096)
       {
@@ -205,7 +212,7 @@ unique_ptr<Cartridge> CartDetector::create(const BytePtr& image, uInt32 size,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 unique_ptr<Cartridge>
 CartDetector::createFromMultiCart(const BytePtr& image, uInt32& size,
-    uInt32 numroms, string& md5, BSType type, string& id, const OSystem& osystem)
+    uInt32 numroms, string& md5, Bankswitch::Type type, string& id, const OSystem& osystem)
 {
   // Get a piece of the larger image
   uInt32 i = osystem.settings().getInt("romloadcount");
@@ -222,142 +229,142 @@ CartDetector::createFromMultiCart(const BytePtr& image, uInt32& size,
   // Move to the next game the next time this ROM is loaded
   osystem.settings().setValue("romloadcount", (i+1)%numroms);
 
-  if(size <= 2048)       type = BSType::_2K;
-  else if(size == 4096)  type = BSType::_4K;
-  else if(size == 8192)  type = BSType::_F8;
-  else  /* default */    type = BSType::_4K;
+  if(size <= 2048)       type = Bankswitch::Type::_2K;
+  else if(size == 4096)  type = Bankswitch::Type::_4K;
+  else if(size == 8192)  type = Bankswitch::Type::_F8;
+  else  /* default */    type = Bankswitch::Type::_4K;
 
   return createFromImage(slice, size, type, md5, osystem);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 unique_ptr<Cartridge>
-CartDetector::createFromImage(const BytePtr& image, uInt32 size, BSType type,
+CartDetector::createFromImage(const BytePtr& image, uInt32 size, Bankswitch::Type type,
                               const string& md5, const OSystem& osystem)
 {
   // We should know the cart's type by now so let's create it
   switch(type)
   {
-    case BSType::_0840:
-      return make_unique<Cartridge0840>(image, size, osystem.settings());
-    case BSType::_2K:
-      return make_unique<Cartridge2K>(image, size, osystem.settings());
-    case BSType::_3E:
-      return make_unique<Cartridge3E>(image, size, osystem.settings());
-    case BSType::_3EP:
-      return make_unique<Cartridge3EPlus>(image, size, osystem.settings());
-    case BSType::_3F:
-      return make_unique<Cartridge3F>(image, size, osystem.settings());
-    case BSType::_4A50:
-      return make_unique<Cartridge4A50>(image, size, osystem.settings());
-    case BSType::_4K:
-      return make_unique<Cartridge4K>(image, size, osystem.settings());
-    case BSType::_4KSC:
-      return make_unique<Cartridge4KSC>(image, size, osystem.settings());
-    case BSType::_AR:
-      return make_unique<CartridgeAR>(image, size, osystem.settings());
-    case BSType::_BUS:
-      return make_unique<CartridgeBUS>(image, size, osystem.settings());
-    case BSType::_CDF:
-      return make_unique<CartridgeCDF>(image, size, osystem.settings());
-    case BSType::_CM:
-      return make_unique<CartridgeCM>(image, size, osystem.settings());
-    case BSType::_CTY:
-      return make_unique<CartridgeCTY>(image, size, osystem);
-    case BSType::_CV:
-      return make_unique<CartridgeCV>(image, size, osystem.settings());
-    case BSType::_CVP:
-      return make_unique<CartridgeCVPlus>(image, size, osystem.settings());
-    case BSType::_DASH:
-      return make_unique<CartridgeDASH>(image, size, osystem.settings());
-    case BSType::_DPC:
-      return make_unique<CartridgeDPC>(image, size, osystem.settings());
-    case BSType::_DPCP:
-      return make_unique<CartridgeDPCPlus>(image, size, osystem.settings());
-    case BSType::_E0:
-      return make_unique<CartridgeE0>(image, size, osystem.settings());
-    case BSType::_E7:
-      return make_unique<CartridgeE7>(image, size, osystem.settings());
-    case BSType::_E78K:
-      return make_unique<CartridgeE78K>(image, size, osystem.settings());
-    case BSType::_EF:
-      return make_unique<CartridgeEF>(image, size, osystem.settings());
-    case BSType::_EFSC:
-      return make_unique<CartridgeEFSC>(image, size, osystem.settings());
-    case BSType::_BF:
-      return make_unique<CartridgeBF>(image, size, osystem.settings());
-    case BSType::_BFSC:
-      return make_unique<CartridgeBFSC>(image, size, osystem.settings());
-    case BSType::_DF:
-      return make_unique<CartridgeDF>(image, size, osystem.settings());
-    case BSType::_DFSC:
-      return make_unique<CartridgeDFSC>(image, size, osystem.settings());
-    case BSType::_F0:
-      return make_unique<CartridgeF0>(image, size, osystem.settings());
-    case BSType::_F4:
-      return make_unique<CartridgeF4>(image, size, osystem.settings());
-    case BSType::_F4SC:
-      return make_unique<CartridgeF4SC>(image, size, osystem.settings());
-    case BSType::_F6:
-      return make_unique<CartridgeF6>(image, size, osystem.settings());
-    case BSType::_F6SC:
-      return make_unique<CartridgeF6SC>(image, size, osystem.settings());
-    case BSType::_F8:
+    case Bankswitch::Type::_0840:
+      return make_unique<Cartridge0840>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_2K:
+      return make_unique<Cartridge2K>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_3E:
+      return make_unique<Cartridge3E>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_3EP:
+      return make_unique<Cartridge3EPlus>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_3F:
+      return make_unique<Cartridge3F>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_4A50:
+      return make_unique<Cartridge4A50>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_4K:
+      return make_unique<Cartridge4K>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_4KSC:
+      return make_unique<Cartridge4KSC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_AR:
+      return make_unique<CartridgeAR>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_BF:
+      return make_unique<CartridgeBF>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_BFSC:
+      return make_unique<CartridgeBFSC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_BUS:
+      return make_unique<CartridgeBUS>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_CDF:
+      return make_unique<CartridgeCDF>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_CM:
+      return make_unique<CartridgeCM>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_CTY:
+      return make_unique<CartridgeCTY>(image, size, md5, osystem);
+    case Bankswitch::Type::_CV:
+      return make_unique<CartridgeCV>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_CVP:
+      return make_unique<CartridgeCVPlus>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_DASH:
+      return make_unique<CartridgeDASH>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_DF:
+      return make_unique<CartridgeDF>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_DFSC:
+      return make_unique<CartridgeDFSC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_DPC:
+      return make_unique<CartridgeDPC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_DPCP:
+      return make_unique<CartridgeDPCPlus>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_E0:
+      return make_unique<CartridgeE0>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_E7:
+      return make_unique<CartridgeE7>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_E78K:
+      return make_unique<CartridgeE78K>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_EF:
+      return make_unique<CartridgeEF>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_EFSC:
+      return make_unique<CartridgeEFSC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F0:
+      return make_unique<CartridgeF0>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F4:
+      return make_unique<CartridgeF4>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F4SC:
+      return make_unique<CartridgeF4SC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F6:
+      return make_unique<CartridgeF6>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F6SC:
+      return make_unique<CartridgeF6SC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_F8:
       return make_unique<CartridgeF8>(image, size, md5, osystem.settings());
-    case BSType::_F8SC:
-      return make_unique<CartridgeF8SC>(image, size, osystem.settings());
-    case BSType::_FA:
-      return make_unique<CartridgeFA>(image, size, osystem.settings());
-    case BSType::_FA2:
-      return make_unique<CartridgeFA2>(image, size, osystem);
-    case BSType::_FE:
-      return make_unique<CartridgeFE>(image, size, osystem.settings());
-    case BSType::_MDM:
-      return make_unique<CartridgeMDM>(image, size, osystem.settings());
-    case BSType::_UA:
-      return make_unique<CartridgeUA>(image, size, osystem.settings());
-    case BSType::_SB:
-      return make_unique<CartridgeSB>(image, size, osystem.settings());
-    case BSType::_WD:
-      return make_unique<CartridgeWD>(image, size, osystem.settings());
-    case BSType::_X07:
-      return make_unique<CartridgeX07>(image, size, osystem.settings());
+    case Bankswitch::Type::_F8SC:
+      return make_unique<CartridgeF8SC>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_FA:
+      return make_unique<CartridgeFA>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_FA2:
+      return make_unique<CartridgeFA2>(image, size, md5, osystem);
+    case Bankswitch::Type::_FE:
+      return make_unique<CartridgeFE>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_MDM:
+      return make_unique<CartridgeMDM>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_UA:
+      return make_unique<CartridgeUA>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_SB:
+      return make_unique<CartridgeSB>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_WD:
+      return make_unique<CartridgeWD>(image, size, md5, osystem.settings());
+    case Bankswitch::Type::_X07:
+      return make_unique<CartridgeX07>(image, size, md5, osystem.settings());
     default:
       return nullptr;  // The remaining types have already been handled
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-BSType CartDetector::autodetectType(const BytePtr& image, uInt32 size)
+Bankswitch::Type CartDetector::autodetectType(const BytePtr& image, uInt32 size)
 {
   // Guess type based on size
-  BSType type = BSType::_AUTO;
+  Bankswitch::Type type = Bankswitch::Type::_AUTO;
 
-  if(isProbablyCVPlus(image,size))
+  if(isProbablyCVPlus(image, size))
   {
-    type = BSType::_CVP;
+    type = Bankswitch::Type::_CVP;
   }
   else if((size % 8448) == 0 || size == 6144)
   {
-    type = BSType::_AR;
+    type = Bankswitch::Type::_AR;
   }
   else if(size < 2048)  // Sub2K images
   {
-    type = BSType::_2K;
+    type = Bankswitch::Type::_2K;
   }
   else if((size == 2048) ||
           (size == 4096 && memcmp(image.get(), image.get() + 2048, 2048) == 0))
   {
-    type = isProbablyCV(image, size) ? BSType::_CV : BSType::_2K;
+    type = isProbablyCV(image, size) ? Bankswitch::Type::_CV : Bankswitch::Type::_2K;
   }
   else if(size == 4096)
   {
     if(isProbablyCV(image, size))
-      type = BSType::_CV;
+      type = Bankswitch::Type::_CV;
     else if(isProbably4KSC(image, size))
-      type = BSType::_4KSC;
+      type = Bankswitch::Type::_4KSC;
     else
-      type = BSType::_4K;
+      type = Bankswitch::Type::_4K;
   }
   else if(size == 8*1024)  // 8K
   {
@@ -366,141 +373,148 @@ BSType CartDetector::autodetectType(const BytePtr& image, uInt32 size)
     bool f8 = searchForBytes(image.get(), size, signature, 3, 2);
 
     if(isProbablySC(image, size))
-      type = BSType::_F8SC;
+      type = Bankswitch::Type::_F8SC;
     else if(memcmp(image.get(), image.get() + 4096, 4096) == 0)
-      type = BSType::_4K;
+      type = Bankswitch::Type::_4K;
     else if(isProbablyE0(image, size))
-      type = BSType::_E0;
+      type = Bankswitch::Type::_E0;
     else if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else if(isProbablyUA(image, size))
-      type = BSType::_UA;
+      type = Bankswitch::Type::_UA;
     else if(isProbablyFE(image, size) && !f8)
-      type = BSType::_FE;
+      type = Bankswitch::Type::_FE;
     else if(isProbably0840(image, size))
-      type = BSType::_0840;
+      type = Bankswitch::Type::_0840;
     else if(isProbablyE78K(image, size))
-      type = BSType::_E78K;
+      type = Bankswitch::Type::_E78K;
     else
-      type = BSType::_F8;
+      type = Bankswitch::Type::_F8;
   }
   else if(size == 8*1024 + 3)  // 8195 bytes (Experimental)
   {
-    type = BSType::_WD;
+    type = Bankswitch::Type::_WD;
   }
   else if(size >= 10240 && size <= 10496)  // ~10K - Pitfall2
   {
-    type = BSType::_DPC;
+    type = Bankswitch::Type::_DPC;
   }
   else if(size == 12*1024)  // 12K
   {
-    type = BSType::_FA;
+    type = Bankswitch::Type::_FA;
   }
   else if(size == 16*1024)  // 16K
   {
     if(isProbablySC(image, size))
-      type = BSType::_F6SC;
+      type = Bankswitch::Type::_F6SC;
     else if(isProbablyE7(image, size))
-      type = BSType::_E7;
+      type = Bankswitch::Type::_E7;
     else if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
   /* no known 16K 3F ROMS
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
   */
     else
-      type = BSType::_F6;
+      type = Bankswitch::Type::_F6;
   }
   else if(size == 24*1024 || size == 28*1024)  // 24K & 28K
   {
-    type = BSType::_FA2;
+    type = Bankswitch::Type::_FA2;
   }
   else if(size == 29*1024)  // 29K
   {
     if(isProbablyARM(image, size))
-      type = BSType::_FA2;
+      type = Bankswitch::Type::_FA2;
     else /*if(isProbablyDPCplus(image, size))*/
-      type = BSType::_DPCP;
+      type = Bankswitch::Type::_DPCP;
   }
   else if(size == 32*1024)  // 32K
   {
-    if(isProbablySC(image, size))
-      type = BSType::_F4SC;
+    if (isProbablyCTY(image, size))
+      type = Bankswitch::Type::_CTY;
+    else if(isProbablySC(image, size))
+      type = Bankswitch::Type::_F4SC;
     else if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else if (isProbablyBUS(image, size))
-      type = BSType::_BUS;
+      type = Bankswitch::Type::_BUS;
     else if (isProbablyCDF(image, size))
-      type = BSType::_CDF;
+      type = Bankswitch::Type::_CDF;
     else if(isProbablyDPCplus(image, size))
-      type = BSType::_DPCP;
-    else if(isProbablyCTY(image, size))
-      type = BSType::_CTY;
+      type = Bankswitch::Type::_DPCP;
     else if(isProbablyFA2(image, size))
-      type = BSType::_FA2;
+      type = Bankswitch::Type::_FA2;
     else
-      type = BSType::_F4;
+      type = Bankswitch::Type::_F4;
+  }
+  else if(size == 60*1024)  // 60K
+  {
+    if(isProbablyCTY(image, size))
+      type = Bankswitch::Type::_CTY;
+    else
+      type = Bankswitch::Type::_F4;
   }
   else if(size == 64*1024)  // 64K
   {
     if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else if(isProbably4A50(image, size))
-      type = BSType::_4A50;
+      type = Bankswitch::Type::_4A50;
     else if(isProbablyEF(image, size, type))
       ; // type has been set directly in the function
     else if(isProbablyX07(image, size))
-      type = BSType::_X07;
+      type = Bankswitch::Type::_X07;
     else
-      type = BSType::_F0;
+      type = Bankswitch::Type::_F0;
   }
   else if(size == 128*1024)  // 128K
   {
     if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbablyDF(image, size, type))
       ; // type has been set directly in the function
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else if(isProbably4A50(image, size))
-      type = BSType::_4A50;
+      type = Bankswitch::Type::_4A50;
     else if(isProbablySB(image, size))
-      type = BSType::_SB;
+      type = Bankswitch::Type::_SB;
   }
   else if(size == 256*1024)  // 256K
   {
     if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbablyBF(image, size, type))
       ; // type has been set directly in the function
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else /*if(isProbablySB(image, size))*/
-      type = BSType::_SB;
+      type = Bankswitch::Type::_SB;
   }
   else  // what else can we do?
   {
     if(isProbably3E(image, size))
-      type = BSType::_3E;
+      type = Bankswitch::Type::_3E;
     else if(isProbably3F(image, size))
-      type = BSType::_3F;
+      type = Bankswitch::Type::_3F;
     else
-      type = BSType::_4K;  // Most common bankswitching type
+      type = Bankswitch::Type::_4K;  // Most common bankswitching type
   }
 
   // Variable sized ROM formats are independent of image size and come last
   if(isProbablyDASH(image, size))
-    type = BSType::_DASH;
+    type = Bankswitch::Type::_DASH;
   else if(isProbably3EPlus(image, size))
-    type = BSType::_3EP;
+    type = Bankswitch::Type::_3EP;
   else if(isProbablyMDM(image, size))
-    type = BSType::_MDM;
+    type = Bankswitch::Type::_MDM;
 
   return type;
 }
@@ -550,23 +564,6 @@ bool CartDetector::isProbablySC(const BytePtr& image, uInt32 size)
   return true;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbably4KSC(const BytePtr& image, uInt32 size)
-{
-  // We check if the first 256 bytes are identical *and* if there's
-  // an "SC" signature for one of our larger SC types at 1FFA.
-
-  uInt8 first = image[0];
-  for(uInt32 i = 1; i < 256; ++i)
-      if(image[i] != first)
-        return false;
-
-  if((image[size-6]=='S') && (image[size-5]=='C'))
-      return true;
-
-  return false;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool CartDetector::isProbablyARM(const BytePtr& image, uInt32 size)
 {
@@ -621,8 +618,8 @@ bool CartDetector::isProbably3E(const BytePtr& image, uInt32 size)
 bool CartDetector::isProbably3EPlus(const BytePtr& image, uInt32 size)
 {
   // 3E+ cart is identified key 'TJ3E' in the ROM
-  uInt8 signature[] = { 'T', 'J', '3', 'E' };
-  return searchForBytes(image.get(), size, signature, 4, 1);
+  uInt8 tj3e[] = { 'T', 'J', '3', 'E' };
+  return searchForBytes(image.get(), size, tj3e, 4, 1);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -655,9 +652,69 @@ bool CartDetector::isProbably4A50(const BytePtr& image, uInt32 size)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyCTY(const BytePtr&, uInt32)
+bool CartDetector::isProbably4KSC(const BytePtr& image, uInt32 size)
 {
-  return false;  // TODO - add autodetection
+  // We check if the first 256 bytes are identical *and* if there's
+  // an "SC" signature for one of our larger SC types at 1FFA.
+
+  uInt8 first = image[0];
+  for(uInt32 i = 1; i < 256; ++i)
+      if(image[i] != first)
+        return false;
+
+  if((image[size-6]=='S') && (image[size-5]=='C'))
+      return true;
+
+  return false;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyBF(const BytePtr& image, uInt32 size,
+                                Bankswitch::Type& type)
+{
+  // BF carts store strings 'BFBF' and 'BFSC' starting at address $FFF8
+  // This signature is attributed to "RevEng" of AtariAge
+  uInt8 bf[]   = { 'B', 'F', 'B', 'F' };
+  uInt8 bfsc[] = { 'B', 'F', 'S', 'C' };
+  if(searchForBytes(image.get()+size-8, 8, bf, 4, 1))
+  {
+    type = Bankswitch::Type::_BF;
+    return true;
+  }
+  else if(searchForBytes(image.get()+size-8, 8, bfsc, 4, 1))
+  {
+    type = Bankswitch::Type::_BFSC;
+    return true;
+  }
+
+  return false;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyBUS(const BytePtr& image, uInt32 size)
+{
+  // BUS ARM code has 2 occurrences of the string BUS
+  // Note: all Harmony/Melody custom drivers also contain the value
+  // 0x10adab1e (LOADABLE) if needed for future improvement
+  uInt8 bus[] = { 'B', 'U', 'S'};
+  return searchForBytes(image.get(), size, bus, 3, 2);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyCDF(const BytePtr& image, uInt32 size)
+{
+  // CDF ARM code has 3 occurrences of the string CDF
+  // Note: all Harmony/Melody custom drivers also contain the value
+  // 0x10adab1e (LOADABLE) if needed for future improvement
+  uInt8 cdf[] = { 'C', 'D', 'F' };
+  return searchForBytes(image.get(), size, cdf, 3, 3);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyCTY(const BytePtr& image, uInt32 size)
+{
+  uInt8 lenin[] = { 'L', 'E', 'N', 'I', 'N' };
+  return searchForBytes(image.get(), size, lenin, 5, 1);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -680,17 +737,40 @@ bool CartDetector::isProbablyCVPlus(const BytePtr& image, uInt32)
 {
   // CV+ cart is identified key 'commavidplus' @ $04 in the ROM
   // We inspect only this area to speed up the search
-  uInt8 signature[12] = { 'c', 'o', 'm', 'm', 'a', 'v', 'i', 'd',
-                          'p', 'l', 'u', 's' };
-  return searchForBytes(image.get()+4, 24, signature, 12, 1);
+  uInt8 cvp[12] = { 'c', 'o', 'm', 'm', 'a', 'v', 'i', 'd',
+                    'p', 'l', 'u', 's' };
+  return searchForBytes(image.get()+4, 24, cvp, 12, 1);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool CartDetector::isProbablyDASH(const BytePtr& image, uInt32 size)
 {
   // DASH cart is identified key 'TJAD' in the ROM
-  uInt8 signature[] = { 'T', 'J', 'A', 'D' };
-  return searchForBytes(image.get(), size, signature, 4, 1);
+  uInt8 tjad[] = { 'T', 'J', 'A', 'D' };
+  return searchForBytes(image.get(), size, tjad, 4, 1);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyDF(const BytePtr& image, uInt32 size,
+                                Bankswitch::Type& type)
+{
+
+  // BF carts store strings 'DFDF' and 'DFSC' starting at address $FFF8
+  // This signature is attributed to "RevEng" of AtariAge
+  uInt8 df[]   = { 'D', 'F', 'D', 'F' };
+  uInt8 dfsc[] = { 'D', 'F', 'S', 'C' };
+  if(searchForBytes(image.get()+size-8, 8, df, 4, 1))
+  {
+    type = Bankswitch::Type::_DF;
+    return true;
+  }
+  else if(searchForBytes(image.get()+size-8, 8, dfsc, 4, 1))
+  {
+    type = Bankswitch::Type::_DFSC;
+    return true;
+  }
+
+  return false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -699,8 +779,8 @@ bool CartDetector::isProbablyDPCplus(const BytePtr& image, uInt32 size)
   // DPC+ ARM code has 2 occurrences of the string DPC+
   // Note: all Harmony/Melody custom drivers also contain the value
   // 0x10adab1e (LOADABLE) if needed for future improvement
-  uInt8 signature[] = { 'D', 'P', 'C', '+' };
-  return searchForBytes(image.get(), size, signature, 4, 2);
+  uInt8 dpcp[] = { 'D', 'P', 'C', '+' };
+  return searchForBytes(image.get(), size, dpcp, 4, 2);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -774,7 +854,8 @@ bool CartDetector::isProbablyE78K(const BytePtr& image, uInt32 size)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyEF(const BytePtr& image, uInt32 size, BSType& type)
+bool CartDetector::isProbablyEF(const BytePtr& image, uInt32 size,
+                                Bankswitch::Type& type)
 {
   // Newer EF carts store strings 'EFEF' and 'EFSC' starting at address $FFF8
   // This signature is attributed to "RevEng" of AtariAge
@@ -782,12 +863,12 @@ bool CartDetector::isProbablyEF(const BytePtr& image, uInt32 size, BSType& type)
   uInt8 efsc[] = { 'E', 'F', 'S', 'C' };
   if(searchForBytes(image.get()+size-8, 8, efef, 4, 1))
   {
-    type = BSType::_EF;
+    type = Bankswitch::Type::_EF;
     return true;
   }
   else if(searchForBytes(image.get()+size-8, 8, efsc, 4, 1))
   {
-    type = BSType::_EFSC;
+    type = Bankswitch::Type::_EFSC;
     return true;
   }
 
@@ -814,70 +895,7 @@ bool CartDetector::isProbablyEF(const BytePtr& image, uInt32 size, BSType& type)
   // the SC variant
   if(isEF)
   {
-    type = isProbablySC(image, size) ? BSType::_EFSC : BSType::_EF;
-    return true;
-  }
-
-  return false;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyBF(const BytePtr& image, uInt32 size, BSType& type)
-{
-  // BF carts store strings 'BFBF' and 'BFSC' starting at address $FFF8
-  // This signature is attributed to "RevEng" of AtariAge
-  uInt8 bf[]   = { 'B', 'F', 'B', 'F' };
-  uInt8 bfsc[] = { 'B', 'F', 'S', 'C' };
-  if(searchForBytes(image.get()+size-8, 8, bf, 4, 1))
-  {
-    type = BSType::_BF;
-    return true;
-  }
-  else if(searchForBytes(image.get()+size-8, 8, bfsc, 4, 1))
-  {
-    type = BSType::_BFSC;
-    return true;
-  }
-
-  return false;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyBUS(const BytePtr& image, uInt32 size)
-{
-  // BUS ARM code has 2 occurrences of the string BUS
-  // Note: all Harmony/Melody custom drivers also contain the value
-  // 0x10adab1e (LOADABLE) if needed for future improvement
-  uInt8 bus[] = { 'B', 'U', 'S'};
-  return searchForBytes(image.get(), size, bus, 3, 2);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyCDF(const BytePtr& image, uInt32 size)
-{
-  // CDF ARM code has 3 occurrences of the string DPC+
-  // Note: all Harmony/Melody custom drivers also contain the value
-  // 0x10adab1e (LOADABLE) if needed for future improvement
-  uInt8 signature[] = { 'C', 'D', 'F' };
-  return searchForBytes(image.get(), size, signature, 3, 3);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartDetector::isProbablyDF(const BytePtr& image, uInt32 size, BSType& type)
-{
-
-  // BF carts store strings 'DFDF' and 'DFSC' starting at address $FFF8
-  // This signature is attributed to "RevEng" of AtariAge
-  uInt8 df[]   = { 'D', 'F', 'D', 'F' };
-  uInt8 dfsc[] = { 'D', 'F', 'S', 'C' };
-  if(searchForBytes(image.get()+size-8, 8, df, 4, 1))
-  {
-    type = BSType::_DF;
-    return true;
-  }
-  else if(searchForBytes(image.get()+size-8, 8, dfsc, 4, 1))
-  {
-    type = BSType::_DFSC;
+    type = isProbablySC(image, size) ? Bankswitch::Type::_EFSC : Bankswitch::Type::_EF;
     return true;
   }
 
@@ -922,8 +940,8 @@ bool CartDetector::isProbablyFE(const BytePtr& image, uInt32 size)
 bool CartDetector::isProbablyMDM(const BytePtr& image, uInt32 size)
 {
   // MDM cart is identified key 'MDMC' in the first 8K of ROM
-  uInt8 signature[] = { 'M', 'D', 'M', 'C' };
-  return searchForBytes(image.get(), std::min(size, 8192u), signature, 4, 1);
+  uInt8 mdmc[] = { 'M', 'D', 'M', 'C' };
+  return searchForBytes(image.get(), std::min(size, 8192u), mdmc, 4, 1);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
