@@ -20,8 +20,8 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeE0::CartridgeE0(const BytePtr& image, uInt32 size,
-                         const Settings& settings)
-  : Cartridge(settings)
+                         const string& md5, const Settings& settings)
+  : Cartridge(settings, md5)
 {
   // Copy the ROM image into my buffer
   memcpy(myImage, image.get(), std::min(8192u, size));
@@ -200,7 +200,6 @@ bool CartridgeE0::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
     out.putShortArray(myCurrentSlice, 4);
   }
   catch(...)
@@ -217,9 +216,6 @@ bool CartridgeE0::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     in.getShortArray(myCurrentSlice, 4);
   }
   catch(...)
