@@ -20,28 +20,23 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeF6SC::CartridgeF6SC(const BytePtr& image, uInt32 size,
-                             const Settings& settings)
-  : Cartridge(settings),
+                             const string& md5, const Settings& settings)
+  : Cartridge(settings, md5),
     myBankOffset(0)
 {
   // Copy the ROM image into my buffer
   memcpy(myImage, image.get(), std::min(16384u, size));
   createCodeAccessBase(16384);
-
-  // Remember startup bank
-  myStartBank = 0;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeF6SC::reset()
 {
-  // define random startup bank
-  randomizeStartBank();
-
   initializeRAM(myRAM, 128);
+  initializeStartBank(0);
 
   // Upon reset we switch to the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -52,16 +47,16 @@ void CartridgeF6SC::install(System& system)
   System::PageAccess access(this, System::PA_READ);
 
   // Set the page accessing method for the RAM writing pages
+  // Map access to this class, since we need to inspect all accesses to
+  // check if RWP happens
   access.type = System::PA_WRITE;
   for(uInt16 addr = 0x1000; addr < 0x1080; addr += System::PAGE_SIZE)
   {
-    access.directPokeBase = &myRAM[addr & 0x007F];
     access.codeAccessBase = &myCodeAccessBase[addr & 0x007F];
     mySystem->setPageAccess(addr, access);
   }
 
   // Set the page accessing method for the RAM reading pages
-  access.directPokeBase = nullptr;
   access.type = System::PA_READ;
   for(uInt16 addr = 0x1080; addr < 0x1100; addr += System::PAGE_SIZE)
   {
@@ -71,7 +66,7 @@ void CartridgeF6SC::install(System& system)
   }
 
   // Install pages for the startup bank
-  bank(myStartBank);
+  bank(startBank());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -107,59 +102,44 @@ uInt8 CartridgeF6SC::peek(uInt16 address)
       break;
   }
 
-  if(address < 0x0080)  // Write port is at 0xF000 - 0xF080 (128 bytes)
-  {
-    // Reading from the write port triggers an unwanted write
-    uInt8 value = mySystem->getDataBusState(0xFF);
-
-    if(bankLocked())
-      return value;
-    else
-    {
-      triggerReadFromWritePort(peekAddress);
-      return myRAM[address] = value;
-    }
-  }
+  if(address < 0x0080)  // Write port is at 0xF000 - 0xF07F (128 bytes)
+    return peekRAM(myRAM[address], peekAddress);
   else
     return myImage[myBankOffset + address];
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CartridgeF6SC::poke(uInt16 address, uInt8)
+bool CartridgeF6SC::poke(uInt16 address, uInt8 value)
 {
-  address &= 0x0FFF;
-
   // Switch banks if necessary
-  switch(address)
+  switch(address & 0x0FFF)
   {
     case 0x0FF6:
       // Set the current bank to the first 4k bank
       bank(0);
-      break;
+      return false;
 
     case 0x0FF7:
       // Set the current bank to the second 4k bank
       bank(1);
-      break;
+      return false;
 
     case 0x0FF8:
       // Set the current bank to the third 4k bank
       bank(2);
-      break;
+      return false;
 
     case 0x0FF9:
       // Set the current bank to the forth 4k bank
       bank(3);
-      break;
+      return false;
 
     default:
       break;
   }
 
-  // NOTE: This does not handle accessing RAM, however, this function
-  // should never be called for RAM because of the way page accessing
-  // has been setup
-  return false;
+  pokeRAM(myRAM[address & 0x007F], address, value);
+  return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -233,7 +213,6 @@ bool CartridgeF6SC::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
     out.putShort(myBankOffset);
     out.putByteArray(myRAM, 128);
   }
@@ -251,9 +230,6 @@ bool CartridgeF6SC::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     myBankOffset = in.getShort();
     in.getByteArray(myRAM, 128);
   }
