@@ -52,9 +52,12 @@
 #include "Menu.hxx"
 #include "CommandMenu.hxx"
 #include "Serializable.hxx"
+#include "Serializer.hxx"
 #include "Version.hxx"
 #include "TIAConstants.hxx"
 #include "FrameLayout.hxx"
+#include "AudioQueue.hxx"
+#include "AudioSettings.hxx"
 #include "frame-manager/FrameManager.hxx"
 #include "frame-manager/FrameLayoutDetector.hxx"
 #include "frame-manager/YStartDetector.hxx"
@@ -75,17 +78,19 @@ namespace {
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
-                 const Properties& props)
+                 const Properties& props, AudioSettings& audioSettings)
   : myOSystem(osystem),
     myEvent(osystem.eventHandler().event()),
     myProperties(props),
     myCart(std::move(cart)),
     myDisplayFormat(""),  // Unknown TV format @ start
-    myFramerate(0.0),     // Unknown framerate @ start
     myCurrentFormat(0),   // Unknown format @ start,
     myAutodetectedYstart(0),
+    myYStartAutodetected(false),
+    myFormatAutodetected(false),
     myUserPaletteDefined(false),
-    myConsoleTiming(ConsoleTiming::ntsc)
+    myConsoleTiming(ConsoleTiming::ntsc),
+    myAudioSettings(audioSettings)
 {
   // Load user-defined palette for this ROM
   loadUserPalette();
@@ -93,7 +98,7 @@ Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
   // Create subsystems for the console
   my6502 = make_unique<M6502>(myOSystem.settings());
   myRiot = make_unique<M6532>(*this, myOSystem.settings());
-  myTIA  = make_unique<TIA>(*this, myOSystem.sound(), myOSystem.settings());
+  myTIA  = make_unique<TIA>(*this, myOSystem.settings());
   myFrameManager = make_unique<FrameManager>();
   mySwitches = make_unique<Switches>(myEvent, myProperties, myOSystem.settings());
 
@@ -109,6 +114,12 @@ Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
   myLeftControl  = make_unique<Joystick>(Controller::Left, myEvent, *mySystem);
   myRightControl = make_unique<Joystick>(Controller::Right, myEvent, *mySystem);
 
+  // Let the cart know how to query for the 'Cartridge.StartBank' property
+  myCart->setStartBankFromPropsFunc([this]() {
+    const string& startbank = myProperties.get(Cartridge_StartBank);
+    return startbank == EmptyString ? -1 : atoi(startbank.c_str());
+  });
+
   // We can only initialize after all the devices/components have been created
   mySystem->initialize();
 
@@ -133,6 +144,7 @@ Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
     {
       autodetected = "*";
       myCurrentFormat = 0;
+      myFormatAutodetected = true;
     }
   }
 
@@ -146,8 +158,6 @@ Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
   // Note that this can be overridden if a format is forced
   //   For example, if a PAL ROM is forced to be NTSC, it will use NTSC-like
   //   properties (60Hz, 262 scanlines, etc), but likely result in flicker
-  // The TIA will self-adjust the framerate if necessary
-  setTIAProperties();
   if(myDisplayFormat == "NTSC")
   {
     myCurrentFormat = 1;
@@ -179,6 +189,8 @@ Console::Console(OSystem& osystem, unique_ptr<Cartridge>& cart,
     myConsoleTiming = ConsoleTiming::secam;
   }
 
+  setTIAProperties();
+
   bool joyallow4 = myOSystem.settings().getBool("joyallow4");
   myOSystem.eventHandler().allowAllDirections(joyallow4);
 
@@ -205,10 +217,14 @@ Console::~Console()
   // Some smart controllers need to be informed that the console is going away
   myLeftControl->close();
   myRightControl->close();
+
+  // Close audio to prevent invalid access to myConsoleTiming from the audio
+  // callback
+  myOSystem.sound().close();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Console::autodetectFrameLayout()
+void Console::autodetectFrameLayout(bool reset)
 {
   // Run the TIA, looking for PAL scanline patterns
   // We turn off the SuperCharger progress bars, otherwise the SC BIOS
@@ -219,7 +235,8 @@ void Console::autodetectFrameLayout()
 
   FrameLayoutDetector frameLayoutDetector;
   myTIA->setFrameManager(&frameLayoutDetector);
-  mySystem->reset(true);
+
+  if (reset) mySystem->reset(true);
 
   for(int i = 0; i < 60; ++i) myTIA->update();
 
@@ -232,7 +249,22 @@ void Console::autodetectFrameLayout()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Console::autodetectYStart()
+void Console::redetectFrameLayout()
+{
+  Serializer s;
+
+  myOSystem.sound().close();
+  save(s);
+
+  autodetectFrameLayout(false);
+  if (myYStartAutodetected) autodetectYStart();
+
+  load(s);
+  initializeAudio();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Console::autodetectYStart(bool reset)
 {
   // We turn off the SuperCharger progress bars, otherwise the SC BIOS
   // will take over 250 frames!
@@ -243,7 +275,8 @@ void Console::autodetectYStart()
   YStartDetector ystartDetector;
   ystartDetector.setLayout(myDisplayFormat == "PAL" ? FrameLayout::pal : FrameLayout::ntsc);
   myTIA->setFrameManager(&ystartDetector);
-  mySystem->reset(true);
+
+  if (reset) mySystem->reset(true);
 
   for (int i = 0; i < 80; i++) myTIA->update();
 
@@ -255,6 +288,20 @@ void Console::autodetectYStart()
   myOSystem.settings().setValue("fastscbios", fastscbios);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Console::redetectYStart()
+{
+  Serializer s;
+
+  myOSystem.sound().close();
+  save(s);
+
+  autodetectYStart(false);
+
+  load(s);
+  initializeAudio();
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Console::save(Serializer& out) const
 {
@@ -305,59 +352,87 @@ bool Console::load(Serializer& in)
 void Console::toggleFormat(int direction)
 {
   string saveformat, message;
+  uInt32 format = myCurrentFormat;
 
   if(direction == 1)
-    myCurrentFormat = (myCurrentFormat + 1) % 7;
+    format = (myCurrentFormat + 1) % 7;
   else if(direction == -1)
-    myCurrentFormat = myCurrentFormat > 0 ? (myCurrentFormat - 1) : 6;
+    format = myCurrentFormat > 0 ? (myCurrentFormat - 1) : 6;
 
+  setFormat(format);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Console::setFormat(uInt32 format)
+{
+  if(myCurrentFormat == format)
+    return;
+
+  string saveformat, message;
+  string autodetected = "";
+
+  myCurrentFormat = format;
   switch(myCurrentFormat)
   {
     case 0:  // auto-detect
-      myTIA->update();
-      myDisplayFormat = myTIA->frameLayout() == FrameLayout::pal ? "PAL" : "NTSC";
-      message = "Auto-detect mode: " + myDisplayFormat;
+    {
+      if (myFormatAutodetected) return;
+
+      string oldDisplayFormat = myDisplayFormat;
+      redetectFrameLayout();
+      myFormatAutodetected = true;
       saveformat = "AUTO";
-      myConsoleTiming = myTIA->frameLayout() == FrameLayout::pal ?
-          ConsoleTiming::pal : ConsoleTiming::ntsc;
+      autodetected = "*";
+      myConsoleTiming = myDisplayFormat == "PAL" ? ConsoleTiming::pal : ConsoleTiming::ntsc;
+      message = "Auto-detect mode: " + myDisplayFormat;
       break;
+    }
     case 1:
       saveformat = myDisplayFormat = "NTSC";
       myConsoleTiming = ConsoleTiming::ntsc;
       message = "NTSC mode";
+      myFormatAutodetected = false;
       break;
     case 2:
       saveformat = myDisplayFormat = "PAL";
       myConsoleTiming = ConsoleTiming::pal;
       message = "PAL mode";
+      myFormatAutodetected = false;
       break;
     case 3:
       saveformat = myDisplayFormat = "SECAM";
       myConsoleTiming = ConsoleTiming::secam;
       message = "SECAM mode";
+      myFormatAutodetected = false;
       break;
     case 4:
       saveformat = myDisplayFormat = "NTSC50";
       myConsoleTiming = ConsoleTiming::ntsc;
       message = "NTSC50 mode";
+      myFormatAutodetected = false;
       break;
     case 5:
       saveformat = myDisplayFormat = "PAL60";
       myConsoleTiming = ConsoleTiming::pal;
       message = "PAL60 mode";
+      myFormatAutodetected = false;
       break;
     case 6:
       saveformat = myDisplayFormat = "SECAM60";
       myConsoleTiming = ConsoleTiming::secam;
       message = "SECAM60 mode";
+      myFormatAutodetected = false;
       break;
   }
   myProperties.set(Display_Format, saveformat);
 
+  myConsoleInfo.DisplayFormat = myDisplayFormat + autodetected;
+
   setPalette(myOSystem.settings().getString("palette"));
   setTIAProperties();
-  myTIA->frameReset();
   initializeVideo();  // takes care of refreshing the screen
+  initializeAudio(); // ensure that audio synthesis is set up to match emulation speed
+  myOSystem.resetFps(); // Reset FPS measurement
 
   myOSystem.frameBuffer().showMessage(message);
 
@@ -459,6 +534,9 @@ void Console::setPalette(const string& type)
      palettes[paletteNum][0];
 
   myOSystem.frameBuffer().setPalette(palette);
+
+  if(myTIA->usingFixedColors())
+    myTIA->enableFixedColors(true);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -466,13 +544,13 @@ void Console::togglePhosphor()
 {
   if(myOSystem.frameBuffer().tiaSurface().phosphorEnabled())
   {
-    myProperties.set(Display_Phosphor, "No");
+    myProperties.set(Display_Phosphor, "NO");
     myOSystem.frameBuffer().tiaSurface().enablePhosphor(false);
     myOSystem.frameBuffer().showMessage("Phosphor effect disabled");
   }
   else
   {
-    myProperties.set(Display_Phosphor, "Yes");
+    myProperties.set(Display_Phosphor, "YES");
     myOSystem.frameBuffer().tiaSurface().enablePhosphor(true);
     myOSystem.frameBuffer().showMessage("Phosphor effect enabled");
   }
@@ -545,37 +623,25 @@ FBInitStatus Console::initializeVideo(bool full)
   }
   setPalette(myOSystem.settings().getString("palette"));
 
-  // Set the correct framerate based on the format of the ROM
-  // This can be overridden by changing the framerate in the
-  // VideoDialog box or on the commandline, but it can't be saved
-  // (ie, framerate is now determined based on number of scanlines).
-  int framerate = myOSystem.settings().getInt("framerate");
-  if(framerate > 0) myFramerate = float(framerate);
-  myOSystem.setFramerate(myFramerate);
-
-  // Make sure auto-frame calculation is only enabled when necessary
-  myTIA->enableAutoFrame(framerate <= 0);
-
   return fbstatus;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Console::initializeAudio()
 {
-  // Initialize the sound interface.
-  // The # of channels can be overridden in the AudioDialog box or on
-  // the commandline, but it can't be saved.
-  int framerate = myOSystem.settings().getInt("framerate");
-  if(framerate > 0) myFramerate = float(framerate);
-  const string& sound = myProperties.get(Cartridge_Sound);
-
   myOSystem.sound().close();
-  myOSystem.sound().setChannels(sound == "STEREO" ? 2 : 1);
-  myOSystem.sound().setFrameRate(myFramerate);
-  myOSystem.sound().open();
 
-  // Make sure auto-frame calculation is only enabled when necessary
-  myTIA->enableAutoFrame(framerate <= 0);
+  myEmulationTiming
+    .updatePlaybackRate(myAudioSettings.sampleRate())
+    .updatePlaybackPeriod(myAudioSettings.fragmentSize())
+    .updateAudioQueueExtraFragments(myAudioSettings.bufferSize())
+    .updateAudioQueueHeadroom(myAudioSettings.headroom())
+    .updateSpeedFactor(myOSystem.settings().getFloat("speed"));
+
+  createAudioQueue();
+  myTIA->setAudioQueue(myAudioQueue);
+
+  myOSystem.sound().open(myAudioQueue, &myEmulationTiming);
 }
 
 /* Original frying research and code by Fred Quimby.
@@ -616,46 +682,62 @@ void Console::changeYStart(int direction)
       myOSystem.frameBuffer().showMessage("YStart at maximum");
       return;
     }
-    ystart++;
+
+    ++ystart;
+    myYStartAutodetected = false;
   }
   else if(direction == -1)  // decrease YStart
   {
-    if (ystart == TIAConstants::minYStart && myAutodetectedYstart == 0) {
-      myOSystem.frameBuffer().showMessage("Autodetected YStart not available");
-      return;
-    }
-
-    if(ystart == TIAConstants::minYStart-1 && myAutodetectedYstart > 0)
+    if(ystart == 0)
     {
-      myOSystem.frameBuffer().showMessage("YStart at minimum");
-      return;
+      throw runtime_error("cannot happen");
     }
 
-    ystart--;
+    --ystart;
+    myYStartAutodetected = false;
   }
   else
     return;
 
-  ostringstream val;
-  val << ystart;
-  if(ystart == TIAConstants::minYStart-1)
-    myOSystem.frameBuffer().showMessage("YStart autodetected");
-  else
-  {
-    if(myAutodetectedYstart > 0 && myAutodetectedYstart == ystart)
-    {
-      // We've reached the auto-detect value, so reset
-      myOSystem.frameBuffer().showMessage("YStart " + val.str() + " (Auto)");
-      val.str("");
-      val << TIAConstants::minYStart-1;
-    }
-    else
-      myOSystem.frameBuffer().showMessage("YStart " + val.str());
+  if(ystart == 0) {
+    redetectYStart();
+    ystart = myAutodetectedYstart;
+    myYStartAutodetected = true;
+
+    myProperties.set(Display_YStart, "0");
+  }
+  else {
+    ostringstream ss;
+    ss << ystart;
+
+    myProperties.set(Display_YStart, ss.str());
   }
 
-  myProperties.set(Display_YStart, val.str());
-  myTIA->setYStart(ystart);
-  myTIA->frameReset();
+  if (ystart != myTIA->ystart()) myTIA->setYStart(ystart);
+
+  ostringstream ss;
+
+  if(myAutodetectedYstart == ystart) ss << "YStart " << ystart << " (Auto)";
+  else ss << "YStart " << ystart;
+
+  myOSystem.frameBuffer().showMessage(ss.str());
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Console::updateYStart(uInt32 ystart)
+{
+  if (ystart > TIAConstants::maxYStart) return;
+
+  if (ystart == 0) {
+    if (myYStartAutodetected) return;
+
+    redetectYStart();
+    myYStartAutodetected = true;
+    ystart = myAutodetectedYstart;
+  } else
+    myYStartAutodetected = false;
+
+  if (ystart != myTIA->ystart()) myTIA->setYStart(ystart);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -666,7 +748,7 @@ void Console::changeHeight(int direction)
 
   if(direction == +1)       // increase Height
   {
-    height++;
+    ++height;
     if(height > TIAConstants::maxViewableHeight || height > dheight)
     {
       myOSystem.frameBuffer().showMessage("Height at maximum");
@@ -675,14 +757,13 @@ void Console::changeHeight(int direction)
   }
   else if(direction == -1)  // decrease Height
   {
-    height--;
+    --height;
     if(height < TIAConstants::minViewableHeight) height = 0;
   }
   else
     return;
 
   myTIA->setHeight(height);
-  myTIA->frameReset();
   initializeVideo();  // takes care of refreshing the screen
 
   ostringstream val;
@@ -696,7 +777,12 @@ void Console::setTIAProperties()
 {
   uInt32 ystart = atoi(myProperties.get(Display_YStart).c_str());
   if(ystart != 0)
-    ystart = BSPF::clamp(ystart, TIAConstants::minYStart, TIAConstants::maxYStart);
+    ystart = BSPF::clamp(ystart, 0u, TIAConstants::maxYStart);
+  else {
+    ystart = myAutodetectedYstart;
+    myYStartAutodetected = true;
+  }
+
   uInt32 height = atoi(myProperties.get(Display_Height).c_str());
   if(height != 0)
     height = BSPF::clamp(height, TIAConstants::minViewableHeight, TIAConstants::maxViewableHeight);
@@ -705,24 +791,36 @@ void Console::setTIAProperties()
      myDisplayFormat == "SECAM60")
   {
     // Assume we've got ~262 scanlines (NTSC-like format)
-    myFramerate = 60.0;
-    myConsoleInfo.InitialFrameRate = "60";
     myTIA->setLayout(FrameLayout::ntsc);
   }
   else
   {
     // Assume we've got ~312 scanlines (PAL-like format)
-    myFramerate = 50.0;
-    myConsoleInfo.InitialFrameRate = "50";
-
     // PAL ROMs normally need at least 250 lines
     if (height != 0) height = std::max(height, 250u);
 
     myTIA->setLayout(FrameLayout::pal);
   }
 
-  myTIA->setYStart(ystart != 0 ? ystart : myAutodetectedYstart);
+  myTIA->setYStart(ystart);
   myTIA->setHeight(height);
+
+  myEmulationTiming.updateFrameLayout(myTIA->frameLayout());
+  myEmulationTiming.updateConsoleTiming(myConsoleTiming);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Console::createAudioQueue()
+{
+  bool useStereo = myOSystem.settings().getBool(AudioSettings::SETTING_STEREO)
+    || myProperties.get(Cartridge_Sound) == "STEREO";
+
+  myAudioQueue = make_shared<AudioQueue>(
+    myEmulationTiming.audioFragmentSize(),
+    myEmulationTiming.audioQueueCapacity(),
+    useStereo,
+    [this](string msg){ myOSystem.logMessage(msg, 1); }
+  );
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -943,11 +1041,11 @@ void Console::generateColorLossPalette()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Console::setFramerate(float framerate)
+float Console::getFramerate() const
 {
-  myFramerate = framerate;
-  myOSystem.setFramerate(framerate);
-  myOSystem.sound().setFrameRate(framerate);
+  return
+    (myConsoleTiming == ConsoleTiming::ntsc ? 262.f * 60.f : 312.f * 50.f) /
+     myTIA->frameBufferScanlinesLastFrame();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1054,38 +1152,38 @@ uInt32 Console::ourNTSCPalette[256] = {
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt32 Console::ourPALPalette[256] = {
-  0x000000, 0, 0x2b2b2b, 0, 0x525252, 0, 0x767676, 0,
-  0x979797, 0, 0xb6b6b6, 0, 0xd2d2d2, 0, 0xececec, 0,
-  0x000000, 0, 0x2b2b2b, 0, 0x525252, 0, 0x767676, 0,
-  0x979797, 0, 0xb6b6b6, 0, 0xd2d2d2, 0, 0xececec, 0,
-  0x805800, 0, 0x96711a, 0, 0xab8732, 0, 0xbe9c48, 0,
-  0xcfaf5c, 0, 0xdfc06f, 0, 0xeed180, 0, 0xfce090, 0,
-  0x445c00, 0, 0x5e791a, 0, 0x769332, 0, 0x8cac48, 0,
-  0xa0c25c, 0, 0xb3d76f, 0, 0xc4ea80, 0, 0xd4fc90, 0,
-  0x703400, 0, 0x89511a, 0, 0xa06b32, 0, 0xb68448, 0,
-  0xc99a5c, 0, 0xdcaf6f, 0, 0xecc280, 0, 0xfcd490, 0,
-  0x006414, 0, 0x1a8035, 0, 0x329852, 0, 0x48b06e, 0,
-  0x5cc587, 0, 0x6fd99e, 0, 0x80ebb4, 0, 0x90fcc8, 0,
-  0x700014, 0, 0x891a35, 0, 0xa03252, 0, 0xb6486e, 0,
-  0xc95c87, 0, 0xdc6f9e, 0, 0xec80b4, 0, 0xfc90c8, 0,
-  0x005c5c, 0, 0x1a7676, 0, 0x328e8e, 0, 0x48a4a4, 0,
-  0x5cb8b8, 0, 0x6fcbcb, 0, 0x80dcdc, 0, 0x90ecec, 0,
-  0x70005c, 0, 0x841a74, 0, 0x963289, 0, 0xa8489e, 0,
-  0xb75cb0, 0, 0xc66fc1, 0, 0xd380d1, 0, 0xe090e0, 0,
-  0x003c70, 0, 0x195a89, 0, 0x2f75a0, 0, 0x448eb6, 0,
-  0x57a5c9, 0, 0x68badc, 0, 0x79ceec, 0, 0x88e0fc, 0,
-  0x580070, 0, 0x6e1a89, 0, 0x8332a0, 0, 0x9648b6, 0,
-  0xa75cc9, 0, 0xb76fdc, 0, 0xc680ec, 0, 0xd490fc, 0,
-  0x002070, 0, 0x193f89, 0, 0x2f5aa0, 0, 0x4474b6, 0,
-  0x578bc9, 0, 0x68a1dc, 0, 0x79b5ec, 0, 0x88c8fc, 0,
-  0x340080, 0, 0x4a1a96, 0, 0x5f32ab, 0, 0x7248be, 0,
-  0x835ccf, 0, 0x936fdf, 0, 0xa280ee, 0, 0xb090fc, 0,
-  0x000088, 0, 0x1a1a9d, 0, 0x3232b0, 0, 0x4848c2, 0,
-  0x5c5cd2, 0, 0x6f6fe1, 0, 0x8080ef, 0, 0x9090fc, 0,
-  0x000000, 0, 0x2b2b2b, 0, 0x525252, 0, 0x767676, 0,
-  0x979797, 0, 0xb6b6b6, 0, 0xd2d2d2, 0, 0xececec, 0,
-  0x000000, 0, 0x2b2b2b, 0, 0x525252, 0, 0x767676, 0,
-  0x979797, 0, 0xb6b6b6, 0, 0xd2d2d2, 0, 0xececec, 0
+  0x000000, 0, 0x121212, 0, 0x242424, 0, 0x484848, 0, // 180 0
+  0x6c6c6c, 0, 0x909090, 0, 0xb4b4b4, 0, 0xd8d8d8, 0, // was 0x111111..0xcccccc
+  0x000000, 0, 0x121212, 0, 0x242424, 0, 0x484848, 0, // 198 1
+  0x6c6c6c, 0, 0x909090, 0, 0xb4b4b4, 0, 0xd8d8d8, 0,
+  0x1d0f00, 0, 0x3f2700, 0, 0x614900, 0, 0x836b01, 0, // 1b0 2
+  0xa58d23, 0, 0xc7af45, 0, 0xe9d167, 0, 0xffe789, 0, // was ..0xfff389
+  0x002400, 0, 0x004600, 0, 0x216800, 0, 0x438a07, 0, // 1c8 3
+  0x65ac29, 0, 0x87ce4b, 0, 0xa9f06d, 0, 0xcbff8f, 0,
+  0x340000, 0, 0x561400, 0, 0x783602, 0, 0x9a5824, 0, // 1e0 4
+  0xbc7a46, 0, 0xde9c68, 0, 0xffbe8a, 0, 0xffd0ad, 0, // was ..0xffe0ac
+  0x002700, 0, 0x004900, 0, 0x0c6b0c, 0, 0x2e8d2e, 0, // 1f8 5
+  0x50af50, 0, 0x72d172, 0, 0x94f394, 0, 0xb6ffb6, 0,
+  0x3d0008, 0, 0x610511, 0, 0x832733, 0, 0xa54955, 0, // 210 6
+  0xc76b77, 0, 0xe98d99, 0, 0xffafbb, 0, 0xffd1d7, 0, // was 0x3f0000..0xffd1dd
+  0x001e12, 0, 0x004228, 0, 0x046540, 0, 0x268762, 0, // 228 7
+  0x48a984, 0, 0x6acba6, 0, 0x8cedc8, 0, 0xafffe0, 0, // was 0x002100, 0x00431e..0xaeffff
+  0x300025, 0, 0x5f0047, 0, 0x811e69, 0, 0xa3408b, 0, // 240 8
+  0xc562ad, 0, 0xe784cf, 0, 0xffa8ea, 0, 0xffc9f2, 0, // was ..0xffa6f1, 0xffc8ff
+  0x001431, 0, 0x003653, 0, 0x0a5875, 0, 0x2c7a97, 0, // 258 9
+  0x4e9cb9, 0, 0x70bedb, 0, 0x92e0fd, 0, 0xb4ffff, 0,
+  0x2c0052, 0, 0x4e0074, 0, 0x701d96, 0, 0x923fb8, 0, // 270 a
+  0xb461da, 0, 0xd683fc, 0, 0xe2a5ff, 0, 0xeec9ff, 0, // was ..0xf8a5ff, 0xffc7ff
+  0x001759, 0, 0x00247c, 0, 0x1d469e, 0, 0x3f68c0, 0, // 288 b
+  0x618ae2, 0, 0x83acff, 0, 0xa5ceff, 0, 0xc7f0ff, 0,
+  0x12006d, 0, 0x34038f, 0, 0x5625b1, 0, 0x7847d3, 0, // 2a0 c
+  0x9a69f5, 0, 0xb48cff, 0, 0xc9adff, 0, 0xe1d1ff, 0, // was ..0xbc8bff, 0xdeadff, 0xffcfff,
+  0x000070, 0, 0x161292, 0, 0x3834b4, 0, 0x5a56d6, 0, // 2b8 d
+  0x7c78f8, 0, 0x9e9aff, 0, 0xc0bcff, 0, 0xe2deff, 0,
+  0x000000, 0, 0x121212, 0, 0x242424, 0, 0x484848, 0, // 2d0 e
+  0x6c6c6c, 0, 0x909090, 0, 0xb4b4b4, 0, 0xd8d8d8, 0,
+  0x000000, 0, 0x121212, 0, 0x242424, 0, 0x484848, 0, // 2e8 f
+  0x6c6c6c, 0, 0x909090, 0, 0xb4b4b4, 0, 0xd8d8d8, 0,
 };
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
