@@ -32,6 +32,7 @@
 #include "OSystem.hxx"
 #include "Settings.hxx"
 #include "TIA.hxx"
+#include "Sound.hxx"
 
 #include "FBSurface.hxx"
 #include "TIASurface.hxx"
@@ -47,10 +48,9 @@ FrameBuffer::FrameBuffer(OSystem& osystem)
     myInitializedCount(0),
     myPausedCount(0),
     myStatsEnabled(false),
-    myLastFrameRate(60),
-    myCurrentModeList(nullptr),
-    myTotalTime(0),
-    myTotalFrames(0)
+    myLastScanlines(0),
+    myGrabMouse(false),
+    myCurrentModeList(nullptr)
 {
 }
 
@@ -132,22 +132,7 @@ bool FrameBuffer::initialize()
     VarList::push_back(myTIAZoomLevels, desc.str(), zoom);
   }
 
-  // Set palette for GUI (upper area of array, doesn't change during execution)
-  int palID = 0;
-  if(myOSystem.settings().getString("uipalette") == "classic")
-    palID = 1;
-  else if(myOSystem.settings().getString("uipalette") == "light")
-    palID = 2;
-
-  for(int i = 0, j = 256; i < kNumColors-256; ++i, ++j)
-  {
-    uInt8 r = (ourGUIColors[palID][i] >> 16) & 0xff;
-    uInt8 g = (ourGUIColors[palID][i] >> 8) & 0xff;
-    uInt8 b = ourGUIColors[palID][i] & 0xff;
-
-    myPalette[j] = mapRGB(r, g, b);
-  }
-  FBSurface::setPalette(myPalette);
+  setUIPalette();
 
   myGrabMouse = myOSystem.settings().getBool("grabmouse");
 
@@ -157,11 +142,32 @@ bool FrameBuffer::initialize()
   return true;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void FrameBuffer::setUIPalette()
+{
+  // Set palette for GUI (upper area of array)
+  int palID = 0;
+  if(myOSystem.settings().getString("uipalette") == "classic")
+    palID = 1;
+  else if(myOSystem.settings().getString("uipalette") == "light")
+    palID = 2;
+
+  for(uInt32 i = 0, j = 256; i < kNumColors - 256; ++i, ++j)
+  {
+    uInt8 r = (ourGUIColors[palID][i] >> 16) & 0xff;
+    uInt8 g = (ourGUIColors[palID][i] >> 8) & 0xff;
+    uInt8 b = ourGUIColors[palID][i] & 0xff;
+
+    myPalette[j] = mapRGB(r, g, b);
+  }
+  FBSurface::setPalette(myPalette);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FBInitStatus FrameBuffer::createDisplay(const string& title,
                                         uInt32 width, uInt32 height)
 {
-  myInitializedCount++;
+  ++myInitializedCount;
   myScreenTitle = title;
 
   // A 'windowed' system is defined as one where the window size can be
@@ -201,6 +207,10 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
   const VideoMode& mode = getSavedVidMode(useFullscreen);
   if(width <= mode.screen.w && height <= mode.screen.h)
   {
+    // Changing the video mode can take some time, during which the last
+    // sound played may get 'stuck'
+    // So we mute the sound until the operation completes
+    bool oldMuteState = myOSystem.sound().mute(true);
     if(setVideoMode(myScreenTitle, mode))
     {
       myImageRect = mode.image;
@@ -215,6 +225,8 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
       myOSystem.settings().setValue("fullscreen", fullScreen());
       resetSurfaces();
       setCursorState();
+
+      myOSystem.sound().mute(oldMuteState);
     }
     else
     {
@@ -230,8 +242,8 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
 
   // Create surfaces for TIA statistics and general messages
   myStatsMsg.color = kColorInfo;
-  myStatsMsg.w = font().getMaxCharWidth() * 30 + 3;
-  myStatsMsg.h = (font().getFontHeight() + 2) * 2;
+  myStatsMsg.w = font().getMaxCharWidth() * 40 + 3;
+  myStatsMsg.h = (font().getFontHeight() + 2) * 3;
 
   if(!myStatsMsg.surface)
   {
@@ -260,98 +272,132 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::update()
+void FrameBuffer::update(bool force)
 {
-  // Determine which mode we are in (from the EventHandler)
-  // Take care of S_EMULATE mode here, otherwise let the GUI
-  // figure out what to draw
+  // Onscreen messages are a special case and require different handling than
+  // other objects; they aren't UI dialogs in the normal sense nor are they
+  // TIA images, and they need to be rendered on top of everything
+  // The logic is split in two pieces:
+  //  - at the top of ::update(), to determine whether underlying dialogs
+  //    need to be force-redrawn
+  //  - at the bottom of ::update(), to actually draw them (this must come
+  //    last, since they are always drawn on top of everything else).
+
+  // Full rendering is required when messages are enabled
+  force |= myMsg.counter >= 0;
+
+  // Detect when a message has been turned off; one last redraw is required
+  // in this case, to draw over the area that the message occupied
+  if(myMsg.counter == 0)
+    myMsg.counter = -1;
 
-  invalidate();
   switch(myOSystem.eventHandler().state())
   {
+    case EventHandlerState::NONE:
     case EventHandlerState::EMULATION:
-    {
-      // Run the console for one frame
-      // Note that the debugger can cause a breakpoint to occur, which changes
-      // the EventHandler state 'behind our back' - we need to check for that
-      myOSystem.console().tia().update();
-  #ifdef DEBUGGER_SUPPORT
-      if(myOSystem.eventHandler().state() != EventHandlerState::EMULATION) break;
-  #endif
-      if(myOSystem.eventHandler().frying())
-        myOSystem.console().fry();
-
-      // And update the screen
-      myTIASurface->render();
-
-      // Show frame statistics
-      if(myStatsMsg.enabled)
-        drawFrameStats();
-      else
-        myLastFrameRate = myOSystem.console().getFramerate();
-      myLastScanlines = myOSystem.console().tia().scanlinesLastFrame();
-      myPausedCount = 0;
-      break;  // EventHandlerState::EMULATION
-    }
+      // Do nothing; emulation mode is handled separately (see below)
+      return;
 
     case EventHandlerState::PAUSE:
     {
-      myTIASurface->render();
-
       // Show a pause message immediately and then every 7 seconds
-      if (myPausedCount-- <= 0)
+      if(myPausedCount-- <= 0)
       {
         myPausedCount = uInt32(7 * myOSystem.frameRate());
         showMessage("Paused", MessagePosition::MiddleCenter);
       }
+      if(force)
+        myTIASurface->render();
+
       break;  // EventHandlerState::PAUSE
     }
 
     case EventHandlerState::OPTIONSMENU:
     {
-      myTIASurface->render();
-      myOSystem.menu().draw(true);
+      force |= myOSystem.menu().needsRedraw();
+      if(force)
+      {
+        myTIASurface->render();
+        myOSystem.menu().draw(force);
+      }
       break;  // EventHandlerState::OPTIONSMENU
     }
 
     case EventHandlerState::CMDMENU:
     {
-      myTIASurface->render();
-      myOSystem.commandMenu().draw(true);
+      force |= myOSystem.commandMenu().needsRedraw();
+      if(force)
+      {
+        myTIASurface->render();
+        myOSystem.commandMenu().draw(force);
+      }
       break;  // EventHandlerState::CMDMENU
     }
 
     case EventHandlerState::TIMEMACHINE:
     {
-      myTIASurface->render();
-      myOSystem.timeMachine().draw(true);
+      force |= myOSystem.timeMachine().needsRedraw();
+      if(force)
+      {
+        myTIASurface->render();
+        myOSystem.timeMachine().draw(force);
+      }
       break;  // EventHandlerState::TIMEMACHINE
     }
 
     case EventHandlerState::LAUNCHER:
     {
-      myOSystem.launcher().draw(true);
+      force |= myOSystem.launcher().draw(force);
       break;  // EventHandlerState::LAUNCHER
     }
 
     case EventHandlerState::DEBUGGER:
     {
   #ifdef DEBUGGER_SUPPORT
-      myOSystem.debugger().draw(true);
+      force |= myOSystem.debugger().draw(force);
   #endif
       break;  // EventHandlerState::DEBUGGER
     }
-
-    case EventHandlerState::NONE:
-      return;
   }
 
+  // Draw any pending messages
+  // The logic here determines whether to draw the message
+  // If the message is to be disabled, logic inside the draw method
+  // indicates that, and then the code at the top of this method sees
+  // the change and redraws everything
+  if(myMsg.enabled)
+    force |= drawMessage();
+
+  // Push buffers to screen only when necessary
+  if(force)
+    renderToScreen();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void FrameBuffer::updateInEmulationMode(float framesPerSecond)
+{
+  // Update method that is specifically tailored to emulation mode
+  // Typically called from a thread, so it needs to be separate from
+  // the normal update() method
+  //
+  // We don't worry about selective rendering here; the rendering
+  // always happens at the full framerate
+
+  myTIASurface->render();
+
+  // Show frame statistics
+  if(myStatsMsg.enabled)
+    drawFrameStats(framesPerSecond);
+
+  myLastScanlines = myOSystem.console().tia().frameBufferScanlinesLastFrame();
+  myPausedCount = 0;
+
   // Draw any pending messages
   if(myMsg.enabled)
     drawMessage();
 
-  // Do any post-frame stuff
-  postFrameUpdate();
+  // Push buffers to screen
+  renderToScreen();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -359,12 +405,13 @@ void FrameBuffer::showMessage(const string& message, MessagePosition position,
                               bool force)
 {
   // Only show messages if they've been enabled
-  if(!(force || myOSystem.settings().getBool("uimessages")))
+  if(myMsg.surface == nullptr || !(force || myOSystem.settings().getBool("uimessages")))
     return;
 
   // Precompute the message coordinates
   myMsg.text    = message;
   myMsg.counter = uInt32(myOSystem.frameRate()) << 1; // Show message for 2 seconds
+  if(myMsg.counter == 0)  myMsg.counter = 60;
   myMsg.color   = kBtnTextColor;
 
   myMsg.w = font().getStringWidth(myMsg.text) + 10;
@@ -376,56 +423,51 @@ void FrameBuffer::showMessage(const string& message, MessagePosition position,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::drawFrameStats()
+void FrameBuffer::drawFrameStats(float framesPerSecond)
 {
   const ConsoleInfo& info = myOSystem.console().about();
-  char msg[30];
-  uInt32 color;
-  const int XPOS = 0, YPOS = 0;
-  int xPos = XPOS;
+  int xPos = 2, yPos = 0;
+  const int dy = font().getFontHeight() + 2;
+
+  ostringstream ss;
 
   myStatsMsg.surface->invalidate();
 
-  myStatsMsg.surface->invalidate();
-  string bsinfo = info.BankSwitch +
-    (myOSystem.settings().getBool("dev.settings") ? "| Developer" : "");
-  // draw shadowed text
-  color = myOSystem.console().tia().scanlinesLastFrame() != myLastScanlines ?
-      uInt32(kDbgColorRed) : myStatsMsg.color;
-  std::snprintf(msg, 30, "%3u", myOSystem.console().tia().scanlinesLastFrame());
-  myStatsMsg.surface->drawString(font(), msg, xPos, YPOS,
+  // draw scanlines
+  ColorId color = myOSystem.console().tia().frameBufferScanlinesLastFrame() != myLastScanlines ?
+      kDbgColorRed : myStatsMsg.color;
+
+  ss
+    << myOSystem.console().tia().frameBufferScanlinesLastFrame()
+    << " / "
+    << std::fixed << std::setprecision(1) << myOSystem.console().getFramerate()
+    << "Hz => "
+    << info.DisplayFormat;
+
+  myStatsMsg.surface->drawString(font(), ss.str(), xPos, yPos,
                                  myStatsMsg.w, color, TextAlign::Left, 0, true, kBGColor);
-  xPos += font().getStringWidth(msg);
 
-  std::snprintf(msg, 30, " => %s", info.DisplayFormat.c_str());
-  myStatsMsg.surface->drawString(font(), msg, xPos, YPOS,
-                                 myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
-  xPos += font().getStringWidth(msg);
+  yPos += dy;
+  ss.str("");
 
-  // draw the effective framerate
-  float frameRate;
-  const TimingInfo& ti = myOSystem.timingInfo();
-  // update every ~1 second
-  if(ti.totalFrames - myTotalFrames >= myLastFrameRate)
-  {
-    frameRate = 1000000.0 * (ti.totalFrames - myTotalFrames) / (ti.totalTime - myTotalTime);
-    if(frameRate > myOSystem.console().getFramerate() + 1)
-      frameRate = 1; // check soon again
-    myTotalFrames = ti.totalFrames;
-    myTotalTime = ti.totalTime;
-  }
-  else
-    frameRate = myLastFrameRate;
-  myLastFrameRate = frameRate;
-  std::snprintf(msg, 30, " @%6.2ffps", frameRate);
-  myStatsMsg.surface->drawString(font(), msg, xPos, YPOS,
+  ss
+    << std::fixed << std::setprecision(1) << framesPerSecond
+    << "fps @ "
+    << std::fixed << std::setprecision(0) << 100 * myOSystem.settings().getFloat("speed")
+    << "% speed";
+
+  myStatsMsg.surface->drawString(font(), ss.str(), xPos, yPos,
                                  myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
 
-  // draw bankswitching type
-  myStatsMsg.surface->drawString(font(), bsinfo, XPOS, YPOS + font().getFontHeight(),
+  yPos += dy;
+  ss.str("");
+
+  ss << info.BankSwitch;
+  if (myOSystem.settings().getBool("dev.settings")) ss << "| Developer";
+
+  myStatsMsg.surface->drawString(font(), ss.str(), xPos, yPos,
                                  myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
 
-  myStatsMsg.surface->setDirty();
   myStatsMsg.surface->setDstPos(myImageRect.x() + 10, myImageRect.y() + 8);
   myStatsMsg.surface->render();
 }
@@ -460,13 +502,26 @@ void FrameBuffer::enableMessages(bool enable)
     // Erase old messages on the screen
     myMsg.enabled = false;
     myMsg.counter = 0;
-    update();  // Force update immediately
+    update(true);  // Force update immediately
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-inline void FrameBuffer::drawMessage()
+inline bool FrameBuffer::drawMessage()
 {
+  // Either erase the entire message (when time is reached),
+  // or show again this frame
+  if(myMsg.counter == 0)
+  {
+    myMsg.enabled = false;
+    return true;
+  }
+  else if(myMsg.counter < 0)
+  {
+    myMsg.enabled = false;
+    return false;
+  }
+
   // Draw the bounded box and text
   const GUI::Rect& dst = myMsg.surface->dstRect();
 
@@ -520,23 +575,13 @@ inline void FrameBuffer::drawMessage()
 
   myMsg.surface->setDstPos(myMsg.x + myImageRect.x(), myMsg.y + myImageRect.y());
   myMsg.surface->fillRect(1, 1, myMsg.w-2, myMsg.h-2, kBtnColor);
-#ifndef FLAT_UI
-  myMsg.surface->box(0, 0, myMsg.w, myMsg.h, kColor, kShadowColor);
-#else
   myMsg.surface->frameRect(0, 0, myMsg.w, myMsg.h, kColor);
-#endif
   myMsg.surface->drawString(font(), myMsg.text, 5, 4,
                             myMsg.w, myMsg.color, TextAlign::Left);
+  myMsg.surface->render();
+  myMsg.counter--;
 
-  // Either erase the entire message (when time is reached),
-  // or show again this frame
-  if(myMsg.counter-- > 0)
-  {
-    myMsg.surface->setDirty();
-    myMsg.surface->render();
-  }
-  else
-    myMsg.enabled = false;
+  return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -580,6 +625,8 @@ void FrameBuffer::resetSurfaces()
 
   freeSurfaces();
   reloadSurfaces();
+
+  update(true); // force full update
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -605,11 +652,34 @@ void FrameBuffer::stateChanged(EventHandlerState state)
   // Make sure any onscreen messages are removed
   myMsg.enabled = false;
   myMsg.counter = 0;
+
+  update(true); // force full update
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::setFullscreen(bool enable)
 {
+  // Switching between fullscreen and windowed modes will invariably mean
+  // that the 'window' resolution changes.  Currently, dialogs are not
+  // able to resize themselves when they are actively being shown
+  // (they would have to be closed and then re-opened, etc).
+  // For now, we simply disallow screen switches in such modes
+  switch(myOSystem.eventHandler().state())
+  {
+    case EventHandlerState::EMULATION:
+    case EventHandlerState::LAUNCHER:
+    case EventHandlerState::DEBUGGER:
+    case EventHandlerState::PAUSE:
+      break; // continue with processing (aka, allow a mode switch)
+    default:
+      return;
+  }
+
+  // Changing the video mode can take some time, during which the last
+  // sound played may get 'stuck'
+  // So we mute the sound until the operation completes
+  bool oldMuteState = myOSystem.sound().mute(true);
+
   const VideoMode& mode = getSavedVidMode(enable);
   if(setVideoMode(myScreenTitle, mode))
   {
@@ -626,6 +696,7 @@ void FrameBuffer::setFullscreen(bool enable)
     resetSurfaces();
     setCursorState();
   }
+  myOSystem.sound().mute(oldMuteState);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -653,6 +724,11 @@ bool FrameBuffer::changeWindowedVidMode(int direction)
   else
     return false;
 
+  // Changing the video mode can take some time, during which the last
+  // sound played may get 'stuck'
+  // So we mute the sound until the operation completes
+  bool oldMuteState = myOSystem.sound().mute(true);
+
   const VideoMode& mode = myCurrentModeList->current();
   if(setVideoMode(myScreenTitle, mode))
   {
@@ -665,8 +741,10 @@ bool FrameBuffer::changeWindowedVidMode(int direction)
     resetSurfaces();
     showMessage(mode.description);
     myOSystem.settings().setValue("tia.zoom", mode.zoom);
+    myOSystem.sound().mute(oldMuteState);
     return true;
   }
+  myOSystem.sound().mute(oldMuteState);
 #endif
   return false;
 }
@@ -679,8 +757,8 @@ void FrameBuffer::setCursorState()
   bool emulation =
       myOSystem.eventHandler().state() == EventHandlerState::EMULATION;
   bool analog = myOSystem.hasConsole() ?
-      (myOSystem.eventHandler().controllerIsAnalog(Controller::Left) ||
-       myOSystem.eventHandler().controllerIsAnalog(Controller::Right)) : false;
+      (myOSystem.console().controller(Controller::Left).isAnalog() ||
+       myOSystem.console().controller(Controller::Right).isAnalog()) : false;
   bool alwaysUseMouse = BSPF::equalsIgnoreCase("always", myOSystem.settings().getString("usemouse"));
 
   grabMouse(emulation && (analog || alwaysUseMouse) && myGrabMouse);
@@ -754,9 +832,8 @@ void FrameBuffer::setAvailableVidModes(uInt32 baseWidth, uInt32 baseHeight)
                      myDesktopSize.w, myDesktopSize.h);
 
     // Aspect ratio
-    bool ntsc = myOSystem.console().about().InitialFrameRate == "60";
-    uInt32 aspect = myOSystem.settings().getInt(ntsc ?
-                      "tia.aspectn" : "tia.aspectp");
+    uInt32 aspect = myOSystem.settings().getInt(myOSystem.console().tia().frameLayout() == FrameLayout::ntsc ?
+                                                "tia.aspectn" : "tia.aspectp");
 
     // Figure our the smallest zoom level we can use
     uInt32 firstZoom = 2;
@@ -993,14 +1070,17 @@ void FrameBuffer::VideoModeList::setZoom(uInt32 zoom)
     kTextColor        Normal text color
     kTextColorHi      Highlighted text color
     kTextColorEm      Emphasized text color
-    kTextColorSel     Color for selected text
+    kTextColorInv     Color for selected text
     *** UI elements (dialog and widgets) ***
     kDlgColor         Dialog background
     kWidColor         Widget background
+    kWidColorHi       Widget highlight color
     kWidFrameColor    Border for currently selected widget
     *** Button colors ***
     kBtnColor         Normal button background
     kBtnColorHi       Highlighted button background
+    kBtnBorderColor,
+    kBtnBorderColorHi,
     kBtnTextColor     Normal button font color
     kBtnTextColorHi   Highlighted button font color
     *** Checkbox colors ***
@@ -1008,50 +1088,56 @@ void FrameBuffer::VideoModeList::setZoom(uInt32 zoom)
     *** Scrollbar colors ***
     kScrollColor      Normal scrollbar color
     kScrollColorHi    Highlighted scrollbar color
-    *** Slider colors ***
-    kSliderColor,
-    kSliderColorHi
     *** Debugger colors ***
     kDbgChangedColor      Background color for changed cells
     kDbgChangedTextColor  Text color for changed cells
     kDbgColorHi           Highlighted color in debugger data cells
     kDbgColorRed          Red color in debugger
-    *** Info color ***
-    kColorinfo
+    *** Slider colors ***
+    kSliderColor          Enabled slider
+    kSliderColorHi        Focussed slider
+    kSliderBGColor        Enabled slider background
+    kSliderBGColorHi      Focussed slider background
+    kSliderBGColorLo      Disabled slider background
+    *** Other colors ***
+    kColorInfo            TIA output position color
+    kColorTitleBar        Title bar color
+    kColorTitleText       Title text color
+    kColorTitleBarLo      Disabled title bar color
+    kColorTitleTextLo     Disabled title text color
 */
 uInt32 FrameBuffer::ourGUIColors[3][kNumColors-256] = {
   // Standard
-  { 0x686868, 0x000000, 0xa38c61, 0xdccfa5, 0x404040,
-    0x000000, 0x62a108, 0x9f0000, 0x000000,
-    0xc9af7c, 0xf0f0cf, 0xc80000,
-    0xac3410, 0xd55941, 0xffffff, 0xffd652,
-    0xac3410,
-    0xac3410, 0xd55941,
-    0xac3410, 0xd55941,
-    0xc80000, 0x00ff00, 0xc8c8ff, 0xc80000,
-    0xffffff
+  { 0x686868, 0x000000, 0xa38c61, 0xdccfa5, 0x404040,           // base
+    0x000000, 0xac3410, 0x9f0000, 0xf0f0cf,                     // text
+    0xc9af7c, 0xf0f0cf, 0xd55941, 0xc80000,                     // UI elements
+    0xac3410, 0xd55941, 0x686868, 0xdccfa5, 0xf0f0cf, 0xf0f0cf, // buttons
+    0xac3410,                                                   // checkbox
+    0xac3410, 0xd55941,                                         // scrollbar
+    0xc80000, 0x00ff00, 0xc8c8ff, 0xc80000,                     // debugger
+    0xac3410, 0xd55941, 0xdccfa5, 0xf0f0cf, 0xa38c61,           // slider
+    0xffffff, 0xac3410, 0xf0f0cf, 0x686868, 0xdccfa5            // other
   },
   // Classic
-  { 0x686868, 0x000000, 0x404040, 0x404040, 0x404040,
-    0x20a020, 0x00ff00, 0xc80000, 0x20a020,
-    0x000000, 0x000000, 0xc80000,
-    0x000000, 0x000000, 0x20a020, 0x00ff00,
-    0x20a020,
-    0x20a020, 0x00ff00,
-    0x20a020, 0x00ff00,
-    0xc80000, 0x00ff00, 0xc8c8ff, 0xc80000,
-    0x20a020
+  { 0x686868, 0x000000, 0x404040, 0x404040, 0x404040,           // base
+    0x20a020, 0x00ff00, 0xc80000, 0x000000,                     // text
+    0x000000, 0x000000, 0x00ff00, 0xc80000,                     // UI elements
+    0x000000, 0x000000, 0x686868, 0x00ff00, 0x20a020, 0x00ff00, // buttons
+    0x20a020,                                                   // checkbox
+    0x20a020, 0x00ff00,                                         // scrollbar
+    0xc80000, 0x00ff00, 0xc8c8ff, 0xc80000,                     // debugger
+    0x20a020, 0x00ff00, 0x404040, 0x686868, 0x404040,           // slider
+    0x00ff00, 0x20a020, 0x000000, 0x686868, 0x404040            // other
   },
   // Light
-  {
-    0x808080, 0x000000, 0xc0c0c0, 0xe1e1e1, 0x333333, // base
-    0x000000, 0x0078d7, 0x0078d7, 0xffffff,           // text
-    0xf0f0f0, 0xffffff, 0x0f0f0f,                     // elements
-    0xe1e1e1, 0xe5f1fb, 0x000000, 0x000000,           // buttons
-    0x333333,                                         // checkbox
-    0x808080, 0x0078d7,                               // scrollbar
-    0x333333, 0x0078d7,                               // slider
-    0xffc0c0, 0x000000, 0xe00000, 0xc00000,           // debugger
-    0xffffff                                          // info
+  { 0x808080, 0x000000, 0xc0c0c0, 0xe1e1e1, 0x333333,           // base
+    0x000000, 0xBDDEF9, 0x0078d7, 0x000000,                     // text
+    0xf0f0f0, 0xffffff, 0x0078d7, 0x0f0f0f,                     // UI elements
+    0xe1e1e1, 0xe5f1fb, 0x808080, 0x0078d7, 0x000000, 0x000000, // buttons
+    0x333333,                                                   // checkbox
+    0xc0c0c0, 0x808080,                                         // scrollbar
+    0xffc0c0, 0x000000, 0xe00000, 0xc00000,                     // debugger
+    0x333333, 0x0078d7, 0xc0c0c0, 0xffffff, 0xc0c0c0,           // slider 0xBDDEF9| 0xe1e1e1 | 0xffffff
+    0xffffff, 0x333333, 0xf0f0f0, 0x808080, 0xc0c0c0            // other
   }
 };
