@@ -39,7 +39,7 @@ System::System(const OSystem& osystem, M6502& m6502, M6532& m6532,
     mySystemInAutodetect(false)
 {
   // Re-initialize random generator
-  randGenerator().initSeed();
+  randGenerator().initSeed(uInt32(myOSystem.getTicks()));
 
   // Initialize page access table
   PageAccess access(&myNullDevice, System::PA_READ);
@@ -202,7 +202,6 @@ bool System::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
     out.putLong(myCycles);
     out.putByte(myDataBusState);
 
@@ -232,9 +231,6 @@ bool System::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     myCycles = in.getLong();
     myDataBusState = in.getByte();
 
