@@ -23,6 +23,7 @@
 #include "OSystem.hxx"
 #include "Console.hxx"
 #include "TIA.hxx"
+    #include "PNGLibrary.hxx"
 #include "TIASurface.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -34,7 +35,8 @@ TIASurface::TIASurface(OSystem& system)
     myUsePhosphor(false),
     myPhosphorPercent(0.60f),
     myScanlinesEnabled(false),
-    myPalette(nullptr)
+    myPalette(nullptr),
+    mySaveSnapFlag(false)
 {
   // Load NTSC filter settings
   myNTSCFilter.loadConfig(myOSystem.settings());
@@ -71,10 +73,21 @@ void TIASurface::initialize(const Console& console, const VideoMode& mode)
   mySLineSurface->setDstSize(mode.image.width(), mode.image.height());
 
   // Phosphor mode can be enabled either globally or per-ROM
-  bool p_enable = myOSystem.settings().getString("tv.phosphor") == "always" ||
-      console.properties().get(Display_Phosphor) == "YES";
-  int p_blend = atoi(console.properties().get(Display_PPBlend).c_str());
-  enablePhosphor(p_enable, p_blend);
+  int p_blend = 0;
+  bool enable = false;
+
+  if(myOSystem.settings().getString("tv.phosphor") == "always")
+  {
+    p_blend = myOSystem.settings().getInt("tv.phosblend");
+    enable = true;
+  }
+  else
+  {
+    p_blend = atoi(console.properties().get(Display_PPBlend).c_str());
+    enable = console.properties().get(Display_Phosphor) == "YES";
+  }
+  enablePhosphor(enable, p_blend);
+
   setNTSC(NTSCFilter::Preset(myOSystem.settings().getInt("tv.filter")), false);
 
   // Scanline repeating is sensitive to non-integral vertical resolution,
@@ -138,11 +151,12 @@ const FBSurface& TIASurface::baseSurface(GUI::Rect& rect) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 TIASurface::pixel(uInt32 idx, uInt8 shift)
+uInt32 TIASurface::mapIndexedPixel(uInt8 indexedColor, uInt8 shift)
 {
-  return myPalette[*(myTIA->frameBuffer() + idx) | shift];
+  return myPalette[indexedColor | shift];
 }
 
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::setNTSC(NTSCFilter::Preset preset, bool show)
 {
@@ -205,7 +219,6 @@ uInt32 TIASurface::enableScanlines(int relative, int absolute)
   attr.blendalpha = std::min(100u, attr.blendalpha);
 
   mySLineSurface->applyAttributes();
-  mySLineSurface->setDirty();
 
   return attr.blendalpha;
 }
@@ -216,27 +229,27 @@ void TIASurface::enableScanlineInterpolation(bool enable)
   FBSurface::Attributes& attr = mySLineSurface->attributes();
   attr.smoothing = enable;
   mySLineSurface->applyAttributes();
-  mySLineSurface->setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::enablePhosphor(bool enable, int blend)
 {
+  if(myUsePhosphor == enable && myPhosphorPercent == blend / 100.0f)
+    return;
+
   myUsePhosphor = enable;
   if(blend >= 0)
-    myPhosphorPercent = blend / 100.0;
+    myPhosphorPercent = blend / 100.0f;
   myFilter = Filter(enable ? uInt8(myFilter) | 0x01 : uInt8(myFilter) & 0x10);
 
-  myTiaSurface->setDirty();
-  mySLineSurface->setDirty();
   memset(myRGBFramebuffer, 0, sizeof(myRGBFramebuffer));
 
   // Precalculate the average colors for the 'phosphor' effect
   if(myUsePhosphor)
   {
-    for(Int16 c = 255; c >= 0; c--)
-      for(Int16 p = 255; p >= 0; p--)
-        myPhosphorPalette[c][p] = getPhosphor(c, p);
+    for(int c = 255; c >= 0; c--)
+      for(int p = 255; p >= 0; p--)
+        myPhosphorPalette[c][p] = getPhosphor(uInt8(c), uInt8(p));
 
     myNTSCFilter.setPhosphorPalette(myPhosphorPalette);
   }
@@ -279,8 +292,6 @@ void TIASurface::enableNTSC(bool enable)
   sl_attr.blendalpha = myOSystem.settings().getInt("tv.scanlines");
   mySLineSurface->applyAttributes();
 
-  myTiaSurface->setDirty();
-  mySLineSurface->setDirty();
   memset(myRGBFramebuffer, 0, sizeof(myRGBFramebuffer));
 }
 
@@ -310,6 +321,25 @@ string TIASurface::effectsInfo() const
   return buf.str();
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+inline uInt32 TIASurface::averageBuffers(uInt32 bufOfs)
+{
+  uInt32 c = myRGBFramebuffer[bufOfs];
+  uInt32 p = myPrevRGBFramebuffer[bufOfs];
+
+  // Split into RGB values
+  TO_RGB(c, rc, gc, bc);
+  TO_RGB(p, rp, gp, bp);
+
+  // Mix current calculated buffer with previous calculated buffer (50:50)
+  const uInt8 rn = (rc + rp) / 2;
+  const uInt8 gn = (gc + gp) / 2;
+  const uInt8 bn = (bc + bp) / 2;
+
+  // return averaged value
+  return  (rn << 16) | (gn << 8) | bn;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::render()
 {
@@ -344,6 +374,9 @@ void TIASurface::render()
       uInt8*  tiaIn = myTIA->frameBuffer();
       uInt32* rgbIn = myRGBFramebuffer;
 
+      if (mySaveSnapFlag)
+        memcpy(myPrevRGBFramebuffer, myRGBFramebuffer, width * height * sizeof(uInt32));
+
       uInt32 bufofs = 0, screenofsY = 0, pos;
       for(uInt32 y = height; y ; --y)
       {
@@ -352,9 +385,9 @@ void TIASurface::render()
         {
           // Store back into displayed frame buffer (for next frame)
           rgbIn[bufofs] = out[pos++] = getRGBPhosphor(myPalette[tiaIn[bufofs]], rgbIn[bufofs]);
-          bufofs++;
+          ++bufofs;
           rgbIn[bufofs] = out[pos++] = getRGBPhosphor(myPalette[tiaIn[bufofs]], rgbIn[bufofs]);
-          bufofs++;
+          ++bufofs;
         }
         screenofsY += outPitch;
       }
@@ -369,26 +402,37 @@ void TIASurface::render()
 
     case Filter::BlarggPhosphor:
     {
+      if(mySaveSnapFlag)
+        memcpy(myPrevRGBFramebuffer, myRGBFramebuffer, height * outPitch * sizeof(uInt32));
+
       myNTSCFilter.render(myTIA->frameBuffer(), width, height, out, outPitch << 2, myRGBFramebuffer);
       break;
     }
   }
 
   // Draw TIA image
-  myTiaSurface->setDirty();
   myTiaSurface->render();
 
   // Draw overlaying scanlines
   if(myScanlinesEnabled)
-  {
-    mySLineSurface->setDirty();
     mySLineSurface->render();
+
+  if(mySaveSnapFlag)
+  {
+    myOSystem.png().takeSnapshot();
+    mySaveSnapFlag = false;
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TIASurface::reRender()
+void TIASurface::renderForSnapshot()
 {
+  // TODO: This is currently called from PNGLibrary::takeSnapshot() only
+  // Therefore the code could be simplified.
+  // At some point, we will probably merge some of the functionality.
+  // Furthermore, toggling the variable 'mySaveSnapFlag' in different places
+  // is brittle, especially since rendering can happen in a different thread.
+
   uInt32 width = myTIA->width();
   uInt32 height = myTIA->height();
   uInt32 pos = 0;
@@ -396,38 +440,47 @@ void TIASurface::reRender()
 
   myTiaSurface->basePtr(outPtr, outPitch);
 
+  mySaveSnapFlag = false;
   switch (myFilter)
   {
-    // for non-phosphor modes, render the frame again
+    // For non-phosphor modes, render the frame again
     case Filter::Normal:
     case Filter::BlarggNormal:
       render();
       break;
-    // for phosphor modes, copy the phosphor framebuffer
+
+    // For phosphor modes, copy the phosphor framebuffer
     case Filter::Phosphor:
-      for (uInt32 y = height; y; --y)
+    {
+      uInt32 bufofs = 0, screenofsY = 0;
+      for(uInt32 y = height; y; --y)
       {
-        memcpy(outPtr, myRGBFramebuffer + pos, width);
-        outPtr += outPitch;
-        pos += width;
+        pos = screenofsY;
+        for(uInt32 x = width / 2; x; --x)
+        {
+          outPtr[pos++] = averageBuffers(bufofs++);
+          outPtr[pos++] = averageBuffers(bufofs++);
+        }
+        screenofsY += outPitch;
       }
       break;
+    }
+
     case Filter::BlarggPhosphor:
-      memcpy(outPtr, myRGBFramebuffer, height * outPitch << 2);
+      uInt32 bufofs = 0;
+      for(uInt32 y = height; y; --y)
+        for(uInt32 x = outPitch; x; --x)
+          outPtr[pos++] = averageBuffers(bufofs++);
       break;
   }
 
-  if (myUsePhosphor)
+  if(myUsePhosphor)
   {
     // Draw TIA image
-    myTiaSurface->setDirty();
     myTiaSurface->render();
 
     // Draw overlaying scanlines
-    if (myScanlinesEnabled)
-    {
-      mySLineSurface->setDirty();
+    if(myScanlinesEnabled)
       mySLineSurface->render();
-    }
   }
 }
