@@ -22,7 +22,8 @@
 Playfield::Playfield(uInt32 collisionMask)
   : myCollisionMaskDisabled(collisionMask),
     myCollisionMaskEnabled(0xFFFF),
-    myIsSuppressed(false)
+    myIsSuppressed(false),
+    myTIA(nullptr)
 {
   reset();
 }
@@ -38,9 +39,11 @@ void Playfield::reset()
   myPf1 = 0;
   myPf2 = 0;
 
+  myX = 0;
+
   myObjectColor = myDebugColor = 0;
-  myColorP0 = 0;
-  myColorP1 = 0;
+  myColorLeft = myColorRight = 0;
+  myColorP0 = myColorP1 = 0;
   myColorMode = ColorMode::normal;
   myDebugEnabled = false;
 
@@ -204,6 +207,12 @@ void Playfield::tick(uInt32 x)
   collision = currentPixel ? myCollisionMaskEnabled : myCollisionMaskDisabled;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Playfield::nextLine()
+{
+  collision = myCollisionMaskDisabled;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Playfield::applyColors()
 {
@@ -284,8 +293,6 @@ bool Playfield::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
     out.putInt(collision);
     out.putInt(myCollisionMaskDisabled);
     out.putInt(myCollisionMaskEnabled);
@@ -300,7 +307,7 @@ bool Playfield::save(Serializer& out) const
     out.putByte(myDebugColor);
     out.putBool(myDebugEnabled);
 
-    out.putByte(myColorMode);
+    out.putByte(uInt8(myColorMode));
 
     out.putInt(myPattern);
     out.putInt(myEffectivePattern);
@@ -327,9 +334,6 @@ bool Playfield::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
     collision = in.getInt();
     myCollisionMaskDisabled = in.getInt();
     myCollisionMaskEnabled = in.getInt();
