@@ -23,6 +23,8 @@
 #include "DelayQueueIteratorImpl.hxx"
 #include "TIAConstants.hxx"
 #include "frame-manager/FrameManager.hxx"
+#include "AudioQueue.hxx"
+#include "DispatchResult.hxx"
 
 #ifdef DEBUGGER_SUPPORT
   #include "CartDebug.hxx"
@@ -65,9 +67,8 @@ enum ResxCounter: uInt8 {
 static constexpr uInt8 resxLateHblankThreshold = 73;
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-TIA::TIA(Console& console, Sound& sound, Settings& settings)
+TIA::TIA(Console& console, Settings& settings)
   : myConsole(console),
-    mySound(sound),
     mySettings(settings),
     myFrameManager(nullptr),
     myPlayfield(~CollisionMask::playfield & 0x7FFF),
@@ -116,6 +117,12 @@ void TIA::setFrameManager(AbstractFrameManager *frameManager)
   myFrameManager->setJitterFactor(myJitterFactor);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void TIA::setAudioQueue(shared_ptr<AudioQueue> queue)
+{
+  myAudio.setAudioQueue(queue);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIA::clearFrameManager()
 {
@@ -137,8 +144,7 @@ void TIA::reset()
   myHstate = HState::blank;
   myCollisionMask = 0;
   myLinesSinceChange = 0;
-  myCollisionUpdateRequired = false;
-  myAutoFrameEnabled = false;
+  myCollisionUpdateRequired = myCollisionUpdateScheduled = false;
   myColorLossEnabled = myColorLossActive = false;
   myColorHBlank = 0;
   myLastCycle = 0;
@@ -159,36 +165,40 @@ void TIA::reset()
   myInput0.reset();
   myInput1.reset();
 
+  myAudio.reset();
+
   myTimestamp = 0;
   for (PaddleReader& paddleReader : myPaddleReaders)
     paddleReader.reset(myTimestamp);
 
-  mySound.reset();
   myDelayQueue.reset();
 
-  if (myFrameManager) myFrameManager->reset();
-
   myCyclesAtFrameStart = 0;
 
-  frameReset();  // Recalculate the size of the display
+  if (myFrameManager)
+  {
+    myFrameManager->reset();
+    enableColorLoss(mySettings.getBool(mySettings.getBool("dev.settings") ? "dev.colorloss" : "plr.colorloss"));
+  }
+
+  myFrontBufferScanlines = myFrameBufferScanlines = 0;
+
+  myFramesSinceLastRender = 0;
 
   // Must be done last, after all other items have reset
   enableFixedColors(mySettings.getBool(mySettings.getBool("dev.settings") ? "dev.debugcolors" : "plr.debugcolors"));
   setFixedColorPalette(mySettings.getString("tia.dbgcolors"));
 
+  // Blank the various framebuffers; they may contain graphical garbage
+  memset(myBackBuffer, 0, 160 * TIAConstants::frameBufferHeight);
+  memset(myFrontBuffer, 0, 160 * TIAConstants::frameBufferHeight);
+  memset(myFramebuffer, 0, 160 * TIAConstants::frameBufferHeight);
+
 #ifdef DEBUGGER_SUPPORT
   createAccessBase();
 #endif // DEBUGGER_SUPPORT
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TIA::frameReset()
-{
-  memset(myFramebuffer, 0, 160 * TIAConstants::frameBufferHeight);
-  myAutoFrameEnabled = mySettings.getInt("framerate") <= 0;
-  enableColorLoss(mySettings.getBool("dev.settings") ? "dev.colorloss" : "plr.colorloss");
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIA::install(System& system)
 {
@@ -223,10 +233,6 @@ bool TIA::save(Serializer& out) const
 {
   try
   {
-    out.putString(name());
-
-    if(!mySound.save(out)) return false;
-
     if(!myDelayQueue.save(out))   return false;
     if(!myFrameManager->save(out)) return false;
 
@@ -237,6 +243,7 @@ bool TIA::save(Serializer& out) const
     if(!myPlayer0.save(out))    return false;
     if(!myPlayer1.save(out))    return false;
     if(!myBall.save(out))       return false;
+    if(!myAudio.save(out))      return false;
 
     for (const PaddleReader& paddleReader : myPaddleReaders)
       if(!paddleReader.save(out)) return false;
@@ -253,6 +260,7 @@ bool TIA::save(Serializer& out) const
     out.putInt(myXAtRenderingStart);
 
     out.putBool(myCollisionUpdateRequired);
+    out.putBool(myCollisionUpdateScheduled);
     out.putInt(myCollisionMask);
 
     out.putInt(myMovementClock);
@@ -271,13 +279,14 @@ bool TIA::save(Serializer& out) const
 
     out.putByte(myColorHBlank);
 
-    out.putDouble(myTimestamp);
-
-    out.putBool(myAutoFrameEnabled);
+    out.putLong(myTimestamp);
 
     out.putByteArray(myShadowRegisters, 64);
 
     out.putLong(myCyclesAtFrameStart);
+
+    out.putInt(myFrameBufferScanlines);
+    out.putInt(myFrontBufferScanlines);
   }
   catch(...)
   {
@@ -293,11 +302,6 @@ bool TIA::load(Serializer& in)
 {
   try
   {
-    if(in.getString() != name())
-      return false;
-
-    if(!mySound.load(in)) return false;
-
     if(!myDelayQueue.load(in))   return false;
     if(!myFrameManager->load(in)) return false;
 
@@ -308,6 +312,7 @@ bool TIA::load(Serializer& in)
     if(!myPlayer0.load(in))    return false;
     if(!myPlayer1.load(in))    return false;
     if(!myBall.load(in))       return false;
+    if(!myAudio.load(in))       return false;
 
     for (PaddleReader& paddleReader : myPaddleReaders)
       if(!paddleReader.load(in)) return false;
@@ -324,6 +329,7 @@ bool TIA::load(Serializer& in)
     myXAtRenderingStart = in.getInt();
 
     myCollisionUpdateRequired = in.getBool();
+    myCollisionUpdateScheduled = in.getBool();
     myCollisionMask = in.getInt();
 
     myMovementClock = in.getInt();
@@ -342,13 +348,14 @@ bool TIA::load(Serializer& in)
 
     myColorHBlank = in.getByte();
 
-    myTimestamp = in.getDouble();
-
-    myAutoFrameEnabled = in.getBool();
+    myTimestamp = in.getLong();
 
     in.getByteArray(myShadowRegisters, 64);
 
     myCyclesAtFrameStart = in.getLong();
+
+    myFrameBufferScanlines = in.getInt();
+    myFrontBufferScanlines = in.getInt();
   }
   catch(...)
   {
@@ -394,7 +401,7 @@ void TIA::bindToControllers()
     }
   );
 
-  for (uInt8 i = 0; i < 4; i++)
+  for (uInt8 i = 0; i < 4; ++i)
     updatePaddle(i);
 }
 
@@ -519,33 +526,35 @@ bool TIA::poke(uInt16 address, uInt8 value)
 
       break;
 
-    ////////////////////////////////////////////////////////////
-    // FIXME - rework this when we add the new sound core
     case AUDV0:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel0().audv(value);
       myShadowRegisters[address] = value;
       break;
+
     case AUDV1:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel1().audv(value);
       myShadowRegisters[address] = value;
       break;
+
     case AUDF0:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel0().audf(value);
       myShadowRegisters[address] = value;
       break;
+
     case AUDF1:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel1().audf(value);
       myShadowRegisters[address] = value;
       break;
+
     case AUDC0:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel0().audc(value);
       myShadowRegisters[address] = value;
       break;
+
     case AUDC1:
-      mySound.set(address, value, mySystem->cycles());
+      myAudio.channel1().audc(value);
       myShadowRegisters[address] = value;
       break;
-    ////////////////////////////////////////////////////////////
 
     case HMOVE:
       myDelayQueue.push(HMOVE, value, Delay::hmove);
@@ -775,7 +784,10 @@ bool TIA::saveDisplay(Serializer& out) const
 {
   try
   {
-    out.putByteArray(myFramebuffer, 160*TIAConstants::frameBufferHeight);
+    out.putByteArray(myFramebuffer, 160* TIAConstants::frameBufferHeight);
+    out.putByteArray(myBackBuffer, 160 * TIAConstants::frameBufferHeight);
+    out.putByteArray(myFrontBuffer, 160 * TIAConstants::frameBufferHeight);
+    out.putInt(myFramesSinceLastRender);
   }
   catch(...)
   {
@@ -792,7 +804,10 @@ bool TIA::loadDisplay(Serializer& in)
   try
   {
     // Reset frame buffer pointer and data
-    in.getByteArray(myFramebuffer, 160*TIAConstants::frameBufferHeight);
+    in.getByteArray(myFramebuffer, 160 * TIAConstants::frameBufferHeight);
+    in.getByteArray(myBackBuffer, 160 * TIAConstants::frameBufferHeight);
+    in.getByteArray(myFrontBuffer, 160 * TIAConstants::frameBufferHeight);
+    myFramesSinceLastRender = in.getInt();
   }
   catch(...)
   {
@@ -804,9 +819,31 @@ bool TIA::loadDisplay(Serializer& in)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TIA::update()
+void TIA::update(DispatchResult& result, uInt64 maxCycles)
 {
-  mySystem->m6502().execute(25000);
+  mySystem->m6502().execute(maxCycles, result);
+
+  updateEmulation();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void TIA::renderToFrameBuffer()
+{
+  if (myFramesSinceLastRender == 0) return;
+
+  myFramesSinceLastRender = 0;
+
+  memcpy(myFramebuffer, myFrontBuffer, 160 * TIAConstants::frameBufferHeight);
+
+  myFrameBufferScanlines = myFrontBufferScanlines;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void TIA::update(uInt64 maxCycles)
+{
+  DispatchResult dispatchResult;
+
+  update(dispatchResult, maxCycles);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -927,18 +964,16 @@ bool TIA::toggleCollisions()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool TIA::enableFixedColors(bool enable)
 {
-  // This will be called during reset at a point where no frame manager
-  // instance is available, so we guard aginst this here.
-  int layout = 0;
-  if (myFrameManager) layout = myFrameManager->layout() == FrameLayout::pal ? 1 : 0;
+  int timing = consoleTiming() == ConsoleTiming::ntsc ? 0
+    : consoleTiming() == ConsoleTiming::pal ? 1 : 2;
 
-  myMissile0.setDebugColor(myFixedColorPalette[layout][FixedObject::M0]);
-  myMissile1.setDebugColor(myFixedColorPalette[layout][FixedObject::M1]);
-  myPlayer0.setDebugColor(myFixedColorPalette[layout][FixedObject::P0]);
-  myPlayer1.setDebugColor(myFixedColorPalette[layout][FixedObject::P1]);
-  myBall.setDebugColor(myFixedColorPalette[layout][FixedObject::BL]);
-  myPlayfield.setDebugColor(myFixedColorPalette[layout][FixedObject::PF]);
-  myBackground.setDebugColor(FixedColor::BK_GREY);
+  myMissile0.setDebugColor(myFixedColorPalette[timing][FixedObject::M0]);
+  myMissile1.setDebugColor(myFixedColorPalette[timing][FixedObject::M1]);
+  myPlayer0.setDebugColor(myFixedColorPalette[timing][FixedObject::P0]);
+  myPlayer1.setDebugColor(myFixedColorPalette[timing][FixedObject::P1]);
+  myBall.setDebugColor(myFixedColorPalette[timing][FixedObject::BL]);
+  myPlayfield.setDebugColor(myFixedColorPalette[timing][FixedObject::PF]);
+  myBackground.setDebugColor(myFixedColorPalette[timing][FixedObject::BK]);
 
   myMissile0.enableDebugColors(enable);
   myMissile1.enableDebugColors(enable);
@@ -967,35 +1002,44 @@ bool TIA::setFixedColorPalette(const string& colors)
       case 'r':
         myFixedColorPalette[0][i] = FixedColor::NTSC_RED;
         myFixedColorPalette[1][i] = FixedColor::PAL_RED;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_RED;
         myFixedColorNames[i] = "Red   ";
         break;
       case 'o':
         myFixedColorPalette[0][i] = FixedColor::NTSC_ORANGE;
         myFixedColorPalette[1][i] = FixedColor::PAL_ORANGE;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_ORANGE;
         myFixedColorNames[i] = "Orange";
         break;
       case 'y':
         myFixedColorPalette[0][i] = FixedColor::NTSC_YELLOW;
         myFixedColorPalette[1][i] = FixedColor::PAL_YELLOW;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_YELLOW;
         myFixedColorNames[i] = "Yellow";
         break;
       case 'g':
         myFixedColorPalette[0][i] = FixedColor::NTSC_GREEN;
         myFixedColorPalette[1][i] = FixedColor::PAL_GREEN;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_GREEN;
         myFixedColorNames[i] = "Green ";
         break;
       case 'b':
         myFixedColorPalette[0][i] = FixedColor::NTSC_BLUE;
         myFixedColorPalette[1][i] = FixedColor::PAL_BLUE;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_BLUE;
         myFixedColorNames[i] = "Blue  ";
         break;
       case 'p':
         myFixedColorPalette[0][i] = FixedColor::NTSC_PURPLE;
         myFixedColorPalette[1][i] = FixedColor::PAL_PURPLE;
+        myFixedColorPalette[2][i] = FixedColor::SECAM_PURPLE;
         myFixedColorNames[i] = "Purple";
         break;
     }
   }
+  myFixedColorPalette[0][TIA::BK] = FixedColor::NTSC_GREY;
+  myFixedColorPalette[1][TIA::BK] = FixedColor::PAL_GREY;
+  myFixedColorPalette[2][TIA::BK] = FixedColor::SECAM_GREY;
 
   // If already in fixed debug colours mode, update the current palette
   if(usingFixedColors())
@@ -1080,7 +1124,7 @@ TIA& TIA::updateScanlineByStep()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 TIA& TIA::updateScanlineByTrace(int target)
 {
-  uInt32 count = 100;  // only try up to 100 steps
+  uInt32 count = 10000;  // only try up to 100 steps
   while (mySystem->m6502().getPC() != target && count-- &&
          mySystem->m6502().execute(1));
 
@@ -1141,16 +1185,18 @@ void TIA::onFrameComplete()
   myCyclesAtFrameStart = mySystem->cycles();
 
   if (myXAtRenderingStart > 0)
-    memset(myFramebuffer, 0, myXAtRenderingStart);
+    memset(myBackBuffer, 0, myXAtRenderingStart);
 
   // Blank out any extra lines not drawn this frame
   const Int32 missingScanlines = myFrameManager->missingScanlines();
   if (missingScanlines > 0)
-    memset(myFramebuffer + 160 * myFrameManager->getY(), 0, missingScanlines * 160);
+    memset(myBackBuffer + 160 * myFrameManager->getY(), 0, missingScanlines * 160);
 
-  // Recalculate framerate, attempting to auto-correct for scanline 'jumps'
-  if(myAutoFrameEnabled)
-    myConsole.setFramerate(myFrameManager->frameRate());
+  memcpy(myFrontBuffer, myBackBuffer, 160 * TIAConstants::frameBufferHeight);
+
+  myFrontBufferScanlines = scanlinesLastFrame();
+
+  ++myFramesSinceLastRender;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1164,13 +1210,14 @@ void TIA::onHalt()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIA::cycle(uInt32 colorClocks)
 {
-  for (uInt32 i = 0; i < colorClocks; i++)
+  for (uInt32 i = 0; i < colorClocks; ++i)
   {
     myDelayQueue.execute(
       [this] (uInt8 address, uInt8 value) {delayedWrite(address, value);}
     );
 
-    myCollisionUpdateRequired = false;
+    myCollisionUpdateRequired = myCollisionUpdateScheduled;
+    myCollisionUpdateScheduled = false;
 
     if (myLinesSinceChange < 2) {
       tickMovement();
@@ -1186,7 +1233,11 @@ void TIA::cycle(uInt32 colorClocks)
     if (++myHctr >= 228)
       nextLine();
 
-    myTimestamp++;
+    #ifdef SOUND_SUPPORT
+      myAudio.tick();
+    #endif
+
+    ++myTimestamp;
   }
 }
 
@@ -1209,7 +1260,7 @@ void TIA::tickMovement()
     myMovementInProgress = m;
     myCollisionUpdateRequired = m;
 
-    myMovementClock++;
+    ++myMovementClock;
   }
 }
 
@@ -1259,7 +1310,7 @@ void TIA::applyRsync()
 
   myHctrDelta = 225 - myHctr;
   if (myFrameManager->isRendering())
-    memset(myFramebuffer + myFrameManager->getY() * 160 + x, 0, 160 - x);
+    memset(myBackBuffer + myFrameManager->getY() * 160 + x, 0, 160 - x);
 
   myHctr = 225;
 }
@@ -1271,15 +1322,20 @@ void TIA::nextLine()
     cloneLastLine();
   }
 
-  myPlayfield.tick(0);
   myHctr = 0;
 
-  if (!myMovementInProgress && myLinesSinceChange < 2) myLinesSinceChange++;
+  if (!myMovementInProgress && myLinesSinceChange < 2) ++myLinesSinceChange;
 
   myHstate = HState::blank;
   myHctrDelta = 0;
 
   myFrameManager->nextLine();
+  myMissile0.nextLine();
+  myMissile1.nextLine();
+  myPlayer0.nextLine();
+  myPlayer1.nextLine();
+  myBall.nextLine();
+  myPlayfield.nextLine();
 
   if (myFrameManager->isRendering() && myFrameManager->getY() == 0) flushLineCache();
 
@@ -1293,11 +1349,17 @@ void TIA::cloneLastLine()
 
   if (!myFrameManager->isRendering() || y == 0) return;
 
-  uInt8* buffer = myFramebuffer;
+  uInt8* buffer = myBackBuffer;
 
   memcpy(buffer + y * 160, buffer + (y-1) * 160, 160);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void TIA::scheduleCollisionUpdate()
+{
+  myCollisionUpdateScheduled = true;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIA::updateCollision()
 {
@@ -1366,7 +1428,7 @@ void TIA::renderPixel(uInt32 x, uInt32 y)
     }
   }
 
-  myFramebuffer[y * 160 + x] = color;
+  myBackBuffer[y * 160 + x] = color;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1379,7 +1441,7 @@ void TIA::flushLineCache()
   if (wasCaching) {
     const auto rewindCycles = myHctr;
 
-    for (myHctr = 0; myHctr < rewindCycles; myHctr++) {
+    for (myHctr = 0; myHctr < rewindCycles; ++myHctr) {
       if (myHstate == HState::blank)
         tickHblank();
       else
@@ -1392,7 +1454,7 @@ void TIA::flushLineCache()
 void TIA::clearHmoveComb()
 {
   if (myFrameManager->isRendering() && myHstate == HState::blank)
-    memset(myFramebuffer + myFrameManager->getY() * 160, myColorHBlank, 8);
+    memset(myBackBuffer + myFrameManager->getY() * 160, myColorHBlank, 8);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1535,7 +1597,7 @@ void TIA::updatePaddle(uInt8 idx)
   }
 
   myPaddleReaders[idx].update(
-    (resistance == Controller::maximumResistance) ? -1 : (double(resistance) / Paddles::MAX_RESISTANCE),
+    (resistance == Controller::MAX_RESISTANCE) ? -1 : (double(resistance) / Paddles::MAX_RESISTANCE),
     myTimestamp,
     consoleTiming()
   );
