@@ -28,7 +28,7 @@ ColorWidget::ColorWidget(GuiObject* boss, const GUI::Font& font,
                          int x, int y, int w, int h, int cmd)
   : Widget(boss, font, x, y, w, h),
     CommandSender(boss),
-    _color(0),
+    _color(kNone),
     _cmd(cmd),
     _crossGrid(false)
 {
@@ -36,7 +36,7 @@ ColorWidget::ColorWidget(GuiObject* boss, const GUI::Font& font,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void ColorWidget::setColor(int color)
+void ColorWidget::setColor(ColorId color)
 {
   _color = color;
   setDirty();
@@ -46,29 +46,18 @@ void ColorWidget::setColor(int color)
 void ColorWidget::drawWidget(bool hilite)
 {
   FBSurface& s = dialog().surface();
+  bool onTop = _boss->dialog().isOnTop();
 
   // Draw a thin frame around us.
-#ifndef FLAT_UI
-  s.hLine(_x, _y, _x + _w - 1, kColor);
-  s.hLine(_x, _y +_h, _x + _w - 1, kShadowColor);
-  s.vLine(_x, _y, _y+_h, kColor);
-  s.vLine(_x + _w - 1, _y, _y +_h - 1, kShadowColor);
-#else
   s.frameRect(_x, _y, _w, _h + 1, kColor);
-#endif
 
   // Show the currently selected color
-  s.fillRect(_x+1, _y+1, _w-2, _h-1, isEnabled() ? _color : kWidColor);
+  s.fillRect(_x+1, _y+1, _w-2, _h-1, onTop ? isEnabled() ? _color : kWidColor : kBGColorLo);
 
   // Cross out the grid?
   if(_crossGrid)
   {
-#ifndef FLAT_UI
-    for(uInt32 row = 1; row < 4; ++row)
-      s.hLine(_x, _y + (row * _h/4), _x + _w - 2, kColor);
-#else
     s.line(_x + 1, _y + 1, _x + _w - 2, _y + _h - 1, kColor);
     s.line(_x + _w - 2, _y + 1, _x + 1, _y + _h - 1, kColor);
-#endif
   }
 }
