@@ -28,7 +28,7 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ContextMenu::ContextMenu(GuiObject* boss, const GUI::Font& font,
                          const VariantList& items, int cmd, int width)
-  : Dialog(boss->instance(), boss->parent()),
+  : Dialog(boss->instance(), boss->parent(), font),
     CommandSender(boss),
     _rowHeight(font.getLineHeight()),
     _firstEntry(0),
@@ -39,7 +39,6 @@ ContextMenu::ContextMenu(GuiObject* boss, const GUI::Font& font,
     _isScrolling(false),
     _scrollUpColor(kColor),
     _scrollDnColor(kColor),
-    _font(font),
     _cmd(cmd),
     _xorig(0),
     _yorig(0),
@@ -60,11 +59,7 @@ void ContextMenu::addItems(const VariantList& items)
     maxwidth = std::max(maxwidth, _font.getStringWidth(e.first));
 
   _x = _y = 0;
-#ifndef FLAT_UI
-  _w = maxwidth + 15;
-#else
   _w = maxwidth + 23;
-#endif
   _h = 1;  // recalculate this in ::recalc()
 
   _scrollUpColor = _firstEntry > 0 ? kScrollColor : kColor;
@@ -106,18 +101,18 @@ void ContextMenu::recalc(const GUI::Rect& image)
 {
   // Now is the time to adjust the height
   // If it's higher than the screen, we need to scroll through
-  uInt32 maxentries = std::min(18u, (image.height() - 4) / _rowHeight);
+  uInt32 maxentries = std::min(18u, (image.height() - 2) / _rowHeight);
   if(_entries.size() > maxentries)
   {
     // We show two less than the max, so we have room for two scroll buttons
     _numEntries = maxentries - 2;
-    _h = maxentries * _rowHeight + 4;
+    _h = maxentries * _rowHeight + 2;
     _showScroll = true;
   }
   else
   {
     _numEntries = int(_entries.size());
-    _h = int(_entries.size()) * _rowHeight + 4;
+    _h = int(_entries.size()) * _rowHeight + 2;
     _showScroll = false;
   }
   _isScrolling = false;
@@ -551,52 +546,38 @@ void ContextMenu::drawDialog()
   // by the ScummVM guys, so I'm not going to mess with it.
   FBSurface& s = surface();
 
-  if(_dirty)
+  // Draw menu border and background
+  s.fillRect(_x+1, _y+1, _w-2, _h-2, kWidColor);
+  s.frameRect(_x, _y, _w, _h, kTextColor);
+
+  // Draw the entries, taking scroll buttons into account
+  int x = _x + 1, y = _y + 1, w = _w - 2;
+
+  // Show top scroll area
+  int offset = _selectedOffset;
+  if(_showScroll)
   {
-    // Draw menu border and background
-    s.fillRect(_x+1, _y+1, _w-2, _h-2, kWidColor);
-#ifndef FLAT_UI
-    s.box(_x, _y, _w, _h, kColor, kShadowColor);
-
-    // Draw the entries, taking scroll buttons into account
-    int x = _x + 2, y = _y + 2, w = _w - 4;
-#else
-    s.frameRect(_x, _y, _w, _h, kTextColor);
-
-    // Draw the entries, taking scroll buttons into account
-    int x = _x + 1, y = _y + 1, w = _w - 2;
-#endif
-
-    // Show top scroll area
-    int offset = _selectedOffset;
-    if(_showScroll)
-    {
-      s.hLine(x, y+_rowHeight-1, w+2, kShadowColor);
-      s.drawBitmap(up_arrow, ((_w-_x)>>1)-4, (_rowHeight>>1)+y-4, _scrollUpColor, 8);
-      y += _rowHeight;
-      offset--;
-    }
-
-    for(int i = _firstEntry, current = 0; i < _firstEntry + _numEntries; ++i, ++current)
-    {
-      bool hilite = offset == current;
-      if(hilite) s.fillRect(x, y, w, _rowHeight, kTextColorHi);
-      s.drawString(_font, _entries[i].first, x + 1, y + 2, w,
-                   !hilite ? kTextColor : kWidColor);
-      y += _rowHeight;
-    }
-
-    // Show bottom scroll area
-    if(_showScroll)
-    {
-      s.hLine(x, y, w+2, kShadowColor);
-      s.drawBitmap(down_arrow, ((_w-_x)>>1)-4, (_rowHeight>>1)+y-4, _scrollDnColor, 8);
-    }
-
-    s.setDirty();
-    _dirty = false;
+    s.hLine(x, y+_rowHeight-1, w+2, kColor);
+    s.drawBitmap(up_arrow, ((_w-_x)>>1)-4, (_rowHeight>>1)+y-4, _scrollUpColor, 8);
+    y += _rowHeight;
+    offset--;
   }
 
-  // Commit surface changes to screen
-  s.render();
+  for(int i = _firstEntry, current = 0; i < _firstEntry + _numEntries; ++i, ++current)
+  {
+    bool hilite = offset == current;
+    if(hilite) s.fillRect(x, y, w, _rowHeight, kTextColorHi);
+    s.drawString(_font, _entries[i].first, x + 1, y + 2, w,
+                 !hilite ? kTextColor : kTextColorInv);
+    y += _rowHeight;
+  }
+
+  // Show bottom scroll area
+  if(_showScroll)
+  {
+    s.hLine(x, y, w+2, kColor);
+    s.drawBitmap(down_arrow, ((_w-_x)>>1)-4, (_rowHeight>>1)+y-4, _scrollDnColor, 8);
+  }
+
+  setDirty();
 }
