@@ -23,7 +23,6 @@
 #include "SaveKey.hxx"
 #include "AtariVox.hxx"
 #include "Settings.hxx"
-#include "EventMappingWidget.hxx"
 #include "EditTextWidget.hxx"
 #include "PopUpWidget.hxx"
 #include "RadioButtonWidget.hxx"
@@ -31,21 +30,23 @@
 #include "TabWidget.hxx"
 #include "Widget.hxx"
 #include "Font.hxx"
-#ifdef DEBUGGER_SUPPORT
-#include "DebuggerDialog.hxx"
-#endif
 #include "Console.hxx"
 #include "TIA.hxx"
 #include "OSystem.hxx"
 #include "StateManager.hxx"
 #include "RewindManager.hxx"
 #include "M6502.hxx"
+#ifdef DEBUGGER_SUPPORT
+  #include "Debugger.hxx"
+  #include "CartDebug.hxx"
+  #include "DebuggerDialog.hxx"
+#endif
 #include "DeveloperDialog.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 DeveloperDialog::DeveloperDialog(OSystem& osystem, DialogContainer& parent,
                                  const GUI::Font& font, int max_w, int max_h)
-  : Dialog(osystem, parent)
+  : Dialog(osystem, parent, font, "Developer settings")
 {
   const int VGAP = 4;
   const int lineHeight = font.getLineHeight(),
@@ -55,18 +56,21 @@ DeveloperDialog::DeveloperDialog(OSystem& osystem, DialogContainer& parent,
 
   // Set real dimensions
   _w = std::min(53 * fontWidth + 10, max_w);
-  _h = std::min(15 * (lineHeight + VGAP) + 14, max_h);
+  _h = std::min(15 * (lineHeight + VGAP) + 14 + _th, max_h);
 
   // The tab widget
   xpos = 2; ypos = 4;
-  myTab = new TabWidget(this, font, xpos, ypos, _w - 2 * xpos, _h - buttonHeight - 16 - ypos);
+  myTab = new TabWidget(this, font, xpos, ypos + _th, _w - 2 * xpos, _h - _th - buttonHeight - 16 - ypos);
   addTabWidget(myTab);
 
   addEmulationTab(font);
   addVideoTab(font);
   addTimeMachineTab(font);
   addDebuggerTab(font);
-  addDefaultOKCancelButtons(font);
+
+  WidgetArray wid;
+  addDefaultsOKCancelBGroup(wid, font);
+  addBGroupToFocusList(wid);
 
   // Activate the first tab
   myTab->setActiveTab(0);
@@ -96,7 +100,7 @@ void DeveloperDialog::addEmulationTab(const GUI::Font& font)
   wid.push_back(r);
   ypos += lineHeight + VGAP * 1;
 
-  myFrameStatsWidget = new CheckboxWidget(myTab, font, HBORDER + INDENT * 1, ypos + 1, "Frame statistics");
+  myFrameStatsWidget = new CheckboxWidget(myTab, font, HBORDER + INDENT * 1, ypos + 1, "Console info overlay");
   wid.push_back(myFrameStatsWidget);
   ypos += lineHeight + VGAP;
 
@@ -129,7 +133,6 @@ void DeveloperDialog::addEmulationTab(const GUI::Font& font)
   ypos += lineHeight + VGAP;
 
   // Randomize CPU
-  lwidth = font.getStringWidth("Randomize CPU ");
   myRandomizeCPULabel = new StaticTextWidget(myTab, font, HBORDER + INDENT * 2, ypos + 1, "Randomize CPU ");
   wid.push_back(myRandomizeCPULabel);
 
@@ -150,6 +153,13 @@ void DeveloperDialog::addEmulationTab(const GUI::Font& font)
   wid.push_back(myUndrivenPinsWidget);
   ypos += lineHeight + VGAP;
 
+#ifdef DEBUGGER_SUPPORT
+  myRWPortBreakWidget = new CheckboxWidget(myTab, font, HBORDER + INDENT * 1, ypos + 1,
+                                           "Break on reads from write ports");
+  wid.push_back(myRWPortBreakWidget);
+  ypos += lineHeight + VGAP;
+#endif
+
   // Thumb ARM emulation exception
   myThumbExceptionWidget = new CheckboxWidget(myTab, font, HBORDER + INDENT * 1, ypos + 1,
                                               "Fatal ARM emulation error throws exception");
@@ -182,7 +192,6 @@ void DeveloperDialog::addVideoTab(const GUI::Font& font)
   int tabID = myTab->addTab("Video");
 
   wid.clear();
-  ypos = VBORDER;
 
   // settings set
   mySettingsGroup1 = new RadioButtonGroup();
@@ -201,15 +210,14 @@ void DeveloperDialog::addVideoTab(const GUI::Font& font)
   wid.push_back(myTVJitterWidget);
   myTVJitterRecWidget = new SliderWidget(myTab, font,
                                          myTVJitterWidget->getRight() + fontWidth * 3, ypos - 1,
-                                         8 * fontWidth, lineHeight, "Recovery ",
-                                         font.getStringWidth("Recovery "), kTVJitterChanged);
+                                         "Recovery ", 0, kTVJitterChanged);
   myTVJitterRecWidget->setMinValue(1); myTVJitterRecWidget->setMaxValue(20);
+  myTVJitterRecWidget->setTickmarkInterval(5);
   wid.push_back(myTVJitterRecWidget);
   myTVJitterRecLabelWidget = new StaticTextWidget(myTab, font,
                                                   myTVJitterRecWidget->getRight() + 4,
                                                   myTVJitterRecWidget->getTop() + 2,
-                                                  5 * fontWidth, fontHeight, "", TextAlign::Left);
-  wid.push_back(myTVJitterRecLabelWidget);
+                                                  5 * fontWidth, fontHeight, "");
   ypos += lineHeight + VGAP;
 
   myColorLossWidget = new CheckboxWidget(myTab, font, HBORDER + INDENT * 1, ypos + 1,
@@ -258,7 +266,7 @@ void DeveloperDialog::addVideoTab(const GUI::Font& font)
   // Add message concerning usage
   const GUI::Font& infofont = instance().frameBuffer().infoFont();
   ypos = myTab->getHeight() - 5 - fontHeight - infofont.getFontHeight() - 10;
-  new StaticTextWidget(myTab, infofont, HBORDER, ypos, "(*) colors identical for player and developer settings");
+  new StaticTextWidget(myTab, infofont, HBORDER, ypos, "(*) Colors identical for player and developer settings");
 
   // Add items for tab 2
   addToFocusList(wid, myTab, tabID);
@@ -310,8 +318,10 @@ void DeveloperDialog::addTimeMachineTab(const GUI::Font& font)
   const int VBORDER = 8;
   const int VGAP = 4;
   int ypos = VBORDER;
-  int lineHeight = font.getLineHeight();
-  int fontHeight = font.getFontHeight();
+  int lineHeight = font.getLineHeight(),
+    fontHeight = font.getFontHeight(),
+    fontWidth = font.getMaxCharWidth(),
+    lwidth = fontWidth * 11;
   WidgetArray wid;
   VariantList items;
   int tabID = myTab->addTab("Time Machine");
@@ -332,25 +342,23 @@ void DeveloperDialog::addTimeMachineTab(const GUI::Font& font)
   wid.push_back(myTimeMachineWidget);
   ypos += lineHeight + VGAP;
 
-  int sWidth = font.getMaxCharWidth() * 8;
-  myStateSizeWidget = new SliderWidget(myTab, font, HBORDER + INDENT * 2, ypos - 1, sWidth, lineHeight,
-                                       "Buffer size (*)   ", 0, kSizeChanged);
+  int swidth = fontWidth * 12 + 5; // width of PopUpWidgets below
+  myStateSizeWidget = new SliderWidget(myTab, font, HBORDER + INDENT * 2, ypos - 1, swidth, lineHeight,
+                                       "Buffer size (*)   ", 0, kSizeChanged, lwidth, " states");
   myStateSizeWidget->setMinValue(20);
   myStateSizeWidget->setMaxValue(1000);
   myStateSizeWidget->setStepValue(20);
+  myStateSizeWidget->setTickmarkInterval(5);
   wid.push_back(myStateSizeWidget);
-  myStateSizeLabelWidget = new StaticTextWidget(myTab, font, myStateSizeWidget->getRight() + 4,
-                                                myStateSizeWidget->getTop() + 2, "100 ");
   ypos += lineHeight + VGAP;
 
-  myUncompressedWidget = new SliderWidget(myTab, font, HBORDER + INDENT * 2, ypos - 1, sWidth, lineHeight,
-                                          "Uncompressed size ", 0, kUncompressedChanged);
+  myUncompressedWidget = new SliderWidget(myTab, font, HBORDER + INDENT * 2, ypos - 1, swidth, lineHeight,
+                                          "Uncompressed size ", 0, kUncompressedChanged, lwidth, " states");
   myUncompressedWidget->setMinValue(0);
   myUncompressedWidget->setMaxValue(1000);
   myUncompressedWidget->setStepValue(20);
+  myUncompressedWidget->setTickmarkInterval(5);
   wid.push_back(myUncompressedWidget);
-  myUncompressedLabelWidget = new StaticTextWidget(myTab, font, myUncompressedWidget->getRight() + 4,
-                                                   myUncompressedWidget->getTop() + 2, "50  ");
   ypos += lineHeight + VGAP;
 
   items.clear();
@@ -412,10 +420,10 @@ void DeveloperDialog::addDebuggerTab(const GUI::Font& font)
 
   // Font style (bold label vs. text, etc)
   items.clear();
-  VarList::push_back(items, "All Normal font", "0");
+  VarList::push_back(items, "All normal font", "0");
   VarList::push_back(items, "Bold labels only", "1");
   VarList::push_back(items, "Bold non-labels only", "2");
-  VarList::push_back(items, "All Bold font", "3");
+  VarList::push_back(items, "All bold font", "3");
   pwidth = font.getStringWidth("Bold non-labels only");
   myDebuggerFontStyle =
     new PopUpWidget(myTab, font, HBORDER, ypos + 1, pwidth, lineHeight, items,
@@ -424,36 +432,30 @@ void DeveloperDialog::addDebuggerTab(const GUI::Font& font)
 
   ypos += lineHeight + VGAP * 4;
 
-  pwidth = font.getMaxCharWidth() * 8;
   // Debugger width and height
-  myDebuggerWidthSlider = new SliderWidget(myTab, font, xpos, ypos-1, pwidth,
-                                           lineHeight, "Debugger width (*)  ",
-                                           0, kDWidthChanged);
+  myDebuggerWidthSlider = new SliderWidget(myTab, font, xpos, ypos-1, "Debugger width (*)  ",
+                                           0, 0, 6 * fontWidth, "px");
   myDebuggerWidthSlider->setMinValue(DebuggerDialog::kSmallFontMinW);
   myDebuggerWidthSlider->setMaxValue(ds.w);
   myDebuggerWidthSlider->setStepValue(10);
+  // one tickmark every ~100 pixel
+  myDebuggerWidthSlider->setTickmarkInterval((ds.w - DebuggerDialog::kSmallFontMinW + 50) / 100);
   wid.push_back(myDebuggerWidthSlider);
-  myDebuggerWidthLabel =
-    new StaticTextWidget(myTab, font,
-                         xpos + myDebuggerWidthSlider->getWidth() + 4,
-                         ypos + 1, 4 * fontWidth, fontHeight, "", TextAlign::Left);
   ypos += lineHeight + VGAP;
 
-  myDebuggerHeightSlider = new SliderWidget(myTab, font, xpos, ypos-1, pwidth,
-                                            lineHeight, "Debugger height (*) ",
-                                            0, kDHeightChanged);
+  myDebuggerHeightSlider = new SliderWidget(myTab, font, xpos, ypos-1, "Debugger height (*) ",
+                                            0, 0, 6 * fontWidth, "px");
   myDebuggerHeightSlider->setMinValue(DebuggerDialog::kSmallFontMinH);
   myDebuggerHeightSlider->setMaxValue(ds.h);
   myDebuggerHeightSlider->setStepValue(10);
+  // one tickmark every ~100 pixel
+  myDebuggerHeightSlider->setTickmarkInterval((ds.h - DebuggerDialog::kSmallFontMinH + 50) / 100);
   wid.push_back(myDebuggerHeightSlider);
-  myDebuggerHeightLabel =
-    new StaticTextWidget(myTab, font,
-                         xpos + myDebuggerHeightSlider->getWidth() + 4,
-                         ypos + 1, 4 * fontWidth, fontHeight, "", TextAlign::Left);
-
   ypos += lineHeight + VGAP * 4;
+
   myGhostReadsTrapWidget = new CheckboxWidget(myTab, font, HBORDER, ypos + 1,
-                                             "Trap on 'ghost' reads", kGhostReads);
+                                             "Trap on 'ghost' reads");
+  wid.push_back(myGhostReadsTrapWidget);
 
   // Add message concerning usage
   const GUI::Font& infofont = instance().frameBuffer().infoFont();
@@ -471,13 +473,8 @@ void DeveloperDialog::addDebuggerTab(const GUI::Font& font)
   if(!debuggerAvailable)
   {
     myDebuggerWidthSlider->clearFlags(WIDGET_ENABLED);
-    myDebuggerWidthLabel->clearFlags(WIDGET_ENABLED);
     myDebuggerHeightSlider->clearFlags(WIDGET_ENABLED);
-    myDebuggerHeightLabel->clearFlags(WIDGET_ENABLED);
   }
-
-  // Add items for tab 1
-  addToFocusList(wid, myTab, tabID);
 #else
   new StaticTextWidget(myTab, font, 0, 20, _w - 20, font.getFontHeight(),
                        "Debugger support not included", TextAlign::Center);
@@ -486,25 +483,10 @@ void DeveloperDialog::addDebuggerTab(const GUI::Font& font)
   addToFocusList(wid, myTab, tabID);
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void DeveloperDialog::addDefaultOKCancelButtons(const GUI::Font& font)
-{
-  const int buttonWidth = font.getStringWidth("Defaults") + 20,
-    buttonHeight = font.getLineHeight() + 4;
-  WidgetArray wid;
-
-  wid.clear();
-  ButtonWidget* btn = new ButtonWidget(this, font, 10, _h - buttonHeight - 10,
-                                       buttonWidth, buttonHeight, "Defaults", GuiObject::kDefaultsCmd);
-  wid.push_back(btn);
-  addOKCancelBGroup(wid, font);
-  addBGroupToFocusList(wid);
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DeveloperDialog::loadSettings(SettingsSet set)
 {
-  string prefix = set == SettingsSet::player ? "plr." : "dev.";
+  const string& prefix = set == SettingsSet::player ? "plr." : "dev.";
 
   myFrameStats[set] = instance().settings().getBool(prefix + "stats");
   myConsole[set] = instance().settings().getString(prefix + "console") == "7800" ? 1 : 0;
@@ -514,6 +496,10 @@ void DeveloperDialog::loadSettings(SettingsSet set)
   myRandomizeCPU[set] = instance().settings().getString(prefix + "cpurandom");
   // Undriven TIA pins
   myUndrivenPins[set] = instance().settings().getBool(prefix + "tiadriven");
+#ifdef DEBUGGER_SUPPORT
+  // Read from write ports break
+  myRWPortBreak[set] = instance().settings().getBool(prefix + "rwportbreak");
+#endif
   // Thumb ARM emulation exception
   myThumbException[set] = instance().settings().getBool(prefix + "thumb.trapfatal");
   // AtariVox/SaveKey EEPROM access
@@ -538,7 +524,7 @@ void DeveloperDialog::loadSettings(SettingsSet set)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DeveloperDialog::saveSettings(SettingsSet set)
 {
-  string prefix = set == SettingsSet::player ? "plr." : "dev.";
+  const string& prefix = set == SettingsSet::player ? "plr." : "dev.";
 
   instance().settings().setValue(prefix + "stats", myFrameStats[set]);
   instance().settings().setValue(prefix + "console", myConsole[set] == 1 ? "7800" : "2600");
@@ -548,6 +534,10 @@ void DeveloperDialog::saveSettings(SettingsSet set)
   instance().settings().setValue(prefix + "cpurandom", myRandomizeCPU[set]);
   // Undriven TIA pins
   instance().settings().setValue(prefix + "tiadriven", myUndrivenPins[set]);
+#ifdef DEBUGGER_SUPPORT
+  // Read from write ports break
+  instance().settings().setValue(prefix + "rwportbreak", myRWPortBreak[set]);
+#endif
   // Thumb ARM emulation exception
   instance().settings().setValue(prefix + "thumb.trapfatal", myThumbException[set]);
   // AtariVox/SaveKey EEPROM access
@@ -585,6 +575,10 @@ void DeveloperDialog::getWidgetStates(SettingsSet set)
   myRandomizeCPU[set] = cpurandom;
   // Undriven TIA pins
   myUndrivenPins[set] = myUndrivenPinsWidget->getState();
+#ifdef DEBUGGER_SUPPORT
+  // Read from write ports break
+  myRWPortBreak[set] = myRWPortBreakWidget->getState();
+#endif
   // Thumb ARM emulation exception
   myThumbException[set] = myThumbExceptionWidget->getState();
   // AtariVox/SaveKey EEPROM access
@@ -622,6 +616,10 @@ void DeveloperDialog::setWidgetStates(SettingsSet set)
     myRandomizeCPUWidget[i]->setState(BSPF::containsIgnoreCase(cpurandom, cpuregs[i]));
   // Undriven TIA pins
   myUndrivenPinsWidget->setState(myUndrivenPins[set]);
+#ifdef DEBUGGER_SUPPORT
+  // Read from write ports break
+  myRWPortBreakWidget->setState(myRWPortBreak[set]);
+#endif
   // Thumb ARM emulation exception
   myThumbExceptionWidget->setState(myThumbException[set]);
   // AtariVox/SaveKey EEPROM access
@@ -680,9 +678,7 @@ void DeveloperDialog::loadConfig()
   w = ds.w; h = ds.h;
 
   myDebuggerWidthSlider->setValue(w);
-  myDebuggerWidthLabel->setValue(w);
   myDebuggerHeightSlider->setValue(h);
-  myDebuggerHeightLabel->setValue(h);
 
   // Debugger font size
   string size = instance().settings().getString("dbg.fontsize");
@@ -752,6 +748,10 @@ void DeveloperDialog::saveConfig()
   instance().settings().setValue("dbg.ghostreadstrap", myGhostReadsTrapWidget->getState());
   if(instance().hasConsole())
     instance().console().system().m6502().setGhostReadsTrap(myGhostReadsTrapWidget->getState());
+
+  // Read from write ports break
+  if(instance().hasConsole())
+    instance().console().system().m6502().setReadFromWritePortBreak(myRWPortBreakWidget->getState());
 #endif
 }
 
@@ -768,10 +768,14 @@ void DeveloperDialog::setDefaults()
       myConsole[set] = 0;
       // Randomization
       myRandomBank[set] = devSettings ? true : false;
-      myRandomizeRAM[set] = devSettings ? true : false;
-      myRandomizeCPU[set] = devSettings ? "SAXYP" : "";
+      myRandomizeRAM[set] = true;
+      myRandomizeCPU[set] = devSettings ? "SAXYP" : "AXYP";
       // Undriven TIA pins
       myUndrivenPins[set] = devSettings ? true : false;
+    #ifdef DEBUGGER_SUPPORT
+      // Reads from write ports
+      myRWPortBreak[set] = devSettings ? true : false;
+    #endif
       // Thumb ARM emulation exception
       myThumbException[set] = devSettings ? true : false;
       // AtariVox/SaveKey EEPROM access
@@ -809,9 +813,7 @@ void DeveloperDialog::setDefaults()
       uInt32 w = std::min(instance().frameBuffer().desktopSize().w, uInt32(DebuggerDialog::kMediumFontMinW));
       uInt32 h = std::min(instance().frameBuffer().desktopSize().h, uInt32(DebuggerDialog::kMediumFontMinH));
       myDebuggerWidthSlider->setValue(w);
-      myDebuggerWidthLabel->setValue(w);
       myDebuggerHeightSlider->setValue(h);
-      myDebuggerHeightLabel->setValue(h);
       myDebuggerFontSize->setSelected("medium");
       myDebuggerFontStyle->setSelected("0");
 
@@ -901,14 +903,6 @@ void DeveloperDialog::handleCommand(CommandSender* sender, int cmd, int data, in
       break;
 
 #ifdef DEBUGGER_SUPPORT
-    case kDWidthChanged:
-      myDebuggerWidthLabel->setValue(myDebuggerWidthSlider->getValue());
-      break;
-
-    case kDHeightChanged:
-      myDebuggerHeightLabel->setValue(myDebuggerHeightSlider->getValue());
-      break;
-
     case kDFontSizeChanged:
       handleFontSize();
       break;
@@ -981,11 +975,7 @@ void DeveloperDialog::handleTimeMachine()
   bool enable = myTimeMachineWidget->getState();
 
   myStateSizeWidget->setEnabled(enable);
-  myStateSizeLabelWidget->setEnabled(enable);
-
   myUncompressedWidget->setEnabled(enable);
-  myUncompressedLabelWidget->setEnabled(enable);
-
   myStateIntervalWidget->setEnabled(enable);
 
   uInt32 size = myStateSizeWidget->getValue();
@@ -1010,7 +1000,6 @@ void DeveloperDialog::handleSize()
   if(horizon == -1)
     horizon = 0;
 
-  myStateSizeLabelWidget->setValue(size);
   // adapt horizon and interval
   do
   {
@@ -1024,7 +1013,7 @@ void DeveloperDialog::handleSize()
       }
     }
     if(!found)
-      interval--;
+      --interval;
   } while(!found);
 
   if(size < uncompressed)
@@ -1040,8 +1029,6 @@ void DeveloperDialog::handleUncompressed()
   uInt32 size = myStateSizeWidget->getValue();
   uInt32 uncompressed = myUncompressedWidget->getValue();
 
-  myUncompressedLabelWidget->setValue(myUncompressedWidget->getValue());
-
   if(size < uncompressed)
     myStateSizeWidget->setValue(uncompressed);
   myStateHorizonWidget->setEnabled(myTimeMachineWidget->getState() && size > uncompressed);
@@ -1136,7 +1123,7 @@ void DeveloperDialog::handleDebugColours(int idx, int color)
     return;
   }
 
-  static constexpr int dbg_color[2][DEBUG_COLORS] = {
+  static constexpr ColorId dbg_color[3][DEBUG_COLORS] = {
     {
       TIA::FixedColor::NTSC_RED,
       TIA::FixedColor::NTSC_ORANGE,
@@ -1152,11 +1139,21 @@ void DeveloperDialog::handleDebugColours(int idx, int color)
       TIA::FixedColor::PAL_GREEN,
       TIA::FixedColor::PAL_PURPLE,
       TIA::FixedColor::PAL_BLUE
+    },
+    {
+      TIA::FixedColor::SECAM_RED,
+      TIA::FixedColor::SECAM_ORANGE,
+      TIA::FixedColor::SECAM_YELLOW,
+      TIA::FixedColor::SECAM_GREEN,
+      TIA::FixedColor::SECAM_PURPLE,
+      TIA::FixedColor::SECAM_BLUE
     }
   };
 
-  int mode = instance().console().tia().frameLayout() == FrameLayout::ntsc ? 0 : 1;
-  myDbgColourSwatch[idx]->setColor(dbg_color[mode][color]);
+  int timing = instance().console().tia().consoleTiming() == ConsoleTiming::ntsc ? 0
+    : instance().console().tia().consoleTiming() == ConsoleTiming::pal ? 1 : 2;
+
+  myDbgColourSwatch[idx]->setColor(dbg_color[timing][color]);
   myDbgColour[idx]->setSelectedIndex(color);
 
   // make sure the selected debug colors are all different
@@ -1168,7 +1165,7 @@ void DeveloperDialog::handleDebugColours(int idx, int color)
     usedCol[i] = false;
     for(int j = 0; j < DEBUG_COLORS; ++j)
     {
-      if(myDbgColourSwatch[j]->getColor() == dbg_color[mode][i])
+      if(myDbgColourSwatch[j]->getColor() == dbg_color[timing][i])
       {
         usedCol[i] = true;
         break;
@@ -1178,14 +1175,14 @@ void DeveloperDialog::handleDebugColours(int idx, int color)
   // check if currently changed color was used somewhere else
   for(int i = 0; i < DEBUG_COLORS; ++i)
   {
-    if (i != idx && myDbgColourSwatch[i]->getColor() == dbg_color[mode][color])
+    if (i != idx && myDbgColourSwatch[i]->getColor() == dbg_color[timing][color])
     {
       // if already used, change the other color to an unused one
       for(int j = 0; j < DEBUG_COLORS; ++j)
       {
         if(!usedCol[j])
         {
-          myDbgColourSwatch[i]->setColor(dbg_color[mode][j]);
+          myDbgColourSwatch[i]->setColor(dbg_color[timing][j]);
           myDbgColour[i]->setSelectedIndex(j);
           break;
         }
@@ -1201,12 +1198,12 @@ void DeveloperDialog::handleDebugColours(const string& colors)
   {
     switch(colors[i])
     {
-      case 'r':  handleDebugColours(i, 0);  break;
-      case 'o':  handleDebugColours(i, 1);  break;
-      case 'y':  handleDebugColours(i, 2);  break;
-      case 'g':  handleDebugColours(i, 3);  break;
-      case 'p':  handleDebugColours(i, 4);  break;
-      case 'b':  handleDebugColours(i, 5);  break;
+      case 'r': handleDebugColours(i, 0);  break;
+      case 'o': handleDebugColours(i, 1);  break;
+      case 'y': handleDebugColours(i, 2);  break;
+      case 'g': handleDebugColours(i, 3);  break;
+      case 'p': handleDebugColours(i, 4);  break;
+      case 'b': handleDebugColours(i, 5);  break;
       default:                              break;
     }
   }
@@ -1239,16 +1236,10 @@ void DeveloperDialog::handleFontSize()
 
   myDebuggerWidthSlider->setMinValue(minW);
   if(minW > uInt32(myDebuggerWidthSlider->getValue()))
-  {
     myDebuggerWidthSlider->setValue(minW);
-    myDebuggerWidthLabel->setValue(minW);
-  }
 
   myDebuggerHeightSlider->setMinValue(minH);
   if(minH > uInt32(myDebuggerHeightSlider->getValue()))
-  {
     myDebuggerHeightSlider->setValue(minH);
-    myDebuggerHeightLabel->setValue(minH);
-  }
 #endif
 }
