@@ -27,9 +27,14 @@
 #include "Dialog.hxx"
 #include "Widget.hxx"
 #include "TabWidget.hxx"
+
+#include "ContextMenu.hxx"
+#include "PopUpWidget.hxx"
 #include "Settings.hxx"
 #include "Console.hxx"
+
 #include "Vec.hxx"
+#include "TIA.hxx"
 
 /*
  * TODO list
@@ -40,19 +45,33 @@
  * ...
  */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Dialog::Dialog(OSystem& instance, DialogContainer& parent,
-               int x, int y, int w, int h)
+Dialog::Dialog(OSystem& instance, DialogContainer& parent, const GUI::Font& font,
+               const string& title, int x, int y, int w, int h)
   : GuiObject(instance, parent, *this, x, y, w, h),
+    _font(font),
     _mouseWidget(nullptr),
     _focusedWidget(nullptr),
     _dragWidget(nullptr),
+    _defaultWidget(nullptr),
     _okWidget(nullptr),
     _cancelWidget(nullptr),
     _visible(false),
+    _onTop(true),
     _processCancel(false),
+    _title(title),
+    _th(0),
     _surface(nullptr),
     _tabID(0),
     _flags(WIDGET_ENABLED | WIDGET_BORDER | WIDGET_CLEARBG)
+{
+  setTitle(title);
+  setDirty();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+Dialog::Dialog(OSystem& instance, DialogContainer& parent,
+               int x, int y, int w, int h)
+  : Dialog(instance, parent, instance.frameBuffer().font(), "", x, y, w, h)
 {
 }
 
@@ -69,7 +88,7 @@ Dialog::~Dialog()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::open(bool refresh)
+void Dialog::open()
 {
   // Make sure we have a valid surface to draw into
   // Technically, this shouldn't be needed until drawDialog(), but some
@@ -86,10 +105,12 @@ void Dialog::open(bool refresh)
   buildCurrentFocusList();
 
   _visible = true;
+
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::close(bool refresh)
+void Dialog::close()
 {
   if (_mouseWidget)
   {
@@ -102,17 +123,52 @@ void Dialog::close(bool refresh)
   _visible = false;
 
   parent().removeDialog();
+  setDirty();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Dialog::setTitle(const string& title)
+{
+  _title = title;
+  _h -= _th;
+  if(title.empty())
+    _th = 0;
+  else
+    _th = _font.getLineHeight() + 4;
+  _h += _th;
+
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::center()
 {
-  if(_surface)
+  const GUI::Size& screen = instance().frameBuffer().screenSize();
+  const GUI::Rect& dst = _surface->dstRect();
+  _surface->setDstPos((screen.w - dst.width()) >> 1, (screen.h - dst.height()) >> 1);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool Dialog::render()
+{
+  if(!_dirty || !isVisible())
+    return false;
+
+  // Draw this dialog
+  center();
+  drawDialog();
+
+  // Update dialog surface; also render any extra surfaces
+  // Extra surfaces must be rendered afterwards, so they are drawn on top
+  if(_surface->render())
   {
-    const GUI::Size& screen = instance().frameBuffer().screenSize();
-    const GUI::Rect& dst = _surface->dstRect();
-    _surface->setDstPos((screen.w - dst.width()) >> 1, (screen.h - dst.height()) >> 1);
+    mySurfaceStack.applyAll([](shared_ptr<FBSurface>& surface){
+      surface->render();
+    });
   }
+  _dirty = false;
+
+  return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -270,54 +326,45 @@ void Dialog::drawDialog()
 
   FBSurface& s = surface();
 
-  if(_dirty)
+  // Dialog is still on top if e.g a ContextMenu is opened
+  _onTop = parent().myDialogStack.top() == this
+    || (parent().myDialogStack.get(parent().myDialogStack.size() - 2) == this
+    && !parent().myDialogStack.top()->hasTitle());
+
+  if(_flags & WIDGET_CLEARBG)
   {
-    if(_flags & WIDGET_CLEARBG)
-      //    cerr << "Dialog::drawDialog(): w = " << _w << ", h = " << _h << " @ " << &s << endl << endl;
-      s.fillRect(_x, _y, _w, _h, kDlgColor);
-    else
-      s.invalidate();
-    if(_flags & WIDGET_BORDER)
-#ifndef FLAT_UI
-      s.box(_x, _y, _w, _h, kColor, kShadowColor);
-#else
-      s.frameRect(_x, _y, _w, _h, kColor);
-#endif // !FLAT_UI
-
-    // Make all child widget dirty
-    Widget* w = _firstWidget;
-    Widget::setDirtyInChain(w);
-
-    // Draw all children
-    w = _firstWidget;
-    while(w)
+    //    cerr << "Dialog::drawDialog(): w = " << _w << ", h = " << _h << " @ " << &s << endl << endl;
+    s.fillRect(_x, _y + _th, _w, _h - _th, _onTop ? kDlgColor : kBGColorLo);
+    if(_th)
     {
-      w->draw();
-      w = w->_next;
+      s.fillRect(_x, _y, _w, _th, _onTop ? kColorTitleBar : kColorTitleBarLo);
+      s.drawString(_font, _title, _x + 10, _y + 2 + 1, _font.getStringWidth(_title),
+                   _onTop ? kColorTitleText : kColorTitleTextLo);
     }
-
-    // Draw outlines for focused widgets
-    // Don't change focus, since this will trigger lost and received
-    // focus events
-    if(_focusedWidget)
-      _focusedWidget = Widget::setFocusForChain(this, getFocusList(),
-                          _focusedWidget, 0, false);
-
-    // Tell the surface(s) this area is dirty
-    s.setDirty();
-
-    _dirty = false;
   }
+  else
+    s.invalidate();
+  if(_flags & WIDGET_BORDER) // currently only used by Dialog itself
+    s.frameRect(_x, _y, _w, _h, _onTop ? kColor : kShadowColor);
 
-  // Commit surface changes to screen; also render any extra surfaces
-  // Extra surfaces must be rendered afterwards, so they are drawn on top
-  if(s.render())
+  // Make all child widget dirty
+  Widget* w = _firstWidget;
+  Widget::setDirtyInChain(w);
+
+  // Draw all children
+  w = _firstWidget;
+  while(w)
   {
-    mySurfaceStack.applyAll([](shared_ptr<FBSurface>& surface){
-      surface->setDirty();
-      surface->render();
-    });
+    w->draw();
+    w = w->_next;
   }
+
+  // Draw outlines for focused widgets
+  // Don't change focus, since this will trigger lost and received
+  // focus events
+  if(_focusedWidget)
+    _focusedWidget = Widget::setFocusForChain(this, getFocusList(),
+                        _focusedWidget, 0, false);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -666,23 +713,30 @@ Widget* Dialog::findWidget(int x, int y) const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
                                const string& okText, const string& cancelText,
-                               bool focusOKButton)
+                               bool focusOKButton, int buttonWidth)
 {
-  int buttonWidth = std::max(font.getStringWidth("Cancel"),
-                    std::max(font.getStringWidth(okText),
-                    font.getStringWidth(okText))) + 15;
+  const int HBORDER = 10;
+  const int VBORDER = 10;
+  const int BTN_BORDER = 20;
+  const int BUTTON_GAP = 8;
+  buttonWidth = std::max(buttonWidth,
+                         std::max(font.getStringWidth("Defaults"),
+                         std::max(font.getStringWidth(okText),
+                         font.getStringWidth(cancelText))) + BTN_BORDER);
   int buttonHeight = font.getLineHeight() + 4;
 
-#ifndef BSPF_MAC_OSX
-  addOKWidget(new ButtonWidget(this, font, _w - 2 * (buttonWidth + 7),
-      _h - buttonHeight - 10, buttonWidth, buttonHeight, okText, GuiObject::kOKCmd));
-  addCancelWidget(new ButtonWidget(this, font, _w - (buttonWidth + 10),
-      _h - buttonHeight - 10, buttonWidth, buttonHeight, cancelText, GuiObject::kCloseCmd));
+  _w = std::max(HBORDER * 2 + buttonWidth * 2 + BUTTON_GAP, _w);
+
+#ifndef BSPF_MACOS
+  addOKWidget(new ButtonWidget(this, font, _w - 2 * buttonWidth - HBORDER - BUTTON_GAP,
+      _h - buttonHeight - VBORDER, buttonWidth, buttonHeight, okText, GuiObject::kOKCmd));
+  addCancelWidget(new ButtonWidget(this, font, _w - (buttonWidth + HBORDER),
+      _h - buttonHeight - VBORDER, buttonWidth, buttonHeight, cancelText, GuiObject::kCloseCmd));
 #else
-  addCancelWidget(new ButtonWidget(this, font, _w - 2 * (buttonWidth + 7),
-      _h - buttonHeight - 10, buttonWidth, buttonHeight, cancelText, GuiObject::kCloseCmd));
-  addOKWidget(new ButtonWidget(this, font, _w - (buttonWidth + 10),
-      _h - buttonHeight - 10, buttonWidth, buttonHeight, okText, GuiObject::kOKCmd));
+  addCancelWidget(new ButtonWidget(this, font, _w - 2 * buttonWidth - HBORDER - BUTTON_GAP,
+      _h - buttonHeight - VBORDER, buttonWidth, buttonHeight, cancelText, GuiObject::kCloseCmd));
+  addOKWidget(new ButtonWidget(this, font, _w - (buttonWidth + HBORDER),
+      _h - buttonHeight - VBORDER, buttonWidth, buttonHeight, okText, GuiObject::kOKCmd));
 #endif
 
   // Note that 'focusOKButton' only takes effect when there are no other UI
@@ -701,6 +755,25 @@ void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
   }
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Dialog::addDefaultsOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
+                                       const string& okText, const string& cancelText,
+                                       const string& defaultsText,
+                                       bool focusOKButton)
+{
+  const int HBORDER = 10;
+  const int VBORDER = 10;
+  const int BTN_BORDER = 20;
+  int buttonWidth = font.getStringWidth(defaultsText) + BTN_BORDER;
+  int buttonHeight = font.getLineHeight() + 4;
+
+  addDefaultWidget(new ButtonWidget(this, font, HBORDER, _h - buttonHeight - VBORDER,
+                   buttonWidth, buttonHeight, defaultsText, GuiObject::kDefaultsCmd));
+  wid.push_back(_defaultWidget);
+
+  addOKCancelBGroup(wid, font, okText, cancelText, focusOKButton, buttonWidth);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::TabFocus::appendFocusList(WidgetArray& list)
 {
@@ -727,28 +800,20 @@ Widget* Dialog::TabFocus::getNewFocus()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool Dialog::getResizableBounds(uInt32& w, uInt32& h) const
+bool Dialog::getDynamicBounds(uInt32& w, uInt32& h) const
 {
   const GUI::Rect& r = instance().frameBuffer().imageRect();
 
-  double scaleFactor = 0.8;
-  if(instance().hasConsole())
-  {
-    bool ntsc = instance().console().about().InitialFrameRate == "60";
-    uInt32 aspect = instance().settings().getInt(ntsc ?"tia.aspectn" : "tia.aspectp");
-    scaleFactor = aspect / 100.0;
-  }
-
   if(r.width() <= FrameBuffer::kFBMinW || r.height() <= FrameBuffer::kFBMinH)
   {
-    w = uInt32(scaleFactor * FrameBuffer::kTIAMinW) * 2;
-    h = FrameBuffer::kTIAMinH * 2;
+    w = r.width();
+    h = r.height();
     return false;
   }
   else
   {
-    w = std::max(uInt32(scaleFactor * r.width()), uInt32(FrameBuffer::kFBMinW));
-    h = std::max(uInt32(scaleFactor * r.height()), uInt32(FrameBuffer::kFBMinH));
+    w = uInt32(0.95 * r.width());
+    h = uInt32(0.95 * r.height());
     return true;
   }
 }
