@@ -48,19 +48,19 @@ DialogContainer::~DialogContainer()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DialogContainer::updateTime(uInt64 time)
 {
-  // We only need millisecond precision
-  myTime = time / 1000;
-
   if(myDialogStack.empty())
     return;
 
+  // We only need millisecond precision
+  myTime = time / 1000;
+
   // Check for pending continuous events and send them to the active dialog box
   Dialog* activeDialog = myDialogStack.top();
 
   // Key still pressed
-  if(myCurrentKeyDown.keycode != 0 && myKeyRepeatTime < myTime)
+  if(myCurrentKeyDown.key != KBDK_UNKNOWN && myKeyRepeatTime < myTime)
   {
-    activeDialog->handleKeyDown(myCurrentKeyDown.keycode, myCurrentKeyDown.flags);
+    activeDialog->handleKeyDown(myCurrentKeyDown.key, myCurrentKeyDown.mod);
     myKeyRepeatTime = myTime + kRepeatSustainDelay;
   }
 
@@ -98,19 +98,31 @@ void DialogContainer::updateTime(uInt64 time)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void DialogContainer::draw(bool full)
+bool DialogContainer::draw(bool full)
 {
-  // Draw all the dialogs on the stack when we want a full refresh
+  if(myDialogStack.empty())
+    return false;
+
+  // Make the top dialog dirty if a full redraw is requested
   if(full)
-  {
-    myDialogStack.applyAll([](Dialog*& d){
-      d->center();
+    myDialogStack.top()->setDirty();
+
+  // If the top dialog is dirty, then all below it must be redrawn too
+  bool dirty = needsRedraw();
+
+  myDialogStack.applyAll([&](Dialog*& d){
+    if(dirty)
       d->setDirty();
-      d->drawDialog();
-    });
-  }
-  else if(!myDialogStack.empty())
-    myDialogStack.top()->drawDialog();
+    full |= d->render();
+  });
+
+  return full;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool DialogContainer::needsRedraw() const
+{
+  return !myDialogStack.empty() ? myDialogStack.top()->isDirty() : false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -121,14 +133,21 @@ void DialogContainer::addDialog(Dialog* d)
     myOSystem.frameBuffer().showMessage(
         "Unable to show dialog box; FIX THE CODE");
   else
+  {
+    d->setDirty();
     myDialogStack.push(d);
+  }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DialogContainer::removeDialog()
 {
   if(!myDialogStack.empty())
+  {
     myDialogStack.pop();
+    if(!myDialogStack.empty())
+      myDialogStack.top()->setDirty();
+  }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -136,9 +155,9 @@ void DialogContainer::reStack()
 {
   // Pop all items from the stack, and then add the base menu
   while(!myDialogStack.empty())
-    myDialogStack.top()->close(false);  // don't force a refresh
+    myDialogStack.top()->close();
 
-  myBaseDialog->open(false);  // don't force a refresh
+  myBaseDialog->open();
 
   // Reset all continuous events
   reset();
@@ -165,8 +184,8 @@ void DialogContainer::handleKeyEvent(StellaKey key, StellaMod mod, bool state)
   Dialog* activeDialog = myDialogStack.top();
   if(state)
   {
-    myCurrentKeyDown.keycode = key;
-    myCurrentKeyDown.flags   = mod;
+    myCurrentKeyDown.key = key;
+    myCurrentKeyDown.mod = mod;
     myKeyRepeatTime = myTime + kRepeatInitialDelay;
 
     activeDialog->handleKeyDown(key, mod);
@@ -176,8 +195,8 @@ void DialogContainer::handleKeyEvent(StellaKey key, StellaMod mod, bool state)
     activeDialog->handleKeyUp(key, mod);
 
     // Only stop firing events if it's the current key
-    if (key == myCurrentKeyDown.keycode)
-      myCurrentKeyDown.keycode = KBDK_UNKNOWN;
+    if(key == myCurrentKeyDown.key)
+      myCurrentKeyDown.key = KBDK_UNKNOWN;
   }
 }
 
@@ -271,7 +290,7 @@ void DialogContainer::handleMouseButtonEvent(MouseButton b, bool pressed,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void DialogContainer::handleJoyEvent(int stick, int button, uInt8 state)
+void DialogContainer::handleJoyBtnEvent(int stick, int button, uInt8 state)
 {
   if(myDialogStack.empty())
     return;
@@ -344,7 +363,8 @@ void DialogContainer::handleJoyHatEvent(int stick, int hat, JoyHat value)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DialogContainer::reset()
 {
-  myCurrentKeyDown.keycode = KBDK_UNKNOWN;
+  myCurrentKeyDown.key = KBDK_UNKNOWN;
+  myCurrentKeyDown.mod = KBDM_NONE;
   myCurrentMouseDown.b = MouseButton::NONE;
   myLastClick.x = myLastClick.y = 0;
   myLastClick.time = 0;
