@@ -210,12 +210,8 @@ void TabWidget::handleMouseLeft()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TabWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
 {
-  switch(cmd)
-  {
-    default:
-      sendCommand(cmd, data, _id);
-      break;
-  }
+  // Command is not inspected; simply forward it to the caller
+  sendCommand(cmd, data, _id);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -253,29 +249,6 @@ void TabWidget::loadConfig()
   updateActiveTab();
 }
 
-#ifndef FLAT_UI
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TabWidget::box(int x, int y, int width, int height,
-                    uInt32 colorA, uInt32 colorB, bool omitBottom)
-{
-  //cerr << "TabWidget::box\n";
-  FBSurface& s = _boss->dialog().surface();
-
-  s.hLine(x + 1, y, x + width - 2, colorA);
-  s.hLine(x, y + 1, x + width - 1, colorA);
-  s.vLine(x, y + 1, y + height - (omitBottom ? 1 : 2), colorA);
-  s.vLine(x + 1, y, y + height - (omitBottom ? 2 : 1), colorA);
-
-  if (!omitBottom)
-  {
-    s.hLine(x + 1, y + height - 2, x + width - 1, colorB);
-    s.hLine(x + 1, y + height - 1, x + width - 2, colorB);
-  }
-  s.vLine(x + width - 1, y + 1, y + height - (omitBottom ? 1 : 2), colorB);
-  s.vLine(x + width - 2, y + 1, y + height - (omitBottom ? 2 : 1), colorB);
-}
-#endif
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TabWidget::drawWidget(bool hilite)
 {
@@ -285,61 +258,35 @@ void TabWidget::drawWidget(bool hilite)
   Widget::setDirtyInChain(_tabs[_activeTab].firstWidget);
 
   FBSurface& s = dialog().surface();
-
-  const int left1  = _x + 1;
-  const int right1 = _x + kTabLeftOffset + _activeTab * (_tabWidth + kTabSpacing);
-  const int left2  = right1 + _tabWidth;
-  const int right2 = _x + _w - 2;
-
-#ifndef FLAT_UI
-  // Draw horizontal line
-  s.hLine(left1, _y + _tabHeight - 2, right1, kShadowColor);
-  s.hLine(left2, _y + _tabHeight - 2, right2, kShadowColor);
-#endif
+  bool onTop = _boss->dialog().isOnTop();
 
   // Iterate over all tabs and draw them
   int i, x = _x + kTabLeftOffset;
   for (i = 0; i < int(_tabs.size()); ++i)
   {
-    uInt32 fontcolor = _tabs[i].enabled ? kTextColor : kColor;
-#ifndef FLAT_UI
-    uInt32 boxcolor = (i == _activeTab) ? kColor : kShadowColor;
-    int yOffset = (i == _activeTab) ? 0 : 2;
-    box(x, _y + yOffset, _tabWidth, _tabHeight - yOffset, boxcolor, boxcolor, (i == _activeTab));
-    s.drawString(_font, _tabs[i].title, x + kTabPadding,
-                 _y + yOffset / 2 + (_tabHeight - _fontHeight - 1),
-                 _tabWidth - 2 * kTabPadding, fontcolor, TextAlign::Center);
-#else
+    ColorId fontcolor = _tabs[i].enabled && onTop? kTextColor : kColor;
     int yOffset = (i == _activeTab) ? 0 : 1;
-    s.fillRect(x, _y + 1, _tabWidth, _tabHeight - 1, (i == _activeTab)
-               ? kDlgColor : kBGColorHi); // ? kWidColor : kDlgColor
+    s.fillRect(x, _y + 1, _tabWidth, _tabHeight - 1,
+              (i == _activeTab)
+               ? onTop ? kDlgColor : kBGColorLo
+               : onTop ? kBGColorHi : kDlgColor); // ? kWidColor : kDlgColor
     s.drawString(_font, _tabs[i].title, x + kTabPadding + yOffset,
                  _y + yOffset + (_tabHeight - _fontHeight - 1),
                  _tabWidth - 2 * kTabPadding, fontcolor, TextAlign::Center);
     if(i == _activeTab)
     {
-      s.hLine(x, _y, x + _tabWidth - 1, kWidColor);
-      s.vLine(x + _tabWidth, _y + 1, _y + _tabHeight - 1, kBGColorLo);
+      s.hLine(x, _y, x + _tabWidth - 1, onTop ? kWidColor : kDlgColor);
+      s.vLine(x + _tabWidth, _y + 1, _y + _tabHeight - 1, onTop ? kBGColorLo : kColor);
     }
     else
-      s.hLine(x, _y + _tabHeight, x + _tabWidth, kWidColor);
-#endif
+      s.hLine(x, _y + _tabHeight, x + _tabWidth, onTop ? kWidColor : kDlgColor);
+
     x += _tabWidth + kTabSpacing;
   }
 
-#ifndef FLAT_UI
-  // Draw a frame around the widget area (belows the tabs)
-  s.hLine(left1, _y + _tabHeight - 1, right1, kColor);
-  s.hLine(left2, _y + _tabHeight - 1, right2, kColor);
-  s.hLine(_x+1, _y + _h - 2, _x + _w - 2, kShadowColor);
-  s.hLine(_x+1, _y + _h - 1, _x + _w - 2, kColor);
-  s.vLine(_x + _w - 2, _y + _tabHeight - 1, _y + _h - 2, kColor);
-  s.vLine(_x + _w - 1, _y + _tabHeight - 1, _y + _h - 2, kShadowColor);
-#else
   // fill empty right space
-  s.hLine(x - kTabSpacing + 1, _y + _tabHeight, _x + _w - 1, kWidColor);
-  s.hLine(_x, _y + _h - 1, _x + _w - 1, kBGColorLo);
-#endif
+  s.hLine(x - kTabSpacing + 1, _y + _tabHeight, _x + _w - 1, onTop ? kWidColor : kDlgColor);
+  s.hLine(_x, _y + _h - 1, _x + _w - 1, onTop ? kBGColorLo : kColor);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
