@@ -16,6 +16,7 @@
 //============================================================================
 
 #include "bspf.hxx"
+#include "BrowserDialog.hxx"
 #include "Dialog.hxx"
 #include "OSystem.hxx"
 #include "FrameBuffer.hxx"
@@ -23,6 +24,7 @@
 #include "ListWidget.hxx"
 #include "PopUpWidget.hxx"
 #include "ScrollBarWidget.hxx"
+#include "EditTextWidget.hxx"
 #include "Settings.hxx"
 #include "TabWidget.hxx"
 #include "Widget.hxx"
@@ -35,114 +37,40 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 UIDialog::UIDialog(OSystem& osystem, DialogContainer& parent,
                    const GUI::Font& font)
-  : Dialog(osystem, parent)
+  : Dialog(osystem, parent, font, "User interface settings"),
+    myFont(font)
 {
   const GUI::Font& ifont = instance().frameBuffer().infoFont();
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
             fontHeight   = font.getFontHeight(),
-            buttonWidth  = font.getStringWidth("Defaults") + 20,
+            buttonWidth  = font.getStringWidth("Image path" + ELLIPSIS) + 20 + 1,
             buttonHeight = font.getLineHeight() + 4;
-  const int vBorder = 5;
+
+  const int VBORDER = 8;
+  const int HBORDER = 10;
+  const int INDENT = 16;
   int xpos, ypos, tabID;
-  int lwidth, pwidth = font.getStringWidth("Standard");
+  int lwidth, pwidth;
   WidgetArray wid;
   VariantList items;
-  ButtonWidget* b;
   const GUI::Size& ds = instance().frameBuffer().desktopSize();
 
   // Set real dimensions
-  _w = 37 * fontWidth + 10;
-  _h = 11 * (lineHeight + 4) + 10;
+  _w = (39+15) * fontWidth + 10 * 2;
+  _h = (10+1) * (lineHeight + 4) + VBORDER + _th;
 
   // The tab widget
-  xpos = ypos = vBorder;
-  myTab = new TabWidget(this, font, xpos, ypos, _w - 2*xpos, _h - buttonHeight - 20);
+  myTab = new TabWidget(this, font, 2, 4 + _th, _w - 2*2, _h - _th - buttonHeight - 20);
   addTabWidget(myTab);
 
   //////////////////////////////////////////////////////////
-  // 1) Launcher options
-  tabID = myTab->addTab(" Launcher ");
-  lwidth = font.getStringWidth("Exit to Launcher ");
-
-  // Launcher width and height
-  myLauncherWidthSlider = new SliderWidget(myTab, font, xpos, ypos, pwidth,
-                                           lineHeight, "Launcher Width ",
-                                           lwidth, kLWidthChanged);
-  myLauncherWidthSlider->setMinValue(FrameBuffer::kFBMinW);
-  myLauncherWidthSlider->setMaxValue(ds.w);
-  myLauncherWidthSlider->setStepValue(10);
-  wid.push_back(myLauncherWidthSlider);
-  myLauncherWidthLabel =
-      new StaticTextWidget(myTab, font,
-                           xpos + myLauncherWidthSlider->getWidth() + 4,
-                           ypos + 1, 4*fontWidth, fontHeight, "", TextAlign::Left);
-  ypos += lineHeight + 4;
-
-  myLauncherHeightSlider = new SliderWidget(myTab, font, xpos, ypos, pwidth,
-                                            lineHeight, "Launcher Height ",
-                                            lwidth, kLHeightChanged);
-  myLauncherHeightSlider->setMinValue(FrameBuffer::kFBMinH);
-  myLauncherHeightSlider->setMaxValue(ds.h);
-  myLauncherHeightSlider->setStepValue(10);
-  wid.push_back(myLauncherHeightSlider);
-  myLauncherHeightLabel =
-      new StaticTextWidget(myTab, font,
-                           xpos + myLauncherHeightSlider->getWidth() + 4,
-                           ypos + 1, 4*fontWidth, fontHeight, "", TextAlign::Left);
-  ypos += lineHeight + 4;
-
-  // Launcher font
-  pwidth = font.getStringWidth("2x (1000x760)");
-  items.clear();
-  VarList::push_back(items, "Small",  "small");
-  VarList::push_back(items, "Medium", "medium");
-  VarList::push_back(items, "Large",  "large");
-  myLauncherFontPopup =
-    new PopUpWidget(myTab, font, xpos, ypos+1, pwidth, lineHeight, items,
-                    "Launcher Font ", lwidth);
-  wid.push_back(myLauncherFontPopup);
-  ypos += lineHeight + 4;
-
-  // ROM launcher info/snapshot viewer
-  items.clear();
-  VarList::push_back(items, "Off", "0");
-  VarList::push_back(items, "1x (640x480) ", "1");
-  VarList::push_back(items, "2x (1000x760)", "2");
-  myRomViewerPopup =
-    new PopUpWidget(myTab, font, xpos, ypos+1, pwidth, lineHeight, items,
-                    "ROM Info viewer ", lwidth);
-  wid.push_back(myRomViewerPopup);
-  ypos += lineHeight + 4;
-
-  // Exit to Launcher
-  pwidth = font.getStringWidth("If in use");
-  items.clear();
-  VarList::push_back(items, "If in use", "0");
-  VarList::push_back(items, "Always", "1");
-  myLauncherExitPopup =
-    new PopUpWidget(myTab, font, xpos, ypos+1, pwidth, lineHeight, items,
-                    "Exit to Launcher ", lwidth);
-  wid.push_back(myLauncherExitPopup);
-  ypos += lineHeight + 4;
-
-  // Add message concerning usage
-  xpos = vBorder; ypos += 1*(lineHeight + 4);
-  lwidth = ifont.getStringWidth("(*) Changes require application restart");
-  new StaticTextWidget(myTab, ifont, xpos, ypos, std::min(lwidth, _w-20), fontHeight,
-                       "(*) Changes require application restart",
-                       TextAlign::Left);
-
-  // Add items for tab 0
-  addToFocusList(wid, myTab, tabID);
-
-  //////////////////////////////////////////////////////////
-  // 3) Misc. options
+  // 1) Misc. options
   wid.clear();
-  tabID = myTab->addTab(" Misc. ");
-  lwidth = font.getStringWidth("Interface Palette (*) ");
+  tabID = myTab->addTab(" Look & Feel ");
+  lwidth = font.getStringWidth("Mouse wheel scroll ");
   pwidth = font.getStringWidth("Standard");
-  xpos = ypos = vBorder;
+  xpos = HBORDER;  ypos = VBORDER;
 
   // UI Palette
   ypos += 1;
@@ -151,51 +79,112 @@ UIDialog::UIDialog(OSystem& osystem, DialogContainer& parent,
   VarList::push_back(items, "Classic", "classic");
   VarList::push_back(items, "Light", "light");
   myPalettePopup = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                   items, "Interface Palette (*) ", lwidth);
+                                   items, "Theme     ", lwidth);
   wid.push_back(myPalettePopup);
-  ypos += lineHeight + 4;
+  ypos += lineHeight + 4 * 4;
 
   // Delay between quick-selecting characters in ListWidget
-  items.clear();
-  VarList::push_back(items, "Disabled", "0");
-  VarList::push_back(items, "300 ms", "300");
-  VarList::push_back(items, "400 ms", "400");
-  VarList::push_back(items, "500 ms", "500");
-  VarList::push_back(items, "600 ms", "600");
-  VarList::push_back(items, "700 ms", "700");
-  VarList::push_back(items, "800 ms", "800");
-  VarList::push_back(items, "900 ms", "900");
-  VarList::push_back(items, "1 second", "1000");
-  myListDelayPopup = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                     items, "List quick delay ", lwidth);
+  int swidth = myPalettePopup->getWidth() - lwidth;
+  myListDelayPopup = new SliderWidget(myTab, font, xpos, ypos, swidth, lineHeight,
+                                      "List input delay   ", 0, kListDelay,
+                                      font.getStringWidth("1 second"));
+  myListDelayPopup->setMinValue(0);
+  myListDelayPopup->setMaxValue(1000);
+  myListDelayPopup->setStepValue(50);
+  myListDelayPopup->setTickmarkInterval(5);
   wid.push_back(myListDelayPopup);
   ypos += lineHeight + 4;
 
   // Number of lines a mouse wheel will scroll
-  items.clear();
-  VarList::push_back(items, "1 line", "1");
-  VarList::push_back(items, "2 lines", "2");
-  VarList::push_back(items, "3 lines", "3");
-  VarList::push_back(items, "4 lines", "4");
-  VarList::push_back(items, "5 lines", "5");
-  VarList::push_back(items, "6 lines", "6");
-  VarList::push_back(items, "7 lines", "7");
-  VarList::push_back(items, "8 lines", "8");
-  VarList::push_back(items, "9 lines", "9");
-  VarList::push_back(items, "10 lines", "10");
-  myWheelLinesPopup = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                      items, "Mouse wheel scroll ", lwidth);
+  myWheelLinesPopup = new SliderWidget(myTab, font, xpos, ypos, swidth, lineHeight,
+                                      "Mouse wheel scroll ", 0, kMouseWheel,
+                                       font.getStringWidth("10 lines"));
+  myWheelLinesPopup->setMinValue(1);
+  myWheelLinesPopup->setMaxValue(10);
+  myWheelLinesPopup->setTickmarkInterval(3);
   wid.push_back(myWheelLinesPopup);
+
+  // Add items for tab 0
+  addToFocusList(wid, myTab, tabID);
+
+  //////////////////////////////////////////////////////////
+  // 2) Launcher options
+  wid.clear();
+  tabID = myTab->addTab(" Launcher ");
+  lwidth = font.getStringWidth("Launcher height ");
+  xpos = HBORDER;  ypos = VBORDER;
+
+  // Launcher width and height
+  myLauncherWidthSlider = new SliderWidget(myTab, font, xpos, ypos, "Launcher width ",
+                                           lwidth, kLauncherSize, 6 * fontWidth, "px");
+  myLauncherWidthSlider->setMinValue(FrameBuffer::kFBMinW);
+  myLauncherWidthSlider->setMaxValue(ds.w);
+  myLauncherWidthSlider->setStepValue(10);
+  // one tickmark every ~100 pixel
+  myLauncherWidthSlider->setTickmarkInterval((ds.w - FrameBuffer::kFBMinW + 50) / 100);
+  wid.push_back(myLauncherWidthSlider);
   ypos += lineHeight + 4;
 
+  myLauncherHeightSlider = new SliderWidget(myTab, font, xpos, ypos, "Launcher height ",
+                                            lwidth, kLauncherSize, 6 * fontWidth, "px");
+  myLauncherHeightSlider->setMinValue(FrameBuffer::kFBMinH);
+  myLauncherHeightSlider->setMaxValue(ds.h);
+  myLauncherHeightSlider->setStepValue(10);
+  // one tickmark every ~100 pixel
+  myLauncherHeightSlider->setTickmarkInterval((ds.h - FrameBuffer::kFBMinH + 50) / 100);
+  wid.push_back(myLauncherHeightSlider);
+  ypos += lineHeight + 4;
+
+  // Launcher font
+  pwidth = font.getStringWidth("2x (1000x760)");
+  items.clear();
+  VarList::push_back(items, "Small", "small");
+  VarList::push_back(items, "Medium", "medium");
+  VarList::push_back(items, "Large", "large");
+  myLauncherFontPopup =
+    new PopUpWidget(myTab, font, xpos, ypos + 1, pwidth, lineHeight, items,
+                    "Launcher font ", lwidth);
+  wid.push_back(myLauncherFontPopup);
+  ypos += lineHeight +  4 * 4;
+
+  // ROM launcher info/snapshot viewer
+  items.clear();
+  VarList::push_back(items, "Off", "0");
+  VarList::push_back(items, "1x (640x480) ", "1");
+  VarList::push_back(items, "2x (1000x760)", "2");
+  myRomViewerPopup =
+    new PopUpWidget(myTab, font, xpos, ypos + 1, pwidth, lineHeight, items,
+                    "ROM info viewer ", lwidth, kRomViewer);
+  wid.push_back(myRomViewerPopup);
+  ypos += lineHeight + 4;
+
+  // Snapshot path (load files)
+  xpos = HBORDER + INDENT;
+  myOpenBrowserButton = new ButtonWidget(myTab, font, xpos, ypos, buttonWidth, buttonHeight,
+                                         "Image path" + ELLIPSIS, kChooseSnapLoadDirCmd);
+  wid.push_back(myOpenBrowserButton);
+  //ypos += lineHeight + 4;
+  xpos = myOpenBrowserButton->getRight() + 8;
+
+  mySnapLoadPath = new EditTextWidget(myTab, font, xpos, ypos + 1,
+                                      _w - xpos - HBORDER, lineHeight, "");
+  wid.push_back(mySnapLoadPath);
+  ypos += lineHeight + 4 * 5;
+
+  // Exit to Launcher
+  xpos = HBORDER;
+  myLauncherExitWidget = new CheckboxWidget(myTab, font, xpos + 1, ypos, "Always exit to Launcher");
+  wid.push_back(myLauncherExitWidget);
+
   // Add message concerning usage
-  xpos = vBorder; ypos += 1*(lineHeight + 4);
-  lwidth = ifont.getStringWidth("(*) Requires application restart");
-  new StaticTextWidget(myTab, ifont, xpos, ypos, std::min(lwidth, _w-20), fontHeight,
-                       "(*) Requires application restart",
+  xpos = HBORDER;
+  ypos = myTab->getHeight() - 5 - fontHeight - ifont.getFontHeight() - 10;
+  lwidth = ifont.getStringWidth("(*) Changes require application restart");
+  new StaticTextWidget(myTab, ifont, xpos, ypos, std::min(lwidth, _w - 20), fontHeight,
+                       "(*) Changes require application restart",
                        TextAlign::Left);
 
-  // Add items for tab 2
+  // Add items for tab 1
   addToFocusList(wid, myTab, tabID);
 
   // Activate the first tab
@@ -203,13 +192,15 @@ UIDialog::UIDialog(OSystem& osystem, DialogContainer& parent,
 
   // Add Defaults, OK and Cancel buttons
   wid.clear();
-  b = new ButtonWidget(this, font, 10, _h - buttonHeight - 10,
-                       buttonWidth, buttonHeight, "Defaults", GuiObject::kDefaultsCmd);
-  wid.push_back(b);
-  addOKCancelBGroup(wid, font);
+  addDefaultsOKCancelBGroup(wid, font);
   addBGroupToFocusList(wid);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+UIDialog::~UIDialog()
+{
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void UIDialog::loadConfig()
 {
@@ -223,9 +214,7 @@ void UIDialog::loadConfig()
   h = std::min(h, instance().frameBuffer().desktopSize().h);
 
   myLauncherWidthSlider->setValue(w);
-  myLauncherWidthLabel->setValue(w);
   myLauncherHeightSlider->setValue(h);
-  myLauncherHeightLabel->setValue(h);
 
   // Launcher font
   const string& font = instance().settings().getString("launcherfont");
@@ -235,21 +224,26 @@ void UIDialog::loadConfig()
   const string& viewer = instance().settings().getString("romviewer");
   myRomViewerPopup->setSelected(viewer, "0");
 
+  // ROM launcher info viewer image path
+  mySnapLoadPath->setText(instance().settings().getString("snaploaddir"));
+
   // Exit to launcher
   bool exitlauncher = instance().settings().getBool("exitlauncher");
-  myLauncherExitPopup->setSelected(exitlauncher ? "1" : "0", "0");
+  myLauncherExitWidget->setState(exitlauncher);
 
   // UI palette
   const string& pal = instance().settings().getString("uipalette");
   myPalettePopup->setSelected(pal, "standard");
 
   // Listwidget quick delay
-  const string& delay = instance().settings().getString("listdelay");
-  myListDelayPopup->setSelected(delay, "300");
+  int delay = instance().settings().getInt("listdelay");
+  myListDelayPopup->setValue(delay);
 
   // Mouse wheel lines
-  const string& mw = instance().settings().getString("mwheel");
-  myWheelLinesPopup->setSelected(mw, "1");
+  int mw = instance().settings().getInt("mwheel");
+  myWheelLinesPopup->setValue(mw);
+
+  handleRomViewer();
 
   myTab->loadConfig();
 }
@@ -270,23 +264,24 @@ void UIDialog::saveConfig()
   instance().settings().setValue("romviewer",
     myRomViewerPopup->getSelectedTag().toString());
 
+  // ROM launcher info viewer image path
+  instance().settings().setValue("snaploaddir", mySnapLoadPath->getText());
+
   // Exit to Launcher
-  instance().settings().setValue("exitlauncher",
-    myLauncherExitPopup->getSelectedTag().toString());
+  instance().settings().setValue("exitlauncher", myLauncherExitWidget->getState());
 
   // UI palette
   instance().settings().setValue("uipalette",
     myPalettePopup->getSelectedTag().toString());
+  instance().frameBuffer().setUIPalette();
 
   // Listwidget quick delay
-  instance().settings().setValue("listdelay",
-    myListDelayPopup->getSelectedTag().toString());
-  ListWidget::setQuickSelectDelay(myListDelayPopup->getSelectedTag().toInt());
+  instance().settings().setValue("listdelay", myListDelayPopup->getValue());
+  ListWidget::setQuickSelectDelay(myListDelayPopup->getValue());
 
   // Mouse wheel lines
-  instance().settings().setValue("mwheel",
-    myWheelLinesPopup->getSelectedTag().toString());
-  ScrollBarWidget::setWheelLines(myWheelLinesPopup->getSelectedTag().toInt());
+  instance().settings().setValue("mwheel", myWheelLinesPopup->getValue());
+  ScrollBarWidget::setWheelLines(myWheelLinesPopup->getValue());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -294,31 +289,26 @@ void UIDialog::setDefaults()
 {
   switch(myTab->getActiveTab())
   {
-    case 0:  // Launcher options
+    case 0:  // Misc. options
+      myPalettePopup->setSelected("standard");
+      myListDelayPopup->setValue(300);
+      myWheelLinesPopup->setValue(4);
+      break;
+    case 1:  // Launcher options
     {
       uInt32 w = std::min(instance().frameBuffer().desktopSize().w, 900u);
       uInt32 h = std::min(instance().frameBuffer().desktopSize().h, 600u);
       myLauncherWidthSlider->setValue(w);
-      myLauncherWidthLabel->setValue(w);
       myLauncherHeightSlider->setValue(h);
-      myLauncherHeightLabel->setValue(h);
       myLauncherFontPopup->setSelected("medium", "");
       myRomViewerPopup->setSelected("1", "");
-      myLauncherExitPopup->setSelected("0", "");
+      mySnapLoadPath->setText(instance().defaultLoadDir());
+      myLauncherExitWidget->setState(false);
       break;
     }
-
-    case 1:  // Misc. options
-      myPalettePopup->setSelected("standard");
-      myListDelayPopup->setSelected("300");
-      myWheelLinesPopup->setSelected("4");
-      break;
-
     default:
       break;
   }
-
-  _dirty = true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -326,14 +316,6 @@ void UIDialog::handleCommand(CommandSender* sender, int cmd, int data, int id)
 {
   switch(cmd)
   {
-    case kLWidthChanged:
-      myLauncherWidthLabel->setValue(myLauncherWidthSlider->getValue());
-      break;
-
-    case kLHeightChanged:
-      myLauncherHeightLabel->setValue(myLauncherHeightSlider->getValue());
-      break;
-
     case GuiObject::kOKCmd:
       saveConfig();
       close();
@@ -343,8 +325,85 @@ void UIDialog::handleCommand(CommandSender* sender, int cmd, int data, int id)
       setDefaults();
       break;
 
+    case kListDelay:
+      if(myListDelayPopup->getValue() == 0)
+      {
+        myListDelayPopup->setValueLabel("Off");
+        myListDelayPopup->setValueUnit("");
+      }
+      else if(myListDelayPopup->getValue() == 1000)
+      {
+        myListDelayPopup->setValueLabel("1");
+        myListDelayPopup->setValueUnit(" second");
+      }
+      else
+      {
+        myListDelayPopup->setValueUnit(" ms");
+      }
+      break;
+    case kMouseWheel:
+      if(myWheelLinesPopup->getValue() == 1)
+        myWheelLinesPopup->setValueUnit(" line");
+      else
+        myWheelLinesPopup->setValueUnit(" lines");
+      break;
+
+    case kLauncherSize:
+    case kRomViewer:
+      handleRomViewer();
+      break;
+
+    case kChooseSnapLoadDirCmd:
+      // This dialog is resizable under certain conditions, so we need
+      // to re-create it as necessary
+      createBrowser("Select snapshot load directory");
+      myBrowser->show(mySnapLoadPath->getText(),
+                      BrowserDialog::Directories, kSnapLoadDirChosenCmd);
+      break;
+
+    case kSnapLoadDirChosenCmd:
+      mySnapLoadPath->setText(myBrowser->getResult().getShortPath());
+      break;
+
     default:
       Dialog::handleCommand(sender, cmd, data, 0);
       break;
   }
 }
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void UIDialog::handleRomViewer()
+{
+  //string size = myRomViewerPopup->getSelectedName();
+  bool enable = myRomViewerPopup->getSelectedName() != "Off";
+  VariantList items;
+
+  myOpenBrowserButton->setEnabled(enable);
+  mySnapLoadPath->setEnabled(enable);
+
+  /*items.clear();
+  VarList::push_back(items, "Off", "0");
+  VarList::push_back(items, "1x (640x480) ", "1");
+  if(myLauncherWidthSlider->getValue() >= 1000 &&
+     myLauncherHeightSlider->getValue() >= 760)
+  {
+    VarList::push_back(items, "2x (1000x760)", "2");
+  }
+  myRomViewerPopup->addItems(items);
+
+  //myRomViewerPopup->setSelected("1x(640x480) ");*/
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void UIDialog::createBrowser(const string& title)
+{
+  uInt32 w = 0, h = 0;
+  getDynamicBounds(w, h);
+
+  // Create file browser dialog
+  if(!myBrowser || uInt32(myBrowser->getWidth()) != w ||
+     uInt32(myBrowser->getHeight()) != h)
+    myBrowser = make_unique<BrowserDialog>(this, myFont, w, h, title);
+  else
+    myBrowser->setTitle(title);
+}
