@@ -15,6 +15,8 @@
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
+#include <cmath>
+
 #include "bspf.hxx"
 #include "Control.hxx"
 #include "Dialog.hxx"
@@ -32,34 +34,71 @@
 #include "TIASurface.hxx"
 #include "VideoDialog.hxx"
 
+namespace {
+  // Emulation speed is a positive float that multiplies the framerate. However, the UI controls
+  // adjust speed in terms of a speedup factor (1/10, 1/9 .. 1/2, 1, 2, 3, .., 10). The following
+  // mapping and formatting functions implement this conversion. The speedup factor is represented
+  // by an integer value between -900 and 900 (0 means no speedup).
+
+  constexpr int MAX_SPEED = 900;
+  constexpr int MIN_SPEED = -900;
+  constexpr int SPEED_STEP = 10;
+
+  int mapSpeed(float speed)
+  {
+    speed = std::abs(speed);
+
+    return BSPF::clamp(
+      static_cast<int>(round(100 * (speed >= 1 ? speed - 1 : -1 / speed + 1))),
+      MIN_SPEED, MAX_SPEED
+    );
+  }
+
+  float unmapSpeed(int speed)
+  {
+    float f_speed = static_cast<float>(speed) / 100;
+
+    return speed < 0 ? -1 / (f_speed - 1) : 1 + f_speed;
+  }
+
+  string formatSpeed(int speed) {
+    stringstream ss;
+
+    ss
+      << std::setw(3) << std::fixed << std::setprecision(0)
+      << (unmapSpeed(speed) * 100);
+
+    return ss.str();
+  }
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
                          const GUI::Font& font, int max_w, int max_h)
-  : Dialog(osystem, parent)
+  : Dialog(osystem, parent, font, "Video settings")
 {
   const int VGAP = 4;
   const int VBORDER = 8;
-  const int HBORDER = 8;
+  const int HBORDER = 10;
+  const int INDENT = 20;
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
-            fontHeight   = font.getFontHeight(),
-            buttonWidth  = font.getStringWidth("Defaults") + 20,
             buttonHeight = font.getLineHeight() + 4;
   int xpos, ypos, tabID;
-  int lwidth = font.getStringWidth("NTSC Aspect "),
+  int lwidth = font.getStringWidth("TIA Palette "),
     pwidth = font.getStringWidth("XXXXxXXXX"),
-    swidth = 69;
+    swidth = font.getMaxCharWidth() * 10 - 2;
 
   WidgetArray wid;
   VariantList items;
 
   // Set real dimensions
-  _w = std::min(52 * fontWidth + 10, max_w);
-  _h = std::min(16 * (lineHeight + VGAP) + 14, max_h);
+  _w = std::min(55 * fontWidth + HBORDER * 2, max_w);
+  _h = std::min(14 * (lineHeight + VGAP) + 14 + _th, max_h);
 
   // The tab widget
   xpos = 2;  ypos = 4;
-  myTab = new TabWidget(this, font, xpos, ypos, _w - 2*xpos, _h - buttonHeight - 20);
+  myTab = new TabWidget(this, font, xpos, ypos + _th, _w - 2*xpos, _h - _th - buttonHeight - 20);
   addTabWidget(myTab);
 
   xpos = HBORDER;  ypos = VBORDER;
@@ -74,117 +113,106 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   wid.push_back(myRenderer);
   ypos += lineHeight + VGAP;
 
-  // TIA filters (will be dynamically filled later)
-  myTIAZoom = new PopUpWidget(myTab, font, xpos, ypos, pwidth,
-                              lineHeight, items, "TIA Zoom ", lwidth);
-  wid.push_back(myTIAZoom);
-  ypos += lineHeight + VGAP;
-
   // TIA Palette
   items.clear();
   VarList::push_back(items, "Standard", "standard");
   VarList::push_back(items, "Z26", "z26");
   VarList::push_back(items, "User", "user");
   myTIAPalette = new PopUpWidget(myTab, font, xpos, ypos, pwidth,
-                                 lineHeight, items, "TIA Palette ", lwidth);
+                                 lineHeight, items, "TIA palette ", lwidth);
   wid.push_back(myTIAPalette);
   ypos += lineHeight + VGAP;
 
-  // TIA interpolation
-  items.clear();
-  VarList::push_back(items, "Linear", "linear");
-  VarList::push_back(items, "Nearest", "nearest");
-  myTIAInterpolate = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                     items, "TIA Inter ", lwidth);
-  wid.push_back(myTIAInterpolate);
+  // TIA filters (will be dynamically filled later)
+  myTIAZoom = new PopUpWidget(myTab, font, xpos, ypos, pwidth,
+                              lineHeight, items, "TIA zoom ", lwidth);
+  wid.push_back(myTIAZoom);
   ypos += lineHeight + VGAP;
 
-  // Timing to use between frames
-  items.clear();
-  VarList::push_back(items, "Sleep", "sleep");
-  VarList::push_back(items, "Busy-wait", "busy");
-  myFrameTiming = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                  items, "Timing (*) ", lwidth);
-  wid.push_back(myFrameTiming);
+  /*SliderWidget* s = new SliderWidget(myTab, font, xpos, ypos - 1, swidth, lineHeight,
+                                     "TIA zoom", lwidth, 0, fontWidth * 4, "%");
+  s->setMinValue(200); s->setMaxValue(500);
+  s->setTickmarkInterval(3); // just for testing now; TODO: remove or redefine
+  wid.push_back(s);
+  ypos += lineHeight + VGAP;*/
+
+  // TIA interpolation
+  myTIAInterpolate = new CheckboxWidget(myTab, font, xpos, ypos + 1, "TIA interpolation ");
+  wid.push_back(myTIAInterpolate);
   ypos += lineHeight + VGAP;
 
   // Aspect ratio (NTSC mode)
   myNAspectRatio =
-    new SliderWidget(myTab, font, xpos, ypos-1, pwidth, lineHeight,
-                     "NTSC Aspect ", lwidth, kNAspectRatioChanged);
+    new SliderWidget(myTab, font, xpos, ypos-1, swidth, lineHeight,
+                     "NTSC aspect ", lwidth, 0,
+                     fontWidth * 4, "%");
   myNAspectRatio->setMinValue(80); myNAspectRatio->setMaxValue(120);
+  myNAspectRatio->setTickmarkInterval(2);
   wid.push_back(myNAspectRatio);
-  myNAspectRatioLabel =
-    new StaticTextWidget(myTab, font, xpos + myNAspectRatio->getWidth() + 4,
-                         ypos + 1, fontWidth * 3, fontHeight, "", TextAlign::Left);
   ypos += lineHeight + VGAP;
 
   // Aspect ratio (PAL mode)
   myPAspectRatio =
-    new SliderWidget(myTab, font, xpos, ypos-1, pwidth, lineHeight,
-                     "PAL Aspect ", lwidth, kPAspectRatioChanged);
+    new SliderWidget(myTab, font, xpos, ypos-1, swidth, lineHeight,
+                     "PAL aspect ", lwidth, 0,
+                     fontWidth * 4, "%");
   myPAspectRatio->setMinValue(80); myPAspectRatio->setMaxValue(120);
+  myPAspectRatio->setTickmarkInterval(2);
   wid.push_back(myPAspectRatio);
-  myPAspectRatioLabel =
-    new StaticTextWidget(myTab, font, xpos + myPAspectRatio->getWidth() + 4,
-                         ypos + 1, fontWidth * 3, fontHeight, "", TextAlign::Left);
   ypos += lineHeight + VGAP;
 
-  // Framerate
-  myFrameRate =
-    new SliderWidget(myTab, font, xpos, ypos-1, pwidth, lineHeight,
-                     "Framerate ", lwidth, kFrameRateChanged);
-  myFrameRate->setMinValue(0); myFrameRate->setMaxValue(900);
-  myFrameRate->setStepValue(10);
-  wid.push_back(myFrameRate);
-  myFrameRateLabel =
-    new StaticTextWidget(myTab, font, xpos + myFrameRate->getWidth() + 4,
-                         ypos + 1, fontWidth * 4, fontHeight, "", TextAlign::Left);
-
-  // Add message concerning usage
-  const GUI::Font& infofont = instance().frameBuffer().infoFont();
-  ypos = myTab->getHeight() - 5 - fontHeight - infofont.getFontHeight() - 10;
-  new StaticTextWidget(myTab, infofont, 10, ypos,
-        font.getStringWidth("(*) Requires application restart"), fontHeight,
-        "(*) Requires application restart", TextAlign::Left);
-
-  // Move over to the next column
-  xpos += myNAspectRatio->getWidth() + myNAspectRatioLabel->getWidth() + 30;
-  ypos = VBORDER;
-
-  // Fullscreen
-  myFullscreen = new CheckboxWidget(myTab, font, xpos, ypos, "Fullscreen");
-  wid.push_back(myFullscreen);
-  ypos += lineHeight + VGAP;
-
-  // FS stretch
-  myUseStretch = new CheckboxWidget(myTab, font, xpos, ypos, "Fullscreen Fill");
-  wid.push_back(myUseStretch);
+  // Speed
+  mySpeed =
+    new SliderWidget(myTab, font, xpos, ypos-1, swidth, lineHeight,
+                     "Emul. speed ", lwidth, kSpeedupChanged, fontWidth * 5, "%");
+  mySpeed->setMinValue(MIN_SPEED); mySpeed->setMaxValue(MAX_SPEED);
+  mySpeed->setStepValue(SPEED_STEP);
+  mySpeed->setTickmarkInterval(2);
+  wid.push_back(mySpeed);
   ypos += lineHeight + VGAP;
 
   // Use sync to vblank
-  myUseVSync = new CheckboxWidget(myTab, font, xpos, ypos, "VSync");
+  myUseVSync = new CheckboxWidget(myTab, font, xpos, ypos + 1, "VSync");
   wid.push_back(myUseVSync);
+
+  // Move over to the next column
+  xpos += mySpeed->getWidth() + 28;
+  ypos = VBORDER;
+
+  // Fullscreen
+  myFullscreen = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Fullscreen");
+  wid.push_back(myFullscreen);
+  ypos += lineHeight + VGAP;
+
+  /*pwidth = font.getStringWidth("0: 3840x2860@120Hz");
+  myFullScreenMode = new PopUpWidget(myTab, font, xpos + INDENT + 2, ypos, pwidth, lineHeight,
+  instance().frameBuffer().supportedScreenModes(), "Mode ");
+  wid.push_back(myFullScreenMode);
+  ypos += lineHeight + VGAP;*/
+
+  // FS stretch
+  myUseStretch = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Fullscreen fill");
+  wid.push_back(myUseStretch);
   ypos += (lineHeight + VGAP) * 2;
 
   // Skip progress load bars for SuperCharger ROMs
   // Doesn't really belong here, but I couldn't find a better place for it
-  myFastSCBios = new CheckboxWidget(myTab, font, xpos, ypos, "Fast SC/AR BIOS");
+  myFastSCBios = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Fast SuperCharger load");
   wid.push_back(myFastSCBios);
   ypos += lineHeight + VGAP;
 
   // Show UI messages onscreen
-  myUIMessages = new CheckboxWidget(myTab, font, xpos, ypos, "Show UI messages");
+  myUIMessages = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Show UI messages");
   wid.push_back(myUIMessages);
   ypos += lineHeight + VGAP;
 
   // Center window (in windowed mode)
-  myCenter = new CheckboxWidget(myTab, font, xpos, ypos, "Center window");
+  myCenter = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Center window");
   wid.push_back(myCenter);
-  ypos += lineHeight + VGAP;
+  ypos += (lineHeight + VGAP) * 2;
 
   // Use multi-threading
-  myUseThreads = new CheckboxWidget(myTab, font, xpos, ypos, "Use multi-threading");
+  myUseThreads = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Multi-threading");
   wid.push_back(myUseThreads);
 
   // Add items for tab 0
@@ -196,6 +224,7 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   tabID = myTab->addTab(" TV Effects ");
   xpos = HBORDER;
   ypos = VBORDER;
+  swidth = font.getMaxCharWidth() * 8 - 4;
 
   // TV Mode
   items.clear();
@@ -209,27 +238,23 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   pwidth = font.getStringWidth("Bad adjust");
   myTVMode =
     new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                    items, "TV Mode ", lwidth, kTVModeChanged);
+                    items, "TV mode ", lwidth, kTVModeChanged);
   wid.push_back(myTVMode);
   ypos += lineHeight + VGAP;
 
   // Custom adjustables (using macro voodoo)
-  xpos += 8+1; ypos += 0;
-  pwidth = lwidth;
+  xpos += INDENT - 2; ypos += 0;
   lwidth = font.getStringWidth("Saturation ");
 
 #define CREATE_CUSTOM_SLIDERS(obj, desc)                                 \
   myTV ## obj =                                                          \
-    new SliderWidget(myTab, font, xpos, ypos-1, pwidth, lineHeight,      \
-                         desc, lwidth, kTV ## obj ##Changed);            \
+    new SliderWidget(myTab, font, xpos, ypos-1, swidth, lineHeight,      \
+                     desc, lwidth, 0, fontWidth*4, "%");                 \
   myTV ## obj->setMinValue(0); myTV ## obj->setMaxValue(100);            \
+  myTV ## obj->setTickmarkInterval(2);                                   \
   wid.push_back(myTV ## obj);                                            \
-  myTV ## obj ## Label =                                                 \
-    new StaticTextWidget(myTab, font, xpos+myTV ## obj->getWidth()+4,    \
-                    ypos+1, fontWidth*3, fontHeight, "", TextAlign::Left);\
   ypos += lineHeight + VGAP;
 
-  pwidth = swidth;
   CREATE_CUSTOM_SLIDERS(Contrast, "Contrast ");
   CREATE_CUSTOM_SLIDERS(Bright, "Brightness ");
   CREATE_CUSTOM_SLIDERS(Hue, "Hue ");
@@ -241,44 +266,36 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   CREATE_CUSTOM_SLIDERS(Fringe, "Fringing ");
   CREATE_CUSTOM_SLIDERS(Bleed, "Bleeding ");
 
-  xpos += myTVContrast->getWidth() + myTVContrastLabel->getWidth() + 36;
+  xpos += myTVContrast->getWidth() + 30;
   ypos = VBORDER;
 
   lwidth = font.getStringWidth("Intensity ");
-  pwidth = font.getMaxCharWidth() * 6;
 
   // TV Phosphor effect
-  items.clear();
-  VarList::push_back(items, "Always", "always");
-  VarList::push_back(items, "Per-ROM", "byrom");
-  myTVPhosphor = new PopUpWidget(myTab, font, xpos, ypos,
-      font.getStringWidth("Per-ROM"), lineHeight, items,
-      "TV Phosphor ", font.getStringWidth("TV Phosphor "));
+  myTVPhosphor = new CheckboxWidget(myTab, font, xpos, ypos + 1, "Phosphor for all ROMs", kPhosphorChanged);
+  wid.push_back(myTVPhosphor);
   ypos += lineHeight + VGAP;
 
-  // TV Phosphor default level
-  xpos += 8-8+16;
-  pwidth = swidth;
-  CREATE_CUSTOM_SLIDERS(PhosLevel, "Default   ");
+  // TV Phosphor blend level
+  xpos += INDENT;
+  swidth = font.getMaxCharWidth() * 10;
+  CREATE_CUSTOM_SLIDERS(PhosLevel, "Blend     ");
   ypos += 6;
 
   // Scanline intensity and interpolation
-  xpos -= 8+8;
-  myTVScanLabel =
-    new StaticTextWidget(myTab, font, xpos, ypos, font.getStringWidth("Scanline settings"),
-                         fontHeight, "Scanline settings", TextAlign::Left);
+  xpos -= INDENT;
+  myTVScanLabel = new StaticTextWidget(myTab, font, xpos, ypos, "Scanline settings");
   ypos += lineHeight;
 
-  xpos += 8+8;
+  xpos += INDENT;
   CREATE_CUSTOM_SLIDERS(ScanIntense, "Intensity ");
 
-  myTVScanInterpolate = new CheckboxWidget(myTab, font, xpos, ypos,
-                                           "Interpolation");
+  myTVScanInterpolate = new CheckboxWidget(myTab, font, xpos, ypos, "Interpolation");
   wid.push_back(myTVScanInterpolate);
   ypos += lineHeight + 6;
 
   // Adjustable presets
-  xpos -= 8+8;
+  xpos -= INDENT;
   int cloneWidth = font.getStringWidth("Clone Bad Adjust") + 20;
 #define CREATE_CLONE_BUTTON(obj, desc)                                 \
   myClone ## obj =                                                     \
@@ -291,7 +308,7 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   CREATE_CLONE_BUTTON(Composite, "Clone Composite");
   CREATE_CLONE_BUTTON(Svideo, "Clone S-Video");
   CREATE_CLONE_BUTTON(RGB, "Clone RGB");
-  CREATE_CLONE_BUTTON(Bad, "Clone Bad Adjust");
+  CREATE_CLONE_BUTTON(Bad, "Clone Bad adjust");
   CREATE_CLONE_BUTTON(Custom, "Revert");
 
   // Add items for tab 2
@@ -302,11 +319,7 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
 
   // Add Defaults, OK and Cancel buttons
   wid.clear();
-  ButtonWidget* b;
-  b = new ButtonWidget(this, font, 10, _h - buttonHeight - 10,
-                       buttonWidth, buttonHeight, "Defaults", GuiObject::kDefaultsCmd);
-  wid.push_back(b);
-  addOKCancelBGroup(wid, font);
+  addDefaultsOKCancelBGroup(wid, font);
   addBGroupToFocusList(wid);
 
   // Disable certain functions when we know they aren't present
@@ -334,28 +347,21 @@ void VideoDialog::loadConfig()
     instance().settings().getString("palette"), "standard");
 
   // TIA interpolation
-  const string& tia_inter = instance().settings().getBool("tia.inter") ?
-                           "linear" : "nearest";
-  myTIAInterpolate->setSelected(tia_inter, "nearest");
-
-  // Wait between frames
-  myFrameTiming->setSelected(
-    instance().settings().getString("timing"), "sleep");
+  myTIAInterpolate->setState(instance().settings().getBool("tia.inter"));
 
   // Aspect ratio setting (NTSC and PAL)
   myNAspectRatio->setValue(instance().settings().getInt("tia.aspectn"));
-  myNAspectRatioLabel->setLabel(instance().settings().getString("tia.aspectn"));
   myPAspectRatio->setValue(instance().settings().getInt("tia.aspectp"));
-  myPAspectRatioLabel->setLabel(instance().settings().getString("tia.aspectp"));
 
-  // Framerate (0 or -1 means automatic framerate calculation)
-  int rate = instance().settings().getInt("framerate");
-  myFrameRate->setValue(rate < 0 ? 0 : rate);
-  myFrameRateLabel->setLabel(rate <= 0 ? "Auto" :
-    instance().settings().getString("framerate"));
+  // Emulation speed
+  int speed = mapSpeed(instance().settings().getFloat("speed"));
+  mySpeed->setValue(speed);
+  mySpeed->setValueLabel(formatSpeed(speed));
 
   // Fullscreen
   myFullscreen->setState(instance().settings().getBool("fullscreen"));
+  /*string mode = instance().settings().getString("fullscreenmode");
+  myFullScreenMode->setSelected(mode);*/
 
   // Fullscreen stretch setting
   myUseStretch->setState(instance().settings().getBool("tia.fsfill"));
@@ -385,16 +391,14 @@ void VideoDialog::loadConfig()
   loadTVAdjustables(NTSCFilter::PRESET_CUSTOM);
 
   // TV phosphor mode
-  myTVPhosphor->setSelected(
-      instance().settings().getString("tv.phosphor"), "byrom");
+  myTVPhosphor->setState(instance().settings().getString("tv.phosphor") == "always");
 
   // TV phosphor blend
   myTVPhosLevel->setValue(instance().settings().getInt("tv.phosblend"));
-  myTVPhosLevelLabel->setLabel(instance().settings().getString("tv.phosblend"));
+  handlePhosphorChange();
 
   // TV scanline intensity and interpolation
   myTVScanIntense->setValue(instance().settings().getInt("tv.scanlines"));
-  myTVScanIntenseLabel->setLabel(instance().settings().getString("tv.scanlines"));
   myTVScanInterpolate->setState(instance().settings().getBool("tv.scaninter"));
 
   myTab->loadConfig();
@@ -415,31 +419,22 @@ void VideoDialog::saveConfig()
   instance().settings().setValue("palette",
     myTIAPalette->getSelectedTag().toString());
 
-  // Wait between frames
-  instance().settings().setValue("timing",
-    myFrameTiming->getSelectedTag().toString());
-
   // TIA interpolation
-  instance().settings().setValue("tia.inter",
-    myTIAInterpolate->getSelectedTag().toString() == "linear" ? true : false);
+  instance().settings().setValue("tia.inter", myTIAInterpolate->getState());
 
   // Aspect ratio setting (NTSC and PAL)
-  instance().settings().setValue("tia.aspectn", myNAspectRatioLabel->getLabel());
-  instance().settings().setValue("tia.aspectp", myPAspectRatioLabel->getLabel());
+  instance().settings().setValue("tia.aspectn", myNAspectRatio->getValueLabel());
+  instance().settings().setValue("tia.aspectp", myPAspectRatio->getValueLabel());
 
-  // Framerate
-  int f = myFrameRate->getValue();
-  instance().settings().setValue("framerate", f);
-  if(instance().hasConsole())
-  {
-    // Make sure auto-frame calculation is only enabled when necessary
-    instance().console().tia().enableAutoFrame(f <= 0);
-    instance().console().setFramerate(float(f));
-  }
+  // Speed
+  int speedup = mySpeed->getValue();
+  instance().settings().setValue("speed", unmapSpeed(speedup));
+  if (instance().hasConsole()) instance().console().initializeAudio();
 
   // Fullscreen
   instance().settings().setValue("fullscreen", myFullscreen->getState());
-
+  /*instance().settings().setValue("fullscreenmode",
+                                 myFullScreenMode->getSelectedTag().toString());*/
   // Fullscreen stretch setting
   instance().settings().setValue("tia.fsfill", myUseStretch->getState());
 
@@ -480,14 +475,12 @@ void VideoDialog::saveConfig()
 
   // TV phosphor mode
   instance().settings().setValue("tv.phosphor",
-      myTVPhosphor->getSelectedTag().toString());
-
+                                 myTVPhosphor->getState() ? "always" : "byrom");
   // TV phosphor blend
-  instance().settings().setValue("tv.phosblend", myTVPhosLevelLabel->getLabel());
-  Properties::setDefault(Display_PPBlend, myTVPhosLevelLabel->getLabel());
+  instance().settings().setValue("tv.phosblend", myTVPhosLevel->getValueLabel());
 
   // TV scanline intensity and interpolation
-  instance().settings().setValue("tv.scanlines", myTVScanIntenseLabel->getLabel());
+  instance().settings().setValue("tv.scanlines", myTVScanIntense->getValueLabel());
   instance().settings().setValue("tv.scaninter", myTVScanInterpolate->getState());
 
   // Finally, issue a complete framebuffer re-initialization
@@ -504,16 +497,13 @@ void VideoDialog::setDefaults()
       myRenderer->setSelectedIndex(0);
       myTIAZoom->setSelected("3", "");
       myTIAPalette->setSelected("standard", "");
-      myFrameTiming->setSelected("sleep", "");
-      myTIAInterpolate->setSelected("nearest", "");
-      myNAspectRatio->setValue(90);
-      myNAspectRatioLabel->setLabel("91");
-      myPAspectRatio->setValue(100);
-      myPAspectRatioLabel->setLabel("109");
-      myFrameRate->setValue(0);
-      myFrameRateLabel->setLabel("Auto");
+      myTIAInterpolate->setState(false);
+      myNAspectRatio->setValue(91);
+      myPAspectRatio->setValue(109);
+      mySpeed->setValue(0);
 
       myFullscreen->setState(false);
+      //myFullScreenMode->setSelectedIndex(0);
       myUseStretch->setState(true);
       myUseVSync->setState(true);
       myUIMessages->setState(true);
@@ -528,25 +518,22 @@ void VideoDialog::setDefaults()
       myTVMode->setSelected("0", "0");
 
       // TV phosphor mode
-      myTVPhosphor->setSelected("byrom", "byrom");
+      myTVPhosphor->setState(false);
 
       // TV phosphor blend
       myTVPhosLevel->setValue(50);
-      myTVPhosLevelLabel->setLabel("50");
 
       // TV scanline intensity and interpolation
       myTVScanIntense->setValue(25);
-      myTVScanIntenseLabel->setLabel("25");
       myTVScanInterpolate->setState(true);
 
       // Make sure that mutually-exclusive items are not enabled at the same time
       handleTVModeChange(NTSCFilter::PRESET_OFF);
+      handlePhosphorChange();
       loadTVAdjustables(NTSCFilter::PRESET_CUSTOM);
       break;
     }
   }
-
-  _dirty = true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -556,25 +543,15 @@ void VideoDialog::handleTVModeChange(NTSCFilter::Preset preset)
   bool scanenable = preset != NTSCFilter::PRESET_OFF;
 
   myTVSharp->setEnabled(enable);
-  myTVSharpLabel->setEnabled(enable);
   myTVHue->setEnabled(enable);
-  myTVHueLabel->setEnabled(enable);
   myTVRes->setEnabled(enable);
-  myTVResLabel->setEnabled(enable);
   myTVArtifacts->setEnabled(enable);
-  myTVArtifactsLabel->setEnabled(enable);
   myTVFringe->setEnabled(enable);
-  myTVFringeLabel->setEnabled(enable);
   myTVBleed->setEnabled(enable);
-  myTVBleedLabel->setEnabled(enable);
   myTVBright->setEnabled(enable);
-  myTVBrightLabel->setEnabled(enable);
   myTVContrast->setEnabled(enable);
-  myTVContrastLabel->setEnabled(enable);
   myTVSatur->setEnabled(enable);
-  myTVSaturLabel->setEnabled(enable);
   myTVGamma->setEnabled(enable);
-  myTVGammaLabel->setEnabled(enable);
   myCloneComposite->setEnabled(enable);
   myCloneSvideo->setEnabled(enable);
   myCloneRGB->setEnabled(enable);
@@ -583,10 +560,7 @@ void VideoDialog::handleTVModeChange(NTSCFilter::Preset preset)
 
   myTVScanLabel->setEnabled(scanenable);
   myTVScanIntense->setEnabled(scanenable);
-  myTVScanIntenseLabel->setEnabled(scanenable);
   myTVScanInterpolate->setEnabled(scanenable);
-
-  _dirty = true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -596,25 +570,21 @@ void VideoDialog::loadTVAdjustables(NTSCFilter::Preset preset)
   instance().frameBuffer().tiaSurface().ntsc().getAdjustables(
       adj, NTSCFilter::Preset(preset));
   myTVSharp->setValue(adj.sharpness);
-  myTVSharpLabel->setValue(adj.sharpness);
   myTVHue->setValue(adj.hue);
-  myTVHueLabel->setValue(adj.hue);
   myTVRes->setValue(adj.resolution);
-  myTVResLabel->setValue(adj.resolution);
   myTVArtifacts->setValue(adj.artifacts);
-  myTVArtifactsLabel->setValue(adj.artifacts);
   myTVFringe->setValue(adj.fringing);
-  myTVFringeLabel->setValue(adj.fringing);
   myTVBleed->setValue(adj.bleed);
-  myTVBleedLabel->setValue(adj.bleed);
   myTVBright->setValue(adj.brightness);
-  myTVBrightLabel->setValue(adj.brightness);
   myTVContrast->setValue(adj.contrast);
-  myTVContrastLabel->setValue(adj.contrast);
   myTVSatur->setValue(adj.saturation);
-  myTVSaturLabel->setValue(adj.saturation);
   myTVGamma->setValue(adj.gamma);
-  myTVGammaLabel->setValue(adj.gamma);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void VideoDialog::handlePhosphorChange()
+{
+  myTVPhosLevel->setEnabled(myTVPhosphor->getState());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -632,48 +602,14 @@ void VideoDialog::handleCommand(CommandSender* sender, int cmd,
       setDefaults();
       break;
 
-    case kNAspectRatioChanged:
-      myNAspectRatioLabel->setValue(myNAspectRatio->getValue());
-      break;
-
-    case kPAspectRatioChanged:
-      myPAspectRatioLabel->setValue(myPAspectRatio->getValue());
-      break;
-
-    case kFrameRateChanged:
-      if(myFrameRate->getValue() == 0)
-        myFrameRateLabel->setLabel("Auto");
-      else
-        myFrameRateLabel->setValue(myFrameRate->getValue());
+    case kSpeedupChanged:
+      mySpeed->setValueLabel(formatSpeed(mySpeed->getValue()));
       break;
 
     case kTVModeChanged:
       handleTVModeChange(NTSCFilter::Preset(myTVMode->getSelectedTag().toInt()));
       break;
-    case kTVSharpChanged:  myTVSharpLabel->setValue(myTVSharp->getValue());
-      break;
-    case kTVHueChanged:  myTVHueLabel->setValue(myTVHue->getValue());
-      break;
-    case kTVResChanged:  myTVResLabel->setValue(myTVRes->getValue());
-      break;
-    case kTVArtifactsChanged:  myTVArtifactsLabel->setValue(myTVArtifacts->getValue());
-      break;
-    case kTVFringeChanged:  myTVFringeLabel->setValue(myTVFringe->getValue());
-      break;
-    case kTVBleedChanged:  myTVBleedLabel->setValue(myTVBleed->getValue());
-      break;
-    case kTVBrightChanged:  myTVBrightLabel->setValue(myTVBright->getValue());
-      break;
-    case kTVContrastChanged:  myTVContrastLabel->setValue(myTVContrast->getValue());
-      break;
-    case kTVSaturChanged:  myTVSaturLabel->setValue(myTVSatur->getValue());
-      break;
-    case kTVGammaChanged:  myTVGammaLabel->setValue(myTVGamma->getValue());
-      break;
-    case kTVPhosLevelChanged:  myTVPhosLevelLabel->setValue(myTVPhosLevel->getValue());
-      break;
-    case kTVScanIntenseChanged:  myTVScanIntenseLabel->setValue(myTVScanIntense->getValue());
-      break;
+
     case kCloneCompositeCmd: loadTVAdjustables(NTSCFilter::PRESET_COMPOSITE);
       break;
     case kCloneSvideoCmd: loadTVAdjustables(NTSCFilter::PRESET_SVIDEO);
@@ -685,6 +621,10 @@ void VideoDialog::handleCommand(CommandSender* sender, int cmd,
     case kCloneCustomCmd: loadTVAdjustables(NTSCFilter::PRESET_CUSTOM);
       break;
 
+    case kPhosphorChanged:
+      handlePhosphorChange();
+      break;
+
     default:
       Dialog::handleCommand(sender, cmd, data, 0);
       break;
