@@ -10,20 +10,21 @@ my %prop_type = (
   "Cartridge.Note"          => 4,
   "Cartridge.Rarity"        => 5,
   "Cartridge.Sound"         => 6,
-  "Cartridge.Type"          => 7,
-  "Console.LeftDifficulty"  => 8,
-  "Console.RightDifficulty" => 9,
-  "Console.TelevisionType"  => 10,
-  "Console.SwapPorts"       => 11,
-  "Controller.Left"         => 12,
-  "Controller.Right"        => 13,
-  "Controller.SwapPaddles"  => 14,
-  "Controller.MouseAxis"    => 15,
-  "Display.Format"          => 16,
-  "Display.YStart"          => 17,
-  "Display.Height"          => 18,
-  "Display.Phosphor"        => 19,
-  "Display.PPBlend"         => 20
+  "Cartridge.StartBank"     => 7,
+  "Cartridge.Type"          => 8,
+  "Console.LeftDifficulty"  => 9,
+  "Console.RightDifficulty" => 10,
+  "Console.TelevisionType"  => 11,
+  "Console.SwapPorts"       => 12,
+  "Controller.Left"         => 13,
+  "Controller.Right"        => 14,
+  "Controller.SwapPaddles"  => 15,
+  "Controller.MouseAxis"    => 16,
+  "Display.Format"          => 17,
+  "Display.YStart"          => 18,
+  "Display.Height"          => 19,
+  "Display.Phosphor"        => 20,
+  "Display.PPBlend"         => 21
 );
 my @prop_type_as_string = (
   "Cartridge.MD5",
@@ -33,6 +34,7 @@ my @prop_type_as_string = (
   "Cartridge.Note",
   "Cartridge.Rarity",
   "Cartridge.Sound",
+  "Cartridge.StartBank",
   "Cartridge.Type",
   "Console.LeftDifficulty",
   "Console.RightDifficulty",
@@ -57,6 +59,7 @@ my @prop_defaults = (
   "",
   "",
   "MONO",
+  "",
   "AUTO",
   "B",
   "B",
