@@ -8,8 +8,8 @@
 
 using namespace std;
 
-typedef unsigned char uInt8;
-typedef unsigned int uInt32;
+using uInt8 = unsigned char;
+using uInt32 = unsigned int;
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int searchForBytes(const uInt8* image, uInt32 imagesize,
@@ -49,18 +49,18 @@ int main(int ac, char* av[])
   }
   if(ac > 3)
     offset = atoi(av[3]);
-  
+
   ifstream in(av[1], ios_base::binary);
   in.seekg(0, ios::end);
   int i_size = (int) in.tellg();
   in.seekg(0, ios::beg);
 
-  uInt8* image = new uInt8[i_size];
-  in.read((char*)(image), i_size);
+  unique_ptr<uInt8[]> image = make_unique<uInt8[]>(i_size);
+  in.read((char*)(image.get()), i_size);
   in.close();
 
   int s_size = 0;
-  uInt8* sig = new uInt8[strlen(av[2])/2];
+  unique_ptr<uInt8[]> sig = make_unique<uInt8[]>(strlen(av[2])/2);
   istringstream buf(av[2]);
 
   uInt32 c;
@@ -72,7 +72,7 @@ int main(int ac, char* av[])
 //  cerr << "sig size = " << hex << s_size << endl;
 
   list<int> locations;
-  int result = searchForBytes(image+offset, i_size-offset, sig, s_size, locations);
+  int result = searchForBytes(image.get()+offset, i_size-offset, sig.get(), s_size, locations);
   if(result > 0)
   {
     cout << setw(3) << result << " hits:  \'" << av[2] << "\' - \"" << av[1] << "\" @";
@@ -81,8 +81,5 @@ int main(int ac, char* av[])
     cout << endl;
   }
 
-  delete[] image;
-  delete[] sig;
-
   return 0;
 }
