@@ -59,14 +59,16 @@ FilesystemNodePOSIX::FilesystemNodePOSIX(const string& p, bool verify)
   if(_path[0] == '~')
   {
     const char* home = getenv("HOME");
-    if (home != nullptr)
+    if(home != nullptr)
       _path.replace(0, 1, home);
   }
-
-  // Get absolute path
-  char buf[MAXPATHLEN];
-  if(realpath(_path.c_str(), buf))
-    _path = buf;
+  // Get absolute path (only used for relative directories)
+  else if(_path[0] == '.')
+  {
+    char buf[MAXPATHLEN];
+    if(realpath(_path.c_str(), buf))
+      _path = buf;
+  }
 
   _displayName = lastPathComponent(_path);
 
@@ -97,12 +99,11 @@ bool FilesystemNodePOSIX::getChildren(AbstractFSList& myList, ListMode mode,
   assert(_isDirectory);
 
   DIR* dirp = opendir(_path.c_str());
-  struct dirent* dp;
-
   if (dirp == nullptr)
     return false;
 
-  // loop over dir entries using readdir
+  // Loop over dir entries using readdir
+  struct dirent* dp;
   while ((dp = readdir(dirp)) != nullptr)
   {
     // Skip 'invisible' files if necessary
@@ -137,7 +138,6 @@ bool FilesystemNodePOSIX::getChildren(AbstractFSList& myList, ListMode mode,
     }
     else
     {
-      entry._isValid = (dp->d_type == DT_DIR) || (dp->d_type == DT_REG) || (dp->d_type == DT_LNK);
       if (dp->d_type == DT_LNK)
       {
         struct stat st;
@@ -157,6 +157,8 @@ bool FilesystemNodePOSIX::getChildren(AbstractFSList& myList, ListMode mode,
 
       if (entry._isDirectory)
         entry._path += "/";
+
+      entry._isValid = entry._isDirectory || entry._isFile;
     }
 #endif
 
@@ -226,7 +228,7 @@ bool FilesystemNodePOSIX::rename(const string& newfile)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-AbstractFSNode* FilesystemNodePOSIX::getParent() const
+AbstractFSNodePtr FilesystemNodePOSIX::getParent() const
 {
   if (_path == "/")
     return nullptr;
@@ -234,5 +236,5 @@ AbstractFSNode* FilesystemNodePOSIX::getParent() const
   const char* start = _path.c_str();
   const char* end = lastPathComponent(_path);
 
-  return new FilesystemNodePOSIX(string(start, size_t(end - start)));
+  return make_unique<FilesystemNodePOSIX>(string(start, size_t(end - start)));
 }
